IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[adfCompanyUpdate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure adfCompanyUpdate'
		DROP PROCEDURE [dbo].[adfCompanyUpdate]
	END
GO

PRINT 'Creating procedure adfCompanyUpdate'
GO

/******************************************************************************
**		File: adfCompanyUpdate.sql
**		Name: adfCompanyUpdate
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Dmitry.Kolchev
**		Date: 10/04/2004 12:32:25
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		17.02.10	PAM				    LegalCode
**
**		6.05.10		KOV				  ApplyVAT
**    
**		21.05.10	KOV				  @ExchangeBanned, @ExportFinanceOnce
**		04.08.11	PAM				      
**		28.11.11	PAM				   ""
**		19.02.13	SAP				  [PlanProfitability],[PlanPurchases] 
**									[BIN]
**		06.03.13	SAP				  OPENXML
*******************************************************************************/
CREATE PROCEDURE [dbo].[adfCompanyUpdate]
	@Xml XML,
	@ExtendedProperties XML
AS
	
	DECLARE	@result INT,
			@ID TIdentifier,
			@FileAs TName,
			@FileAsOld	TName,
			@FoundationDate TDate,
			@LegalName TName,
			@KPP TCode,
			@LegalCode TCode,
			@BankAccountID TIdentifier,
			@ExecutiveEmployeeID TIdentifier,
			@AccountantEmployeeID TIdentifier,
			@ManagerEmployeeID TIdentifier,
			@Own TBool,
			@CompanySizeID TIdentifier,
			@CompanyTurnoverID TIdentifier,
			@CompanyStatusID TIdentifier,
			@Comments TNotes,
			@Class TClass,
			@ApplyVAT TBool,
			@PaymentCurrencyPoint TBool,
			@ExchangeBanned TBool,
			@ExportFinanceOnce TBool,
			@Number TCode,
			@PlanProfitability TPercent,
			@PlanPurchases TBool,
			@BIN TCode,
			@OwnOld TBool,
			@PlanProfitabilityOld TPercent
	
			
	SET NOCOUNT ON
	
	
	SELECT
		@ID	= T.c.value('ID[1]','int'),
		@FileAs = T.c.value('FileAs[1]','nvarchar(256)'),
		@FoundationDate = CONVERT(datetime, T.c.value('FoundationDate[1]','varchar(19)'), 126),
		@LegalName = T.c.value('LegalName[1]','nvarchar(256)'),
		@KPP = T.c.value('KPP[1]','varchar(32)'),
		@LegalCode = CASE 
						WHEN T.c.value('LegalCode[1]','varchar(32)') = '' THEN NULL 
						ELSE T.c.value('LegalCode[1]','varchar(32)') 
					END,
		@ApplyVAT = T.c.value('ApplyVAT[1]','varchar(5)'),
		@BankAccountID = T.c.value('BankAccountID[1]','int'),
		@ExecutiveEmployeeID = T.c.value('ExecutiveEmployeeID[1]','int'),
		@AccountantEmployeeID = T.c.value('AccountantEmployeeID[1]','int'),
		@Own = (CASE T.c.value('Own[1]','varchar(5)') 
					WHEN 'false' THEN 0 
					ELSE 1 
				END),
		@ManagerEmployeeID = T.c.value('ManagerEmployeeID[1]','int'),
		@CompanySizeID = T.c.value('CompanySizeID[1]','int'),
		@CompanyTurnoverID = T.c.value('CompanyTurnoverID[1]','int'),
		@CompanyStatusID = T.c.value('CompanyStatusID[1]','int'),
		@Comments = T.c.value('Comments[1]','nvarchar(max)'),
		@PaymentCurrencyPoint = T.c.value('PaymentCurrencyPoint[1]','int'),
		@ExchangeBanned = T.c.value('ExchangeBanned[1]','varchar(5)'),
		@ExportFinanceOnce = T.c.value('ExportFinanceOnce[1]','varchar(5)'),
		@Number = T.c.value('Number[1]','varchar(32)'),
		@PlanProfitability = T.c.value('PlanProfitability[1]','decimal(18,4)'),
		@PlanPurchases = T.c.value('PlanPurchases[1]','bit'),
		@BIN = T.c.value('BIN[1]','varchar(32)')
	FROM
		@Xml.nodes('/adfCompanyGet/Company') AS T(c)


	IF (@Own = 1 OR (SELECT [Own] FROM [Company] WHERE [ID] = @ID) = 1) AND dbo.adfHasAccessRightByName('ManageOwnCompanies') = 0
	BEGIN
		RAISERROR('#accessdenied', 16, -1)
		RETURN 1
	END

	SET @FileAsOld = (SELECT [FileAs] FROM [Company] WHERE [ID] = @ID)
	SET @OwnOld = (SELECT [Own] FROM [Company] WHERE [ID] = @ID)
	SET @PlanProfitabilityOld = (SELECT [PlanProfitability] FROM [Company] WHERE [ID] = @ID)
	
	 
	
	BEGIN TRANSACTION
	
	UPDATE [Company]
	SET
		@Class = [Company].[Class],
		[Company].[FileAs] = @FileAs,
		[Company].[FoundationDate] = @FoundationDate,
		[Company].[LegalName] = @LegalName,
		[Company].[KPP] = @KPP,
		[Company].[LegalCode] = @LegalCode,
		[Company].[ApplyVAT] = @ApplyVAT,
		[Company].[BankAccountID] = @BankAccountID,
		[Company].[ExecutiveEmployeeID] = @ExecutiveEmployeeID,
		[Company].[AccountantEmployeeID] = @AccountantEmployeeID,
		[Company].[Own] = @Own,
		[Company].[ManagerEmployeeID] = @ManagerEmployeeID,
		[Company].[CompanySizeID] = @CompanySizeID,
		[Company].[CompanyTurnoverID] = @CompanyTurnoverID,
		[Company].[CompanyStatusID] = @CompanyStatusID,
		[Company].[Comments] = @Comments,
		[Company].[Modified] = DEFAULT,
		[Company].[ModifiedBy] = DEFAULT,
		[Company].[PaymentCurrencyPoint] = @PaymentCurrencyPoint,
		[Company].[ExchangeBanned] = @ExchangeBanned,
		[Company].[ExportFinanceOnce] = @ExportFinanceOnce,
		[Company].[Number] = @Number,
		[Company].[PlanProfitability] = @PlanProfitability,
		[Company].[PlanPurchases] = @PlanPurchases,
		[Company].[BIN] = @BIN
	WHERE
		[Company].[ID] = @ID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	IF (@OwnOld = 1 AND @Own = 0) AND (@PlanProfitabilityOld IS NULL)
	BEGIN
		EXEC adfCompanyInsertDefaultPlanningValues @CompanyID=@ID
	END
	
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	DECLARE @CurrentUserID TIdentifier
	
	SET @CurrentUserID = dbo.adfGetCurrentUserID()

	UPDATE [ExtendedProperties]
	SET
		[ExtendedProperties]=@ExtendedProperties
	WHERE
		[Class] = @Class AND [ID] = @ID
	
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

		
	EXEC @result = adfBusinessCardUpdate @doc = @Xml, @XPathRoot = '/adfCompanyGet', 
		@ID = @ID, @Class = @Class, @FileAs = @FileAs, @Comments = @Comments,
		@CompanyID = @ID, @PositionID = NULL
	
	IF @@error != 0 OR @result != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	DELETE [CompanyIndustryBranch] WHERE [CompanyID] = @ID
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	

	INSERT INTO [CompanyIndustryBranch] ([CompanyID], [IndustryBranchID])
	SELECT 
		@ID, 
		T.c.value('IndustryBranchID[1]','int') 
	FROM
		@Xml.nodes('/adfCompanyGet/CompanyIndustryBranch') AS T(c)

	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	EXEC @result = adfCompanyCalendarCreate @ID, @Own
	IF @result != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	IF @FileAsOld != @FileAs
	BEGIN
		UPDATE [Folder]
		SET
			[Folder].[FileAs] = @FileAs
		WHERE
			[Folder].[CompanyID] = @ID AND
			[Folder].[FolderID] IS NULL
		IF @@error != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END

	COMMIT TRANSACTION	
	
	
	EXEC adfCompanyGet @ID

	RETURN 0
GO

GRANT EXECUTE ON adfCompanyUpdate TO PUBLIC
GO
