IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfCustomerBrowseByCategory')
	BEGIN
		PRINT 'Dropping Procedure adfCustomerBrowseByCategory'
		DROP  Procedure  adfCustomerBrowseByCategory
	END

GO

PRINT 'Creating Procedure adfCustomerBrowseByCategory'
GO
/******************************************************************************
**		File: 
**		Name: adfCustomerBrowseByCategory
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		6.05.10		KOV				  ApplyVAT
**		15.12.11	PAM				   
*******************************************************************************/
CREATE Procedure adfCustomerBrowseByCategory
AS
	SET NOCOUNT ON
	SET ARITHABORT ON

	--     
	IF dbo.adfHasAccessRightByName('ManageCompanies') = 0 AND dbo.adfHasAccessRightByName('ViewAllCompanies') = 0
		RETURN 0

	DECLARE @CurrentUserID TIdentifier, @CompanyClass TClass, @UserID TIdentifier
	
	SET @CurrentUserID = dbo.adfGetCurrentUserID()
	SET @CompanyClass = dbo.adfGetClassByName('Adf.Company')

	
	DECLARE @none nvarchar(6)
	IF dbo.adfGetLanguage() = 'ru'
		SET @none = '()'
	ELSE
		SET @none = '(none)'	
	
	SELECT
		[Company].[ID],
		[Company].[Class],
		[Company].[State],
		[Company].[Flag],
		[Company].[FileAs],
		[Company].[FoundationDate],
		[Company].[LegalName],
		[Company].[KPP],
		[Company].[LegalCode],
		[Company].[BankAccountID],
		[Company].[ExecutiveEmployeeID],
		[Company].[AccountantEmployeeID],
		[Company].[Own],
		[Company].[ManagerEmployeeID],
		[Company].[CompanySizeID],
		[Company].[CompanyTurnoverID],
		[Company].[CompanyStatusID],
		[Company].[Comments],
		[Company].[Created],
		[Company].[CreatedBy],
		[Company].[Modified],
		[Company].[ModifiedBy],
		[Company].[Timestamp],
		[Company].[ApplyVAT],
		[#PhoneType#7] as Phone1,
		[#PhoneType#11] as Phone2,
		(SELECT [Street]  FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 1) as [Street],
		(SELECT [Street] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 3) as [Street2],
		(SELECT [Country] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 1) as [Country],
		(SELECT [Country] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 3) as [Country2],
		(SELECT [Region] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 1) as [Region],
		(SELECT [Region] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 3) as [Region2],
		(SELECT [City] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 1) as [City],
		(SELECT [City] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 3) as [City2],
		(SELECT [PostalCode] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 1) as [PostalCode],
		(SELECT [PostalCode] FROM [Address] WHERE [Address].[BusinessCardID] = [Company].[ID] AND [Address].[BusinessCardClass] = [Company].[Class] AND [Address].[AddressTypeID] = 3) as [PostalCode2],
		(SELECT [Email] FROM [Email] WHERE [Email].[BusinessCardID] = [Company].[ID] AND [Email].[BusinessCardClass] = [Company].[Class] AND [Email].[EmailTypeID] = 1) as Email,
		(SELECT [Email] FROM [Email] WHERE [Email].[BusinessCardID] = [Company].[ID] AND [Email].[BusinessCardClass] = [Company].[Class] AND [Email].[EmailTypeID] = 4) as WebPage,
		ISNULL([adfvwDocumentCategory].[CategoryName], @none) as [Category],
		CAST((CASE WHEN [UserContact].[BusinessCardID] IS NULL THEN 0 ELSE 1 END) as bit) as [Private],
		[#PhoneType#1],
		[#PhoneType#2],
		[#PhoneType#3],
		[#PhoneType#4],
		[#PhoneType#5],
		[#PhoneType#6],
		[#PhoneType#7],
		[#PhoneType#8],
		[#PhoneType#9],
		[#PhoneType#10],
		[#PhoneType#11]
	FROM
		[Company]
		LEFT OUTER JOIN [vwPhone]
			ON ([Company].[ID] = [vwPhone].[BusinessCardID] AND @CompanyClass = [vwPhone].[BusinessCardClass])
		LEFT OUTER JOIN [adfvwDocumentCategory]
			ON ([Company].[Class] = [adfvwDocumentCategory].[DocumentClass] AND [Company].[ID] = [adfvwDocumentCategory].[DocumentID])
		LEFT OUTER JOIN [UserContact]
			ON ([Company].[ID] = [UserContact].[BusinessCardID] AND [UserContact].[BusinessCardClass] = @CompanyClass AND [UserContact].[UserID] = @CurrentUserID)
	WHERE
		[Company].[State] = 1
	AND
		[Company].[Own] = 0
	AND
		(EXISTS(SELECT * FROM [Project] WHERE [Project].[CustomerCompanyID] = [Company].[ID] AND [Project].[State] IN (2, 3)))
	RETURN 0
GO

GRANT EXEC ON adfCustomerBrowseByCategory TO PUBLIC
GO
 