﻿IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfContactBrowseByInteraction')
	BEGIN
		PRINT 'Dropping Procedure adfContactBrowseByInteraction'
		DROP  Procedure  adfContactBrowseByInteraction
	END

GO

PRINT 'Creating Procedure adfContactBrowseByInteraction'
GO
/******************************************************************************
**		File: adfContactBrowseByInteraction.sql
**		Name: adfContactBrowseByInteraction
**		Desc: Процедура заполняет представление "Следующее взаимодействие" для
**				контактов
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**     ----------							-----------
**
**		Auth: anton.paramonov
**		Date: 15.05.2012 14:55:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		04.03.14	GNV				Добавление полей адреса (юридич. и фактич.)
*******************************************************************************/
CREATE Procedure adfContactBrowseByInteraction
	@Own BIT,
	@StateSelector INT,
	@DateSelector INT
AS
	SET NOCOUNT ON
	
	--Есть ли права на просмотр контактов
	IF dbo.adfHasAccessRightByName('ViewAllContacts') = 0 AND dbo.adfHasAccessRightByName('ManageContacts') = 0
		RETURN 0

	DECLARE 
		@UserID				TIdentifier, 
		@EmployeeClass		TClass,
		@DateFirstBefore	int,
		@Lang               TLanguage
	
	SET @DateFirstBefore = @@datefirst
	SET @UserID = dbo.adfGetCurrentUserID()
	SET @EmployeeClass = dbo.adfGetClassByName('Adf.Employee')
	SET DATEFIRST 1
	SET @Lang = dbo.adfGetLanguage()

	SELECT
		[Employee].[ID],
		[Employee].[Class],
		[Employee].[State],
		[Employee].[Flag],
		[Employee].[FileAs],
		[Employee].[CompanyID],
		[Employee].[PositionID],
		[Employee].[QualificationID],
		[Employee].[DivisionID],
		[Employee].[Comments],
		[Employee].[Created],
		[Employee].[CreatedBy],
		[Employee].[Modified],
		[Employee].[ModifiedBy],
		[Employee].[Timestamp],
		[Employee].[Title],
		[Employee].[FirstName],
		[Employee].[MiddleName],
		[Employee].[LastName],
		[Employee].[Suffix],
		[Employee].[Initials],
		[Employee].[BirthDate],
		[Employee].[BirthPlace],
		[Employee].[LegalCode],
		(CASE 
			WHEN  CAST([ExtendedProperties] as xml).value('(/ExtendedProperties/Values/Gender)[1]','int') = '1' THEN (CASE WHEN @lang='ru' THEN 'муж.' ELSE 'male' END)
			WHEN  CAST([ExtendedProperties] as xml).value('(/ExtendedProperties/Values/Gender)[1]','int') = '2' THEN (CASE WHEN @lang='ru' THEN 'жен.' ELSE 'female' END)
			ELSE (CASE WHEN @lang='ru' THEN 'не указан' ELSE 'not set' END)
		END) AS [Gender],
		[#PhoneType#1] as Phone1,
		[#PhoneType#2] as Phone2,
		(SELECT [Street] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 1) as [Street1],
		(SELECT [Street] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 3) as [Street2],
		(SELECT [Country] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 1) as [Country1],
		(SELECT [Country] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 3) as [Country2],
		(SELECT [Region] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 1) as [Region1],
		(SELECT [Region] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 3) as [Region2],
		(SELECT [City] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 1) as [City1],
		(SELECT [City] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 3) as [City2],
		(SELECT [PostalCode] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 1) as [PostalCode1],
		(SELECT [PostalCode] FROM [Address] WHERE [Address].[BusinessCardID] = [Employee].[ID] AND [Address].[BusinessCardClass] = [Employee].[Class] AND [Address].[AddressTypeID] = 3) as [PostalCode2],
		(SELECT [Email] FROM [Email] WHERE [Email].[BusinessCardID] = [Employee].[ID] AND [Email].[BusinessCardClass] = [Employee].[Class] AND [Email].[EmailTypeID] = 1) as Email,
		(SELECT [Email] FROM [Email] WHERE [Email].[BusinessCardID] = [Employee].[ID] AND [Email].[BusinessCardClass] = [Employee].[Class] AND [Email].[EmailTypeID] = 4) as WebPage,
		[Company].[ManagerEmployeeID],
		CAST((CASE WHEN [UserContact].[BusinessCardID] IS NULL THEN 0 ELSE 1 END) as bit) as [Private],
		[#PhoneType#1],
		[#PhoneType#2],
		[#PhoneType#3],
		[#PhoneType#4],
		[#PhoneType#5],
		[#PhoneType#6],
		[#PhoneType#7],
		[#PhoneType#8],
		[#PhoneType#9],
		[#PhoneType#10],
		[#PhoneType#11],
		CASE 
			WHEN [Reminder].[Subtype] <> 'CB' THEN	[Reminder].[EventTime]
			ELSE DATEADD(Minute,- [UserReminder].[OriginalInterval],[Reminder].[EventTime])
		END AS [ReminderEventTime],
		[UserReminder].[Description] AS [ReminderDescription]
	FROM
		[Employee] 
		INNER JOIN [Reminder]
			ON [Reminder].[DocumentID] = [Employee].[ID] AND
				[Reminder].[DocumentClass] = [Employee].[Class]
		INNER JOIN [UserReminder]
				ON [UserReminder].[ReminderID] = [Reminder].[ID] AND
					[UserReminder].[UserID] = @UserID
		LEFT OUTER JOIN [vwPhone]
			ON ([Employee].[ID] = [vwPhone].[BusinessCardID] AND [Employee].[Class] = [vwPhone].[BusinessCardClass])
		INNER JOIN [BusinessCard]
			ON ([Employee].[ID] = [BusinessCard].[ID] AND [Employee].[Class] = [BusinessCard].[Class])
		LEFT OUTER JOIN [Company]
			ON ([Employee].[CompanyID] = [Company].[ID])
		LEFT OUTER JOIN [UserContact]
			ON ([Employee].[ID] = [UserContact].[BusinessCardID] AND [UserContact].[BusinessCardClass] = @EmployeeClass AND [UserContact].[UserID] = @UserID)
		LEFT OUTER JOIN [ExtendedProperties]
			ON [Employee].[ID] = [ExtendedProperties].[ID] AND [Employee].[Class] = [ExtendedProperties].[Class]
	WHERE
		(
			(@StateSelector = 0) 
			OR 
			(@StateSelector = 1 AND ([Employee].[State] = 1 AND ( [Company].[State] = 1 OR [Employee].[CompanyID] IS NULL)))
			OR 
			(@StateSelector = 2 AND ([Employee].[State] = 2 OR [Company].[State] = 2))
		)
		AND
		(
			[Company].[Own] = 0
			OR
			[Employee].[CompanyID] IS NULL
		)
		AND
		(	
			@Own = 0
			OR
			(@Own != 0 AND [UserContact].[BusinessCardID] IS NOT NULL)
		)
		AND
		(
			(@DateSelector = 0)
			OR
			(@DateSelector = 1 AND SUBSTRING((SELECT dbo.fnPjm7GetEmployeeBirthdayFormatted([Reminder].[EventTime],1)),1,1) IN ('5','6','7','0'))
			OR
			(@DateSelector = 2 AND SUBSTRING((SELECT dbo.fnPjm7GetEmployeeBirthdayFormatted([Reminder].[EventTime],0)),1,1) IN ('4'))
			OR
			(@DateSelector = 3 AND Datepart(month,[Employee].[BirthDate]) = Datepart(month,GetDate()))
			OR
			(@DateSelector = 4 AND Datepart(month,[Employee].[BirthDate]) = Datepart(month,Dateadd(month,1,GetDate())))
		)
		AND
			[UserReminder].[State] = 1		

	SET DATEFIRST @DateFirstBefore
	RETURN 0
GO

GRANT EXEC ON adfContactBrowseByInteraction TO PUBLIC

GO
