IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'adftrDocumentInsert')
	BEGIN
		PRINT 'Dropping Trigger adftrDocumentInsert'
		DROP  Trigger adftrDocumentInsert
	END
GO

/******************************************************************************
**		File: 
**		Name: adftrDocumentInsert
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    04.12.09			SYV				   @ModifiedBy   AS OWNER
*******************************************************************************/

PRINT 'Creating Trigger adftrDocumentInsert'
GO
CREATE TRIGGER adftrDocumentInsert ON [Document] FOR INSERT
AS
	IF @@rowcount = 0 
		RETURN

	SET NOCOUNT ON
	DECLARE insertedDocuments CURSOR LOCAL FORWARD_ONLY READ_ONLY FOR
		SELECT [ID], [Class], [State], [ModifiedBy] FROM inserted
	DECLARE @ID TIdentifier, @Class TClass, @ToState TState,
			@TransitionTemplateID TIdentifier, @RightID TIdentifier,
			@UserID TIdentifier, @Created TDateTime, @result INT,
			@ModifiedBy TIdentifier,
			@IssueClass TClass, @StickerClass TClass, @AnnouncementClass TClass, @MailItemClass TClass
			
	SET @UserID = dbo.adfGetCurrentUserID()
	SET @Created = GETDATE()
	SET @IssueClass = dbo.adfGetClassByName('Pjm5.Issue')
	SET @StickerClass = dbo.adfGetClassByName('Adf.Sticker')
	SET @AnnouncementClass = dbo.adfGetClassByName('Adf.Announcement')
	SET @MailItemClass = dbo.adfGetClassByName('Adf.MailItem')

	OPEN insertedDocuments
	FETCH NEXT FROM insertedDocuments INTO @ID, @Class, @ToState, @ModifiedBy
	WHILE @@FETCH_STATUS = 0
	BEGIN
		SET @TransitionTemplateID = NULL
		SELECT
			@TransitionTemplateID = [TransitionTemplate].[ID],
			@RightID = [TransitionTemplate].[RightID]
		FROM
			[TransitionTemplate]
		WHERE
			[FromState] IS NULL AND [ToState] = @ToState AND [Class] = @Class
		
		IF @TransitionTemplateID IS NULL
		BEGIN	
			RAISERROR('#TransitionTemplateCouldNotBeFound', 16, -1)
			ROLLBACK TRANSACTION
			RETURN
		END
		
		EXEC @result = adfAccessRightCheckInternal @RightID, @UserID
		IF @result != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN
		END
		
		IF @UserID = 1
		BEGIN
			INSERT INTO [Transition]
				([TransitionTemplateID], [Class], [DocumentID], [UserID], [Created])
			VALUES
				(@TransitionTemplateID, @Class, @ID, @ModifiedBy, @Created)
			IF @@error != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN
			END
		END
		ELSE
		BEGIN
			INSERT INTO [Transition]
				([TransitionTemplateID], [Class], [DocumentID], [UserID], [Created])
			VALUES
				(@TransitionTemplateID, @Class, @ID, @UserID, @Created)
			IF @@error != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN
			END
		END
		
		IF (@Class IN (@IssueClass, @StickerClass, @AnnouncementClass, @MailItemClass))
		BEGIN
			INSERT INTO [DocumentUserState] 
				([UserID], [DocumentClass], [DocumentID], [Read])
			VALUES
				(@UserID, @Class, @ID, 1)
		END

		FETCH NEXT FROM insertedDocuments INTO @ID, @Class, @ToState, @ModifiedBy
	END
	
	CLOSE insertedDocuments
	DEALLOCATE insertedDocuments
	
	RETURN
GO

