﻿if exists (select * from dbo.sysobjects where id = object_id(N'[exch].[MeetingRequestBrowse]') and objectproperty(id, N'IsProcedure') = 1)
begin
	print 'Dropping procedure MeetingRequestBrowse'
	drop procedure [exch].[MeetingRequestBrowse]
end
go

print 'Creating procedure MeetingRequestBrowse'
go

create procedure [exch].[MeetingRequestBrowse] @UserID TIdentifier
with execute as 'pjmexchangesync'
as
begin
	set nocount on;

	declare @calendarSyncPeriod int, @date date;
	
	set @calendarSyncPeriod = isnull(cast((select [Value] from [UserParameter] where [Name] = 'SyncExchangeCalendarEntriesTimeLimit' AND [UserID] = @UserID) as int), 1);
	set @calendarSyncPeriod = case when @calendarSyncPeriod = 0 then 1 when @calendarSyncPeriod = 1 then 7 else 30 end;
	set @date = getdate();
	set @date = dateadd(day, -@calendarSyncPeriod, @date);

	declare @EmployeeID TIdentifier;

	select @EmployeeID = [ID] from [dbo].[Employee] where [UserID] = @UserID;

	declare @SyncReminders int;

	select @SyncReminders = isnull(cast([Value] as int), 1) from [UserParameter] where [Name] = 'SyncExchangeNotifications' and [UserID] = @UserID;

	with [MeetingRequest] ([Class], [ID], [State], [FileAs], [OriginatorEmployeeID], [OriginatorName], [IsOriginator], [Email], [Priority], [Start], [End], [Location], [Comments], [Created], [Modified], [ExchangeID], [SyncTime], [RowVersion]) as
	(
		select 
			[M].[Class],
			[M].[ID],
			[M].[State],
			[M].[FileAs],
			[M].[OriginatorEmployeeID],
			[E].[FileAs] as [OrigitnatorName],
			(case when [M].[OriginatorEmployeeID] = @EmployeeID then 1 else 0 end),
			coalesce((select [Email] from [Email] where [BusinessCardClass] = [E].[Class] and [BusinessCardID] = [E].[ID] and [EmailTypeID] = 1),
				(select [Email] from [Email] where [BusinessCardClass] = [E].[Class] and [BusinessCardID] = [E].[ID] and [EmailTypeID] = 2),
				(select [Email] from [Email] where [BusinessCardClass] = [E].[Class] and [BusinessCardID] = [E].[ID] and [EmailTypeID] = 3)) as [Email],
			[M].[PriorityID],
			[M].[StartTime],
			dateadd(minute, [M].[Duration], [M].[StartTime]) as [EndTime],
			[M].[Location],
			[M].[Comments],
			[M].[Created],
			[M].[Modified],
			[L].[ExchangeID],
			[L].[SyncTime],
			cast([M].[Timestamp] as bigint) as [RowVersion]
		from 
			[dbo].[ExchangeDocumentSync] as [S] inner join [dbo].[MeetingRequest] as [M] 
				on ([S].[DocumentClass] = [M].[Class] and [S].[DocumentID] = [M].[ID])
			inner join [dbo].[Employee] as [E]
				on ([M].[OriginatorEmployeeID] = [E].[ID])
			left outer join [exch].[ExchangeLink] as [L]
				on ([M].[Class] = [L].[DocumentClass] and [M].[ID] = [L].[DocumentID] and [L].[UserID] = @UserID)
		where
			[S].[UserID] = @UserID 
		and 
			[M].[StartTime] >= @date
		and 
			[M].[State] in (2, 3, 4)
	),
	[Attendee] ([MeetingRequestID], [ID], [Name], [Email], [Required]) as
	(
		select
			[A].[MeetingRequestID],
			[A].[EmployeeID],
			[E].[FileAs],
			coalesce((select [Email] from [Email] where [BusinessCardClass] = [E].[Class] and [BusinessCardID] = [E].[ID] and [EmailTypeID] = 1),
				(select [Email] from [Email] where [BusinessCardClass] = [E].[Class] and [BusinessCardID] = [E].[ID] and [EmailTypeID] = 2),
				(select [Email] from [Email] where [BusinessCardClass] = [E].[Class] and [BusinessCardID] = [E].[ID] and [EmailTypeID] = 3)) as [Email],
			[A].[Required]
		from
			[dbo].[MeetingRequest] as [M] inner join [dbo].[Attendee] as [A]
				on ([M].[ID] = [A].[MeetingRequestID])
			inner join [dbo].[Employee] as [E]
				on ([A].[EmployeeID] = [E].[ID])
		where
			[M].[StartTime] >= @date
		and 
			[M].[State] in (2, 3, 4)

	),
	[Reminder] ([ID], [EventTime], [OriginalInterval], [NextInterval], [RowVersion]) as
	(
		select
			[R].[DocumentID],
			max([R].[EventTime]),
			max([UR].[OriginalInterval]),
			max([UR].[NextInterval]),
			max(cast([UR].[Timestamp] as bigint))
		from
			[dbo].[MeetingRequest] as [M] inner join [dbo].[Reminder] as [R] 
				on ([R].[DocumentClass] = [M].[Class] and [R].[DocumentID] = [M].[ID])
			inner join [UserReminder] as [UR]
				ON ([UR].[ReminderID] = [R].[ID] and [UR].[UserID] = @UserID)
		where
			[M].[StartTime] >= @date
		and 
			[M].[State] in (2, 3, 4)
		and
			[UR].[State] = 1
		and
			@SyncReminders = 1
		group by
			[R].[DocumentID]
		having
			count(*) = 1
	)
	select
		[MeetingRequest].[ID],
		[MeetingRequest].[State],
		[MeetingRequest].[FileAs],
		[MeetingRequest].[OriginatorEmployeeID],
		[MeetingRequest].[OriginatorName],
		[MeetingRequest].[IsOriginator],
		[MeetingRequest].[Email],
		[MeetingRequest].[Priority],
		[MeetingRequest].[Start],
		[MeetingRequest].[End],
		[MeetingRequest].[Location],
		[MeetingRequest].[Comments],
		[MeetingRequest].[Created],
		[MeetingRequest].[Modified],
		(case when [MeetingRequest].[RowVersion] > isnull([Reminder].[RowVersion], 0) then [MeetingRequest].[RowVersion] else [Reminder].[RowVersion] end) as [RowVersion],
		[MeetingRequest].[ExchangeID],
		[MeetingRequest].[SyncTime],
		(select 
			[EventTime],
			[NextInterval]
		from
			[Reminder]
		where
			[Reminder].[ID] = [MeetingRequest].[ID]
		for xml auto, type),
		(select	
			[Attendee].[ID],
			[Attendee].[Name],
			[Attendee].[Email],
			[Attendee].[Required]
		from	
			[Attendee] 
		where
			[Attendee].[MeetingRequestID] = [MeetingRequest].[ID]
		for xml auto, type)
	from
		[MeetingRequest] left outer join [Reminder]
			on ([MeetingRequest].[ID] = [Reminder].[ID])
	for xml auto, root('MeetingRequests');

	return 0;
end
GO


grant execute on [exch].[MeetingRequestBrowse] to [projectmateservice];
go
