﻿if exists (select * from dbo.sysobjects where id = object_id(N'[exch].[MeetingRequestGet]') and objectproperty(id, N'IsProcedure') = 1)
begin
	print 'Dropping procedure MeetingRequestGet'
	drop procedure [exch].[MeetingRequestGet]
end
go

print 'Creating procedure MeetingRequestGet'
go

create procedure [exch].[MeetingRequestGet] @UserID TIdentifier, @ID TIdentifier
with execute as 'pjmexchangesync'
as
begin
	set nocount on;


	declare @EmployeeID TIdentifier;

	select @EmployeeID = [ID] from [dbo].[Employee] where [UserID] = @UserID;

	with [MeetingRequest] ([Class], [ID], [State], [FileAs], [OriginatorEmployeeID], [OriginatorName], [Email], [Priority], [Start], [End], [Location], [Comments], [Created], [Modified], [ExchangeID], [SyncTime], [RowVersion]) as
	(
		select 
			[M].[Class],
			[M].[ID],
			[M].[State],
			[M].[FileAs],
			[M].[OriginatorEmployeeID],
			[E].[FileAs] as [OrigitnatorName],
			coalesce((select [Email] from [Email] where [BusinessCardClass] = [E].[Class] and [BusinessCardID] = [E].[ID] and [EmailTypeID] = 1),
				(select [Email] from [Email] where [BusinessCardClass] = [E].[Class] and [BusinessCardID] = [E].[ID] and [EmailTypeID] = 2),
				(select [Email] from [Email] where [BusinessCardClass] = [E].[Class] and [BusinessCardID] = [E].[ID] and [EmailTypeID] = 3)) as [Email],
			[M].[PriorityID],
			[M].[StartTime],
			dateadd(minute, [M].[Duration], [M].[StartTime]) as [EndTime],
			[M].[Location],
			[M].[Comments],
			[M].[Created],
			[M].[Modified],
			[L].[ExchangeID],
			[L].[SyncTime],
			cast([M].[Timestamp] as bigint) as [RowVersion]
		from 
			[dbo].[MeetingRequest] as [M] inner join [dbo].[Employee] as [E]
				on ([M].[OriginatorEmployeeID] = [E].[ID])
			left outer join [exch].[ExchangeLink] as [L]
				on ([M].[Class] = [L].[DocumentClass] and [M].[ID] = [L].[DocumentID] and [L].[UserID] = @UserID)
		where
			[M].[OriginatorEmployeeID] = @EmployeeID
		and 
			[M].[ID] = @ID
	),
	[Attendee] ([MeetingRequestID], [ID], [Name], [Email], [Required]) as
	(
		select
			[A].[MeetingRequestID],
			[A].[EmployeeID],
			[E].[FileAs],
			coalesce((select [Email] from [Email] where [BusinessCardClass] = [E].[Class] and [BusinessCardID] = [E].[ID] and [EmailTypeID] = 1),
				(select [Email] from [Email] where [BusinessCardClass] = [E].[Class] and [BusinessCardID] = [E].[ID] and [EmailTypeID] = 2),
				(select [Email] from [Email] where [BusinessCardClass] = [E].[Class] and [BusinessCardID] = [E].[ID] and [EmailTypeID] = 3)) as [Email],
			[A].[Required]
		from
			[dbo].[MeetingRequest] as [M] inner join [dbo].[Attendee] as [A]
				on ([M].[ID] = [A].[MeetingRequestID])
			inner join [dbo].[Employee] as [E]
				on ([A].[EmployeeID] = [E].[ID])
		where
			[M].[OriginatorEmployeeID] = @EmployeeID
		and 
			[M].[ID] = @ID
	),
	[Reminder] ([ID], [EventTime], [RowVersion]) as
	(
		select
			[R].[DocumentID],
			min([R].[EventTime]),
			max(cast([UR].[Timestamp] as bigint))
		from
			[dbo].[MeetingRequest] as [M] inner join [dbo].[Reminder] as [R] 
				on ([R].[DocumentClass] = [M].[Class] and [R].[DocumentID] = [M].[ID])
			inner join [UserReminder] as [UR]
				ON ([UR].[ReminderID] = [R].[ID] and [UR].[UserID] = @UserID)
		where
			[M].[OriginatorEmployeeID] = @EmployeeID
		and 
			[M].[ID] = @ID
		and
			[UR].[State] = 1
		and
			[R].[EventTime] > getdate()
		group by
			[R].[DocumentID]
	)
	select
		[MeetingRequest].[ID],
		[MeetingRequest].[State],
		[MeetingRequest].[FileAs],
		[MeetingRequest].[OriginatorEmployeeID],
		[MeetingRequest].[OriginatorName],
		[MeetingRequest].[Email],
		[MeetingRequest].[Priority],
		[MeetingRequest].[Start],
		[MeetingRequest].[End],
		[MeetingRequest].[Location],
		[MeetingRequest].[Comments],
		[MeetingRequest].[Created],
		[MeetingRequest].[Modified],
		(case when [MeetingRequest].[RowVersion] > isnull([Reminder].[RowVersion], 0) then [MeetingRequest].[RowVersion] else [Reminder].[RowVersion] end) as [RowVersion],
		[MeetingRequest].[ExchangeID],
		[MeetingRequest].[SyncTime],
		(select	
			[Attendee].[ID],
			[Attendee].[Name],
			[Attendee].[Email],
			[Attendee].[Required]
		from	
			[Attendee] 
		where
			[Attendee].[MeetingRequestID] = [MeetingRequest].[ID]
		for xml auto, type)
	from
		[MeetingRequest] left outer join [Reminder]
			on ([MeetingRequest].[ID] = [Reminder].[ID])
	for xml auto;

	return 0;
end
GO


grant execute on [exch].[MeetingRequestGet] to [projectmateservice];
go
