﻿if exists (select * from dbo.sysobjects where id = object_id(N'[exch].[MeetingRequestUpdate]') and objectproperty(id, N'IsProcedure') = 1)
begin
	print 'Dropping procedure MeetingRequestUpdate'
	drop procedure [exch].[MeetingRequestUpdate]
end
go

print 'Creating procedure MeetingRequestUpdate'
go

create procedure [exch].[MeetingRequestUpdate] @UserID TIdentifier, @XData xml
with execute as 'pjmexchangesync'
as
begin
	set nocount on;

	declare	@FileAs TName, @Start TDateTime, @End TDateTime, @Comments TNotes, @EventTime TDateTime, @NextInterval int, @EmployeeID TIdentifier, @CompanyID TIdentifier, @MeetingRequestClass TClass,
			@Location TName, @Email THref, @Priority TIdentifier, @MeetingRequestID TIdentifier, @result int,
			@OldStart TDateTime, @OldDuration TDateTime;
	
	set @MeetingRequestClass = dbo.adfGetClassByName('Pjm5.MeetingRequest')

	select
		@MeetingRequestID = T.C.value('@ID', 'TIdentifier'),
		@FileAs = T.C.value('@FileAs', 'TName'),
		@Start = T.C.value('@Start', 'TDateTime'),
		@End = T.C.value('@End', 'TDateTime'),
		@Priority = T.C.value('@Priority', 'TIdentifier'),
		@Email = T.C.value('@Email', 'THref'),
		@Location = T.C.value('@Location', 'TName'),
		@Comments = T.C.value('@Comments', 'TNotes'),
		@EventTime = T.C.value('(Reminder/@EventTime)[1]', 'TDateTime'),
		@NextInterval = T.C.value('(Reminder/@NextInterval)[1]', 'int')
	from
		@XData.nodes('MeetingRequest') T(C);

	if @FileAs is null
		set @FileAs = '(без темы)';

	declare @Duration TCount, @State TState;

	set @Duration = datediff(minute, @Start, @End);

	select
		@EmployeeID = [Employee].[ID],
		@CompanyID = [Employee].[CompanyID]
	from 
		[Employee] 
	where 
		[Employee].[UserID] = @UserID 
		and
		[Employee].[State] = 1;

	select @State = [State] from [MeetingRequest] where [ID] = @MeetingRequestID and [OriginatorEmployeeID] = @EmployeeID;

	if @State is null
	begin
		select cast(N'<MeetingRequest />' as xml);
		return -1;
	end

	if @State <> 2
	begin
		select cast(N'<MeetingRequest />' as xml);
		return -1;
	end

	declare @attendies table ([EmployeeID] int not null, [Required] bit not null, [ResponseType] varchar(32) null);

	insert into @attendies
		([EmployeeID], [Required], [ResponseType])
	select 
		[exch].[fnGetEmployeeByEmail](T.C.value('@Email', 'THref'), null),
		T.C.value('@Required', 'TBool'),
		(case isnull(T.C.value('@ResponseType', 'int'), 0) when 2 then 'Tentative' when 3 then 'Accept' when 4 then 'Decline' else null end)
	from
		@XData.nodes('MeetingRequest/Attendee') T(C)
	where
		[exch].[fnGetEmployeeByEmail](T.C.value('@Email', 'THref'), null) is not null;


	begin transaction;

	update [MeetingRequest]
	set
		[FileAs] = @FileAs,
		@OldStart = [StartTime],
		[StartTime] = @Start,
		@OldDuration = [Duration],
		[Duration] = @Duration,
		[PriorityID] = @Priority,
		[Location] = @Location,
		[Comments] = @Comments,
		[Modified] = DEFAULT,
		[ModifiedBy] = DEFAULT
	where
		[ID] = @MeetingRequestID;
			
	if @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	delete [AttendeeResponse] 
	where 
		[MeetingRequestID] = @MeetingRequestID
		and 
		[EmployeeID] not in (select [EmployeeID] from @attendies) 

	if @@error != 0
	begin
		rollback transaction
		return 1;
	end
		
	delete [Attendee] 
	where
		[MeetingRequestID] = @MeetingRequestID 
		and 
		[EmployeeID] not in (select [EmployeeID] from @attendies) 
	if @@error != 0
	begin
		rollback transaction
		return 1
	end
		
	insert into [Attendee] ([MeetingRequestID], [EmployeeID], [Required], [ResponseType], [Present])
	select
		@MeetingRequestID,
		[EmployeeID],
		[Required],
		[ResponseType],
		(case when [ResponseType] = 'Accept' then 1 else 0 end)
	from
		@attendies
	where
		[EmployeeID] not in (select [EmployeeID] from [Attendee] where [MeetingRequestID] = @MeetingRequestID)
		and 
		[EmployeeID] != @EmployeeID
	if @@error != 0
	begin
		rollback transaction
		return 1
	end
		
	update [Attendee]
	set
		[Required] = [E].[Required],
		[Present] = (case when [E].[ResponseType] = 'Accept' then 1 else 0 end),
		[ResponseType] = [E].[ResponseType]
	from
		[Attendee] inner join (select [EmployeeID], [Required], [ResponseType] from @attendies) as [E] 
			on ([Attendee].[EmployeeID] = [E].[EmployeeID] AND [Attendee].[MeetingRequestID] = @MeetingRequestID)
	where
		[Attendee].[ResponseType] is not null;
	if @@error != 0
	begin
		rollback transaction
		return 1
	end
		
	exec [exch].[ReminderUpdate] @UserID, @MeetingRequestClass, @MeetingRequestID, @EventTime, @NextInterval;

	if @result = 1 or @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	commit transaction;

	if @OldStart != @Start or @OldDuration != @Duration
	begin
		update [dbo].[MeetingRequest] set [SendUpdate] = 0 where [ID] = @MeetingRequestID;
		exec [dbo].[pjm5PostDocumentChangeNotificationEvent] 'MeetingRequestUpdated', 'Pjm5.MeetingRequest', @MeetingRequestID, null;
	end

	exec [exch].[MeetingRequestGet] @UserID, @MeetingRequestID;

	return 0;
end

go


grant execute on [exch].[MeetingRequestUpdate] to [projectmateservice];
go
