﻿if exists (select * from dbo.sysobjects where id = object_id(N'[exch].[TimeEntryBrowse]') and objectproperty(id, N'IsProcedure') = 1)
begin
	print 'Dropping procedure TimeEntryBrowse'
	drop procedure [exch].[TimeEntryBrowse]
end
go

print 'Creating procedure TimeEntryBrowse'
go

create procedure [exch].[TimeEntryBrowse] @UserID TIdentifier
with execute as 'pjmexchangesync'
as
begin
	set nocount on;
	
	declare @calendarSyncPeriod int, @date date;
	
	set @calendarSyncPeriod = isnull(cast((select [Value] from [UserParameter] where [Name] = 'SyncExchangeCalendarEntriesTimeLimit' AND [UserID] = @UserID) as int), 1);
	set @calendarSyncPeriod = case when @calendarSyncPeriod = 0 then 1 when @calendarSyncPeriod = 1 then 7 else 30 end;
	set @date = getdate();
	set @date = dateadd(day, -@calendarSyncPeriod, @date);

	declare @SyncReminders int;

	select @SyncReminders = isnull(cast([Value] as int), 1) from [UserParameter] where [Name] = 'SyncExchangeNotifications' and [UserID] = @UserID;


	with [TimeEntry] ([Class], [ID], [State], [FileAs], [Comments], [StartTime], [EndTime], [Duration], [RowVersion], [Created], [Modified], [ExchangeID], [SyncTime]) as
	(
		select
			[T].[Class],
			[T].[ID],
			[T].[State],
			[T].[FileAs],
			[T].[Comments],
			[T].[StartTime],
			dateadd(minute, [T].[Duration], [T].[StartTime]) as [EndTime],
			[T].[Duration],
			cast([T].[Timestamp] as bigint) as [RowVersion],
			[T].[Created],
			[T].[Modified],
			[L].[ExchangeID],
			[L].[SyncTime]
		from	
			[dbo].[ExchangeDocumentSync] as [S] inner join [dbo].[TimeEntry] as [T]
				on ([S].[DocumentClass] = [T].[Class] and [S].[DocumentID] = [T].[ID])
			 left outer join [exch].[ExchangeLink] as [L]
				on ([T].[Class] = [L].[DocumentClass] and [T].[ID] = [L].[DocumentID] and [L].[UserID] = @UserID)
		where
			[S].[UserID] = @UserID and [T].[StartTime] >= @date
	),
	[Reminder] ([ID], [EventTime], [OriginalInterval], [NextInterval], [RowVersion]) as
	(
		select
			[R].[DocumentID],
			max([R].[EventTime]),
			max([UR].[OriginalInterval]),
			max([UR].[NextInterval]),
			max(cast([UR].[Timestamp] as bigint))
		from
			[dbo].[ExchangeDocumentSync] as [S] inner join [dbo].[TimeEntry] as [T]
					on ([S].[DocumentClass] = [T].[Class] and [S].[DocumentID] = [T].[ID])
			inner join [dbo].[Reminder] as [R] 
				on ([R].[DocumentClass] = [T].[Class] and [R].[DocumentID] = [T].[ID])
			inner join [UserReminder] as [UR]
				ON ([UR].[ReminderID] = [R].[ID] and [UR].[UserID] = @UserID)
		where
			[S].[UserID] = @UserID
		and
			[UR].[State] = 1
		and
			@SyncReminders = 1
		group by
			[R].[DocumentID]
		having
			count(*) = 1
	)
	select
		[TimeEntry].[ID]			as [ID],
		[TimeEntry].[State]			as [State],
		[TimeEntry].[FileAs]		as [FileAs],
		[TimeEntry].[StartTime]		as [Start],
		[TimeEntry].[EndTime]		as [End],
		[TimeEntry].[Comments]		as [Comments],
		[TimeEntry].[Created]		as [Created],
		[TimeEntry].[Modified]		as [Modified],
		[TimeEntry].[ExchangeID]	as [ExchangeID],
		[TimeEntry].[SyncTime]		as [SyncTime],
		(case when [TimeEntry].[RowVersion] > isnull([R].[RowVersion], 0) then [TimeEntry].[RowVersion] else [R].[RowVersion] end)
									as [RowVersion],
		(select
			[EventTime],
			[NextInterval]
		from
			[Reminder]
		where
			[Reminder].[ID] = [TimeEntry].[ID]
		for xml auto, type)
	from	
		[TimeEntry]	left outer join [Reminder] as [R]
			on ([TimeEntry].[ID] = [R].[ID])
	for xml auto, root('TimeEntries');
	
	return 0;
end
go


grant execute on [exch].[TimeEntryBrowse] to [projectmateservice];
go
