﻿if exists (select * from dbo.sysobjects where id = object_id(N'[exch].[TimeEntryCreate]') and objectproperty(id, N'IsProcedure') = 1)
begin
	print 'Dropping procedure TimeEntryCreate'
	drop procedure [exch].[TimeEntryCreate]
end
go

print 'Creating procedure TimeEntryCreate'
go

create procedure [exch].[TimeEntryCreate] @UserID TIdentifier, @XData xml
with execute as 'pjmexchangesync'
as
begin
	set nocount on;

	declare	@FileAs TName, @Start TDateTime, @End TDateTime, @Comments TNotes, @EventTime TDateTime, @NextInterval int, @EmployeeID TIdentifier, @DivisionID TIdentifier, @TimeEntryClass TClass,
			@TimeEntryID TIdentifier, @result int;
	
	set @TimeEntryClass = dbo.adfGetClassByName('Pjm5.TimeEntry')

	select
		@FileAs = T.C.value('@FileAs', 'TName'),
		@Start = T.C.value('@Start', 'TDateTime'),
		@End = T.C.value('@End', 'TDateTime'),
		@Comments = T.C.value('@Comments', 'TNotes'),
		@EventTime = T.C.value('(Reminder/@EventTime)[1]', 'TDateTime'),
		@NextInterval = T.C.value('(Reminder/@NextInterval)[1]', 'int')
	from
		@XData.nodes('TimeEntry') T(C);

	select
		@EmployeeID = [Employee].[ID],
		@DivisionID = [Employee].[DivisionID]
	from 
		[Employee] 
	where 
		[Employee].[UserID] = @UserID 
		AND 
		[Employee].[State] = 1;
	
	if @FileAs is null
		set @FileAs = '(без темы)';

	--Параметры округления длительности записи

	declare @RoundInterval int, @RoundingMode int, @var TVariant, @RoundedDuration TCount, @Duration TCount, @CurrencyCode varchar(3), @VATRate	TPercent;

	set @Duration = datediff(minute, @Start, @End);

	exec adfParameterGet @Name='RoundInterval', @Group='Pjm5', @Value = @var output
	set @RoundInterval = CAST(@var as int)

	exec adfParameterGet @Name='RoundingMode', @Group='Pjm5', @Value = @var output
	set @RoundingMode = CAST(@var as int)

	exec adfParameterGet 'NationalCurrency', 'CommonBusiness', @var output;
	set @CurrencyCode = CAST(@var AS varchar(3));

	set @RoundedDuration = dbo.fnPjm5RoundedDuration(@Duration, @RoundInterval, @RoundingMode);

	set @VATRate = dbo.fnPjm5GetVATRate();

	begin transaction;

	insert into [TimeEntry]
		([Flag], [State], [FileAs], [ActivityTypeID], [EmployeeID], [AssignmentID], [ProjectID], [DocumentClass], [DocumentID], [TaskID], 
		[StartTime], [Duration], [RoundedDuration], [Billable], 
		[Overtime], [Rate], [CurrencyCode], [VATRate], [Color],
		[Comments], [DivisionID])
	values
		(0, 1, @FileAs, null, @EmployeeID, null, null, null, null, null, 
		@Start, @Duration, @RoundedDuration, 0, 
		0, 0, @CurrencyCode, @VATRate, null,
		@Comments, @DivisionID);
			
	if @@error != 0
	begin
		rollback transaction;
		return 1;
	end
	set @TimeEntryID = scope_identity();

	exec [exch].[ReminderUpdate] @UserID, @TimeEntryClass, @TimeEntryID, @EventTime, @NextInterval;
	if @result = 1 or @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	commit transaction;

	exec [exch].[TimeEntryGet] @UserID, @TimeEntryID;

	return 0;
end

go


grant execute on [exch].[TimeEntryCreate] to [projectmateservice];
go
