IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnPjm7GetAvailableProjectsForCalculationProjectSelectorDialog]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnPjm7GetAvailableProjectsForCalculationProjectSelectorDialog'
		DROP FUNCTION [dbo].[fnPjm7GetAvailableProjectsForCalculationProjectSelectorDialog]
	END

GO

PRINT 'Creating function fnPjm7GetAvailableProjectsForCalculationProjectSelectorDialog'
GO

/******************************************************************************
**		File:	fnPjm7GetAvailableProjectsForCalculationProjectSelectorDialog.sql
**		Name: 	fnPjm7GetAvailableProjectsForCalculationProjectSelectorDialog
**		Desc:	      , 
**				      
**			
**
**
*******************************************************************************
**		Date:		Author:		Description:
**		-----		-------		-------------
**		15.03.13	SOV			     
**		07.04.13	SOV			       (@ProjectState = 0)
*******************************************************************************/
CREATE FUNCTION fnPjm7GetAvailableProjectsForCalculationProjectSelectorDialog (
	@EmployeeID TIdentifier,
	@OnlyActive bit,
	@ContractOnly bit,
	@OnlyProjectMember bit,
	@ProjectState int = 2,
	@ProjectSelector bit = 0,
	@SupportsRequestManagement bit
)
RETURNS @Projects TABLE ([ID] INT PRIMARY KEY)
AS 
BEGIN

	DECLARE @CurrentEmployeeID 	TIdentifier, 
		@UserID 		TIdentifier

	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @UserID = dbo.adfGetCurrentUserID()

	IF @EmployeeID IS NULL OR @EmployeeID <= 0
		SET @EmployeeID = @CurrentEmployeeID

	DECLARE
		@ViewAllProjects TBool,
		@ExpenseSecretary TBool,
		@ManageAllCalculations TBool,
		@ManageCalculates TBool,
		@ViewFinance TBool,
		@ViewAllFinance TBool
		

	SET @ViewAllProjects = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects')) 
	SET @ManageAllCalculations = dbo.adfHasAccessRight(dbo.adfGetRightID('ManageAllCalculations'))
	SET @ManageCalculates = dbo.adfHasAccessRight(dbo.adfGetRightID('ManageCalculates'))
	SET @ViewFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance'))
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))


--	   
	INSERT INTO @Projects ([ID])
	SELECT [Project].[ID]
	FROM   [Project]
	WHERE
		(
			[Project].[State] = 2 OR (@OnlyActive = 0 AND [Project].[State] = 4)
		) 
		AND
		(
			(@ViewAllProjects = 1 AND @ManageAllCalculations = 1 AND @ViewAllFinance = 1)				
			OR
			(
				@OnlyProjectMember = 0 AND
				(
					dbo.fnPjm7IsFinanceManager([Project].[ID], @EmployeeID) = 1
					OR 
					dbo.fnPjm5IsProjectManager([Project].[ID], @EmployeeID) = 1
				)
			)
			OR
				 ([Project].[ID] IN (
					SELECT
						[Assignment].[ProjectID]
					FROM
						[Assignment] 
					WHERE 	
						[Assignment].[ID] IN (
							SELECT [AssignmentEntry].[AssignmentID]
							FROM   [AssignmentEntry]
							WHERE  
								[AssignmentEntry].[EmployeeID] = @EmployeeID 
						) AND
					   [Assignment].[State] = 1 AND 
					   (
							(@ManageCalculates = 1 OR @ManageAllCalculations = 1)
							AND 
							((@ViewFinance = 1 AND [FinanceManagement] = 1) OR @ViewAllFinance = 1)
					   )
					)
				)
		)
		AND
		(
			@ContractOnly = 0 OR [Project].[ProjectTypeID] = 1
		) 
		AND
		(
			@ProjectState = 0 
			OR
			@ProjectState = 2 
			OR
			(@ProjectState = 1 
			  AND 
			 ([Project].[ID] IN (
				SELECT [vas].[ProjectID]
				FROM	vwAssignment AS vas
				WHERE	[vas].[EmployeeID] = @EmployeeID 
				AND     [vas].[State] = 1)
			 )
			)	 
			OR
			@ProjectState = 3 AND [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
		) 
		AND
		(
			@ProjectSelector = 0 
			OR
			(@SupportsRequestManagement = 0 AND 
				EXISTS (SELECT * FROM [CalendarProject] WHERE [UserID] = @UserID AND [ProjectID] = [Project].[ID])
			)
			OR
			(@SupportsRequestManagement = 1 AND 
				EXISTS (SELECT * FROM [IssueProject] WHERE [UserID] = @UserID AND [ProjectID] = [Project].[ID])
			)
		)
		AND
		(
			@SupportsRequestManagement = 0
			OR
			(@SupportsRequestManagement = 1 AND [SupportsRequestManagement] = 1)
		)

	RETURN
END
GO