IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnpjm7BillableHourGet]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnpjm7BillableHourGet'
		DROP FUNCTION [dbo].[fnpjm7BillableHourGet]
	END

GO

PRINT 'Creating function fnpjm7BillableHourGet'
GO
/******************************************************************************
**		File: 
**		Name: fnpjm7BillableHourGet
**		Desc:          
**		    "/"
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Sergey Pelevin
**		Date: 04.03.12
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		05.03.13	SAP				    " "
**		12.03.13	SAP				    " "
**		22.03.13	SAP				    " "
**									( .   
**									   , 
**									  ViewFinance, ViewAllFinance)
**		28.03.13	SAP				    " "
**									(  " ")
**		26.04.13	SOV				    " "
**		06.09.13	SOV				      
*******************************************************************************/
CREATE FUNCTION fnpjm7BillableHourGet(@ProjectID int, @BillableDuration decimal(18,2), @BillableHoursStyle int, @IsOwnEntry bit)
RETURNS decimal(18,2)
AS
BEGIN
	DECLARE
		@CurrentEmployeeID int,
		@CanView bit = 0,
				
        @IsManager bit = 0, 
        @IsManagerAssistant bit = 0,
        @IsApprover bit = 0,
        @IsAdministrator bit = 0,
        @IsProjectFinanceManager bit = 0,
        @IsParticipantWithFinanceManagement bit = 0,
        @IsProjectParticipant bit = 0,
        
        @ViewFinance bit,
        @ViewAllFinance bit,
        @CanBeManagerAssistant bit,
		@ManageProject bit,

		@RetVal decimal(18,2),
		@TimeEntryIsBillable bit
		
		-- 
		SET @CurrentEmployeeID = [dbo].[adfGetCurrentEmployeeID]()
		SET @IsProjectParticipant = [dbo].[fnPjm5IsProjectMember](@ProjectID, @CurrentEmployeeID)

		--
		SELECT
			@ViewFinance = [dbo].[adfHasAccessRightByName]('ViewFinance'),
			@ViewAllFinance = [dbo].[adfHasAccessRightByName]('ViewAllFinance'),
			@CanBeManagerAssistant = [dbo].[adfHasAccessRightByName]('CanBeProjectManagerAssistant'),
			@ManageProject = [dbo].[adfHasAccessRightByName]('ManageProject')		

		SELECT
			@IsProjectFinanceManager = 
				CASE [FinanceManagerEmployeeID] 
					WHEN @CurrentEmployeeID THEN 1
					ELSE 0
				END,
			@IsManager = 
				CASE [ProjectManagerEmployeeID]
					WHEN @CurrentEmployeeID THEN 1
					ELSE 0
				END,
			@IsManagerAssistant = 
				CASE [ManagerAssistantEmployeeID]
					WHEN @CurrentEmployeeID THEN 1
					ELSE 0
				END
		FROM
			[Project]
		WHERE
			[Project].[ID] = @ProjectID
			
		IF @IsProjectParticipant = 1
		BEGIN
			--  
			SELECT
				@IsApprover = [Assignment].[Approver],
				@IsAdministrator = [Assignment].[Administrator],
				@IsParticipantWithFinanceManagement = [Assignment].[FinanceManagement]
			FROM
				[Project]
				INNER JOIN [Assignment]
					ON [Project].[ID] = [Assignment].[ProjectID] AND [Assignment].[State] = 1
				INNER JOIN [AssignmentEntry]
					ON [Assignment].[ID] = [AssignmentEntry].[AssignmentID] 
						AND [AssignmentEntry].[EmployeeID] = @CurrentEmployeeID
			WHERE
				[Project].[ID] = @ProjectID
		END			
						
		/*
		RETURN -60.0 -   -60.0: 
			 xsd-  BillableDurationHour,    ,
			    (CONVERT([Billable], 'System.Int32')*[BillableDuration] )/ 60.0.
			 ,  -60.0       -1.0,  
			  ,     ****.
		*/
		
        SET @CanView = 
			CASE
				-- 
				WHEN @ManageProject = 1 AND @IsManager = 1 THEN 1
				--              
				WHEN @IsApprover = 1 OR @IsAdministrator = 1 THEN 1
				--  
				WHEN @IsManagerAssistant = 1 AND @CanBeManagerAssistant = 1 THEN 1
				--   ViewAllFinance
				WHEN @ViewAllFinance = 1 THEN 1
				--   viewFinance        
				--   
				WHEN (@IsParticipantWithFinanceManagement = 1 OR @IsProjectFinanceManager = 1) AND
					@ViewFinance = 1 THEN 1
				ELSE 0
			END                           
		
		IF @CanView = 0 AND (@BillableHoursStyle = 1 OR @BillableHoursStyle = 2)
		BEGIN
			SET @CanView =
				CASE
					--  ( )
					WHEN @IsProjectParticipant = 1 AND @IsOwnEntry = 1 THEN 1	
				ELSE 0
				END            
		END		
		
		IF @CanView = 1
			RETURN @BillableDuration
		
		RETURN -60.0
END
GO

GRANT EXEC ON fnpjm7BillableHourGet TO PUBLIC
GO


