IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnPjm7GetShortPeriodName]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnPjm7GetShortPeriodName'
		DROP FUNCTION [dbo].[fnPjm7GetShortPeriodName]
	END

GO

PRINT 'Creating function fnPjm7GetShortPeriodName'
GO
/******************************************************************************
**		File: 
**		Name: fnPjm7GetShortPeriodName
**		Desc:     : 
**		01.02.2010 - 01.03.2010 --> . 2010	
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Sergey Pelevin
**		Date: 22.03.13
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE FUNCTION fnPjm7GetShortPeriodName(@PeriodStart TDateTime, @LangCode TCode3 = NULL, @PeriodEnd TDateTime = NULL)
RETURNS varchar(50)
AS
BEGIN
	DECLARE 
		@res varchar(50),		
		@StartMonthName varchar(16),
		@StartMonthNumber int,
		@StartYear varchar(16)
		
	IF(@LangCode IS NULL OR @LangCode NOT IN ('en', 'ru'))
		SET @LangCode = 'ru'	-- set to russian language as default
	
	SET @StartYear = DATENAME(year,@PeriodStart)
	SET @StartMonthNumber = DATEPART(month,@PeriodStart)
	
	IF @LangCode = 'ru'
	SET @StartMonthName = 
		CASE @StartMonthNumber
			WHEN 1 THEN ' '
			WHEN 2 THEN ' '
			WHEN 3 THEN ' '
			WHEN 4 THEN ' '
			WHEN 5 THEN ' '
			WHEN 6 THEN ' '
			WHEN 7 THEN ' '
			WHEN 8 THEN ' '
			WHEN 9 THEN ' '
			WHEN 10 THEN ' '
			WHEN 11 THEN ' '
			WHEN 12 THEN ' '
		END
	
	IF @LangCode = 'en'
	SET @StartMonthName = 
		CASE @StartMonthNumber
			WHEN 1 THEN 'Jan '
			WHEN 2 THEN 'Feb '
			WHEN 3 THEN 'Mar '
			WHEN 4 THEN 'Apr '
			WHEN 5 THEN 'May '
			WHEN 6 THEN 'Jun '
			WHEN 7 THEN 'Jul '
			WHEN 8 THEN 'Aug '
			WHEN 9 THEN 'Sep '
			WHEN 10 THEN 'Oct '
			WHEN 11 THEN 'Nov '
			WHEN 12 THEN 'Dec '
		END
	
	IF @PeriodEnd IS NULL	
		SET @res = @StartMonthName-- + @StartYear
	ELSE
	BEGIN
		DECLARE
			@EndMonthName varchar(16),
			@EndMonthNumber int,
			@EndYear varchar(16)
		
		SET @EndYear = DATENAME(year,@PeriodEnd)
		SET @EndMonthNumber = DATEPART(month,@PeriodEnd)
		
		IF @LangCode = 'ru'
		SET @EndMonthName = 
			CASE @EndMonthNumber
				WHEN 1 THEN ' '
				WHEN 2 THEN ' '
				WHEN 3 THEN ' '
				WHEN 4 THEN ' '
				WHEN 5 THEN ' '
				WHEN 6 THEN ' '
				WHEN 7 THEN ' '
				WHEN 8 THEN ' '
				WHEN 9 THEN ' '
				WHEN 10 THEN ' '
				WHEN 11 THEN ' '
				WHEN 12 THEN ' '
			END
		
		IF @LangCode = 'en'
		SET @EndMonthName = 
			CASE @EndMonthNumber
				WHEN 1 THEN 'Jan '
				WHEN 2 THEN 'Feb '
				WHEN 3 THEN 'Mar '
				WHEN 4 THEN 'Apr '
				WHEN 5 THEN 'May '
				WHEN 6 THEN 'Jun '
				WHEN 7 THEN 'Jul '
				WHEN 8 THEN 'Aug '
				WHEN 9 THEN 'Sep '
				WHEN 10 THEN 'Oct '
				WHEN 11 THEN 'Nov '
				WHEN 12 THEN 'Dec '
			END
		
		SET @res = @StartMonthName + @StartYear + ' - ' + @EndMonthName + @EndYear
	END


	RETURN @res
END
GO

GRANT EXEC ON fnPjm7GetShortPeriodName TO PUBLIC
GO
 