IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnReportGetExpense]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnReportGetExpense'
		DROP FUNCTION [dbo].[fnReportGetExpense]
	END
GO

PRINT 'Creating function fnReportGetExpense'
GO

/******************************************************************************
**		File: fnReportGetExpense.sql
**		Name: fnReportGetExpense
**
**              
**		Return values:
**
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**		@PeriodStart
**		   
**		@PeriodEnd
**		   
**		@CurrencySelector
**		 
**		 0 - 
**		 1 - 
**		@ProjectXML
**		XML c  
**		
**		Auth: MAN
**		Date: 26/08/2010 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		26.08.2010	MAN				First Version
*******************************************************************************/
CREATE FUNCTION dbo.fnReportGetExpense
(
	@PeriodStart		TDateTime,
	@PeriodEnd			TDateTime,
	@CurrencyCode		TCode3,
	@ProjectXML			XML
)
RETURNS @ResultExpense TABLE 
(
		ProjectID		Tidentifier,
		ExpenseMarked	TAmount,	--  : 
		ExpenseBillable TAmount,	--  :  
		ExpenseSold		TAmount		--  :  
)
AS
BEGIN
	
	INSERT INTO @ResultExpense
	(
		[ProjectID],
		[ExpenseMarked],	
		[ExpenseBillable],
		[ExpenseSold]
	)
	SELECT
		[Expense].[ProjectID] as [ProjectID],
		SUM(
			CASE
				WHEN [Expense].[State] in ( 1, 2, 3, 5, 6 ) --  4 (  )
					THEN 
						[Expense].[TotalWithVATPC]
						 *
						dbo.pjm6fnCurrencyGetRate
						(
							[Expense].[ToCurrencyCode],
							[Expense].[Date], 
							@CurrencyCode
						)
					ELSE 0
			END
			) AS [ExpenseMarked],
		SUM(
			CASE
				WHEN 
					[Expense].[Billable] = 1 --  " "
					AND
					[Expense].[State] in ( 3, 6 ) --   					
					THEN 
						[Expense].[TotalWithVATPC] *
						dbo.pjm6fnCurrencyGetRate
						 (
							[Expense].[ToCurrencyCode],
							[Expense].[Date], 
							@CurrencyCode
						)
					ELSE 0
			END
			) AS [ExpenseBillable],
		SUM(
			CASE
				WHEN 
					[Expense].[State] in ( 6 ) -- 
					THEN 
						[Expense].[TotalWithVATPC] *
						dbo.pjm6fnCurrencyGetRate
						 (
							[Expense].[ToCurrencyCode],
							[Expense].[Date], 
							@CurrencyCode
						)
					ELSE 0
			END
			) AS [ExpenseSold] 
	FROM 
		[Expense]
	WHERE
		[Expense].[Date] >= @PeriodStart 
		AND 
		[Expense].[Date] < @PeriodEnd --  
		AND
		[Expense].[ProjectID] IN 
		(
			SELECT
				ROW.value('@ProjectID','TIdentifier') as [ProjectID]
			FROM
				@ProjectXML.nodes('/row') AS ROW(ROW)
		)
GROUP BY 
	[Expense].[ProjectID]
			
RETURN
END
GO