IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'TaskBookingInfoGet')
	BEGIN
		PRINT 'Dropping Procedure TaskBookingInfoGet'
		DROP  Procedure  TaskBookingInfoGet
	END

GO

PRINT 'Creating Procedure TaskBookingInfoGet'
GO
/******************************************************************************
**		File: 
**		Name: TaskBookingInfoGet
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure TaskBookingInfoGet
	@TaskID TIdentifier,
	@ProjectID TIdentifier
AS
	SET NOCOUNT ON
	
	SELECT
		[ID],
		[State],
		[ProjectID],
		[StartDate],
		[DueDate],
		[Duration]
	FROM
		[Task]
	WHERE 
		[ID] = @TaskID

	SELECT
		[AssignmentID],
		[TaskAssignment].[State],
		[Work],
		[Units],
		[MsAvailable],
		CASE WHEN [Task].[MsTaskID] IS NULL THEN 0 ELSE 1 END AS [FromMsProject],
		[RemainingWork],
		ISNULL([RemainingOvertimeWork],0) as [RemainingOvertimeWork],
		ISNULL((SELECT SUM([BusyEntry].[ActualWork] + ISNULL([BusyEntry].[ActualOvertimeWork], 0)) FROM [BusyEntry] 
			WHERE [BusyEntry].[TaskID] = [TaskAssignment].[TaskID] 
				AND [BusyEntry].[AssignmentID] = [TaskAssignment].[AssignmentID]
				) / 60.0, 0)		as [ActualWork]
	FROM
		[TaskAssignment]
		INNER JOIN [Task]
			ON [Task].[ID] = [TaskAssignment].[TaskID]
	WHERE
		[TaskID] = @TaskID

	SELECT
		[AssignmentID],
		[Date],
		[Planned],
		[Canceled],
		[Committed]
	FROM
		[BusyEntry]
	WHERE
		[TaskID] = @TaskID

	DECLARE @WorkTime INT, @Param TVariant, @result INT, @WorkingDays INT
	
	EXEC @result = adfParameterGet 'WorkTime', 'Pjm5', @Param OUTPUT
	SET @WorkTime = CAST(@Param as INT)

	EXEC @result = adfParameterGet 'WorkDaysOfWeek', 'Pjm5', @Param OUTPUT
	SET @WorkingDays = CAST(@Param as INT)	
	
	SELECT
		@WorkTime as [WorkTime],
		@WorkingDays as [WorkingDays]

	SELECT
		[Date],
		[NonWorkingTime],
		[Recurrent]
	FROM
		[Calendar]
	

	RETURN 0
GO

GRANT EXEC ON TaskBookingInfoGet TO PUBLIC
GO
