IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6BudgetCalcRecurrenceInsert]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6BudgetCalcRecurrenceInsert'
		DROP PROCEDURE [dbo].[pjm6BudgetCalcRecurrenceInsert]
	END
GO

PRINT 'Creating procedure pjm6BudgetCalcRecurrenceInsert'
GO

CREATE PROCEDURE pjm6BudgetCalcRecurrenceInsert
	@BudgetID TIdentifier,
	@StartDate TDate,
	@EndDate TDate = NULL,
	@Occurrences TCount = NULL,
	@RecurrenceType TIdentifier,
	@Interval TIdentifier,
	@DayOfWeekMask TIdentifier,
	@Instance TIdentifier,
	@MonthOfYear TIdentifier,
	@DayOfMonth TIdentifier,
	@DayTransferRule TIdentifier,
	@RenurnValue TBool = NULL	
AS
	SET NOCOUNT ON

	IF((SELECT [State] FROM [Budget] WHERE [ID] = @BudgetID) = 3)
	BEGIN
		RAISERROR('#budgetIsClosed', 18, -1)
		RETURN 1
	END

	INSERT INTO [AssistantRecurrencePattern]
	(
		[StartDate], [EndDate], [Occurrences], [RecurrenceType], [Interval], [DayOfWeekMask],
		[Instance], [MonthOfYear], [DayOfMonth], [DayTransferRule]
	)
	SELECT
		@StartDate, @EndDate, @Occurrences, @RecurrenceType, @Interval, @DayOfWeekMask,
		@Instance, @MonthOfYear, @DayOfMonth, @DayTransferRule	
			
	DECLARE @Scope TIdentifier
	SET @Scope = SCOPE_IDENTITY()
			
	UPDATE [Budget] 
	SET [Budget].[CalculateBudgetPatternID] = @Scope
	WHERE [Budget].[ID] = @BudgetID

	IF @RenurnValue IS NULL
		SELECT SCOPE_IDENTITY() 

	RETURN 0
GO

GRANT EXECUTE ON pjm6BudgetCalcRecurrenceInsert TO PUBLIC
GO




IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6BudgetCalcRecurrenceUpdate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6BudgetCalcRecurrenceUpdate'
		DROP PROCEDURE [dbo].[pjm6BudgetCalcRecurrenceUpdate]
	END
GO

PRINT 'Creating procedure pjm6BudgetCalcRecurrenceUpdate'
GO

CREATE PROCEDURE pjm6BudgetCalcRecurrenceUpdate
	@ID TIdentifier,
	@BudgetID TIdentifier,
	@StartDate TDate,
	@EndDate TDate = NULL,
	@Occurrences TCount = NULL,
	@RecurrenceType TIdentifier,
	@Interval TIdentifier,
	@DayOfWeekMask TIdentifier,
	@Instance TIdentifier,
	@MonthOfYear TIdentifier,
	@DayOfMonth TIdentifier,
	@DayTransferRule TIdentifier	
AS
	SET NOCOUNT ON

	IF((SELECT [State] FROM [Budget] WHERE [ID] = @BudgetID) = 3)
	BEGIN
		RAISERROR('#budgetIsClosed', 18, -1)
		RETURN 1
	END

	UPDATE
		[AssistantRecurrencePattern]
	SET
		[StartDate] = @StartDate,
		[EndDate] = @EndDate,
		[Occurrences] = @Occurrences,
		[RecurrenceType] = @RecurrenceType,
		[Interval] = @Interval,	
		[DayOfWeekMask] = @DayOfWeekMask,
		[Instance] = @Instance, 
		[MonthOfYear] = @MonthOfYear, 
		[DayOfMonth] = @DayOfMonth, 
		[DayTransferRule] = @DayTransferRule
	WHERE [AssistantRecurrencePattern].[ID] = @ID 

	RETURN 0
GO

GRANT EXECUTE ON pjm6BudgetCalcRecurrenceUpdate TO PUBLIC
GO




IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6BudgetCalcRecurrenceDelete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6BudgetCalcRecurrenceDelete'
		DROP PROCEDURE [dbo].[pjm6BudgetCalcRecurrenceDelete]
	END
GO

PRINT 'Creating procedure pjm6BudgetCalcRecurrenceDelete'
GO

CREATE PROCEDURE pjm6BudgetCalcRecurrenceDelete
	@ID TIdentifier,
	@BudgetID TIdentifier
AS
	SET NOCOUNT ON

	IF((SELECT [State] FROM [Budget] WHERE [ID] = @BudgetID) = 3)
	BEGIN
		RAISERROR('#budgetIsClosed', 18, -1)
		RETURN 1
	END

	UPDATE [Budget] 
	SET [Budget].[CalculateBudgetPatternID] = NULL
	WHERE [Budget].[ID] = @BudgetID
	
	DELETE FROM [AssistantRecurrencePattern] WHERE [AssistantRecurrencePattern].[ID] = @ID
	
	IF @@ERROR != 0
		RETURN 1

	RETURN 0
GO

GRANT EXECUTE ON pjm6BudgetCalcRecurrenceDelete TO PUBLIC
GO




IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6BudgetCalcRecurrenceGet]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6BudgetCalcRecurrenceGet'
		DROP PROCEDURE [dbo].[pjm6BudgetCalcRecurrenceGet]
	END
GO

PRINT 'Creating procedure pjm6BudgetCalcRecurrenceGet'
GO

CREATE PROCEDURE pjm6BudgetCalcRecurrenceGet
	@ID TIdentifier
AS
	SET NOCOUNT ON
	
	SELECT
		[StartDate],
		[EndDate],
		[Occurrences],
		[RecurrenceType],
		[Interval],
		[DayOfWeekMask],
		[Instance],
		[MonthOfYear],
		[DayOfMonth],
		[DayTransferRule]
	FROM 
		[AssistantRecurrencePattern]
	WHERE
		[AssistantRecurrencePattern].[ID] = @ID

	IF @@ERROR != 0
		RETURN 1

	RETURN 0
GO

GRANT EXECUTE ON pjm6BudgetCalcRecurrenceGet TO PUBLIC
GO


 