﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6BudgetCalculateActualTotals]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6BudgetCalculateActualTotals'
		DROP PROCEDURE [dbo].[pjm6BudgetCalculateActualTotals]
	END
GO

PRINT 'Creating procedure pjm6BudgetCalculateActualTotals'
GO

/******************************************************************************
**		File: BudgetCalculateActualTotals.sql
**		Name: pjm6BudgetCalculateActualTotals
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Anton.Paramonov
**		Date: 21/01/2011 17:00:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		15.03.13	MAB				Добавление паоказателей плановых закупок
*******************************************************************************/
CREATE PROCEDURE [pjm6BudgetCalculateActualTotals]
	@ID				TIdentifier,
	@AutoExecute TBool = 0								--Признак автоматического вызова процедуры
AS
	DECLARE
		@BudgetTypeID			TIdentifier,
		@BudgetStartDate		TDate,
		@BudgetEndDate			Tdate,
		@BudgetCurrencyCode		TCode3,
		@BudgetTimeEntryActualTotalsAccount	TIdentifier,
		@DocumentID				TIdentifier,
		@BreakCalculation		TBool,					--Код ошибки в процессе расчета бюджета
		@CalculateWithSub		TBool,					--Признак того, что для дерева проектов возможен расчет с учетом вложенности
		@ProjectHasBudget		TBool,		
		@PlannedManHour							TAmount,
		@ActualManHour							TAmount, 
		@TotalPCPlannedManHour					TMoney, 
		@TotalWithVATPCPlannedManHour			TMoney, 
		@TotalPCActualManHour					TMoney, 
		@TotalWithVATPCActualManHour			TMoney,  
		@TotalPCPlannedExpense					TMoney, 
		@TotalWithVATPCPlannedExpense			TMoney,
		@VATPCPlanPurchase						TMoney,  
		@TotalPCPlanPurchase					TMoney, 
		@TotalPCActualExpense					TMoney, 
		@TotalWithVATPCActualExpense			TMoney,
		@TotalPCWDPlannedManHour				TMoney, 
		@TotalWithVATPCWDPlannedManHour			TMoney, 
		@TotalPCWDActualManHour					TMoney, 
		@TotalWithVATPCWDActualManHour			TMoney,  
		@TotalPCWDPlannedExpense				TMoney, 
		@TotalWithVATPCWDPlannedExpense			TMoney, 
		@TotalPCWDActualExpense					TMoney, 
		@TotalWithVATPCWDActualExpense			TMoney,			

		@WarningFlag			TIdentifier,			--Идентификатор сообщения об ошибке для записи в бюджет
		@rv						int
	
	IF dbo.fnPjm6CanEditBudget(@ID) != 1
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END		

	SELECT
		@BudgetTypeID						= [BudgetTypeID],		
		@BudgetStartDate					= [StartDate],	
		@BudgetEndDate						= [EndDate],
		@DocumentID							= [DocumentID],
		@BudgetCurrencyCode					= [CurrencyCode],
		@BudgetTimeEntryActualTotalsAccount = [TimeEntryActualTotalsAccount]
	FROM
		[Budget]
	WHERE
		[Budget].[ID] = @ID

	BEGIN TRANSACTION

	EXEC @BreakCalculation = pjm6BudgetCalculateActualTotalsForSubProjects @DocumentID, @BudgetTypeID, 
		@BudgetStartDate, @BudgetEndDate, @BudgetCurrencyCode, @BudgetTimeEntryActualTotalsAccount, @CalculateWithSub = @CalculateWithSub OUTPUT, 
		@ProjectHasBudget = @ProjectHasBudget OUTPUT,
		@PlannedManHourWithSub					= @PlannedManHour OUTPUT,								
		@ActualManHourWithSub					= @ActualManHour OUTPUT,													
		@TotalPCPlannedManHourWithSub			= @TotalPCPlannedManHour OUTPUT,						
		@TotalWithVATPCPlannedManHourWithSub	= @TotalWithVATPCPlannedManHour	OUTPUT,										
		@TotalPCActualManHourWithSub			= @TotalPCActualManHour OUTPUT,						
		@TotalWithVATPCActualManHourWithSub		= @TotalWithVATPCActualManHour OUTPUT,										
		@TotalPCPlannedExpenseWithSub			= @TotalPCPlannedExpense OUTPUT,						
		@TotalWithVATPCPlannedExpenseWithSub	= @TotalWithVATPCPlannedExpense	OUTPUT,	
		@VATPCPlanPurchaseWithSub				= @VATPCPlanPurchase OUTPUT,		
		@TotalPCPlanPurchaseWithSub				= @TotalPCPlanPurchase OUTPUT,							
		@TotalPCActualExpenseWithSub			= @TotalPCActualExpense OUTPUT,						
		@TotalWithVATPCActualExpenseWithSub		= @TotalWithVATPCActualExpense OUTPUT,
		@TotalPCWDPlannedManHourWithSub			= @TotalPCWDPlannedManHour OUTPUT,		
		@TotalWithVATPCWDPlannedManHourWithSub	= @TotalWithVATPCWDPlannedManHour OUTPUT,	
		@TotalPCWDActualManHourWithSub			= @TotalPCWDActualManHour OUTPUT,			
		@TotalWithVATPCWDActualManHourWithSub	= @TotalWithVATPCWDActualManHour OUTPUT,	
		@TotalPCWDPlannedExpenseWithSub			= @TotalPCWDPlannedExpense OUTPUT,		
		@TotalWithVATPCWDPlannedExpenseWithSub	= @TotalWithVATPCWDPlannedExpense OUTPUT,	
		@TotalPCWDActualExpenseWithSub			= @TotalPCWDActualExpense OUTPUT,			
		@TotalWithVATPCWDActualExpenseWithSub	= @TotalWithVATPCWDActualExpense OUTPUT	

	

	IF @BreakCalculation != 0
	BEGIN
		IF @AutoExecute = 0
		BEGIN
			IF @BreakCalculation IN (1,2)
			BEGIN
				RAISERROR('#BudgetHasWrongSubBudgets', 18, -1)
				ROLLBACK TRANSACTION
				RETURN 1
			END		
			ELSE IF @BreakCalculation > 2
			BEGIN
				ROLLBACK TRANSACTION
				RETURN @BreakCalculation
			END
		END
		ELSE
		BEGIN
			IF @BreakCalculation IN (1,2)
			BEGIN
				SET @WarningFlag = 3
			END

			ROLLBACK TRANSACTION
			
			BEGIN TRANSACTION
			UPDATE
				[Budget]
			SET
				[Budget].[WarningFlagID] = @WarningFlag
			WHERE
				[Budget].[ID] = @ID
			IF @@ERROR !=0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
			COMMIT TRANSACTION

		END
	END
	ELSE
	BEGIN
		IF @CalculateWithSub = 0
		BEGIN
			SET @WarningFlag = 4
		END

		UPDATE
			[Budget]
		SET
			[Budget].[WarningFlagID] = @WarningFlag
		WHERE
			[Budget].[ID] = @ID
		IF @@ERROR !=0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END
	COMMIT TRANSACTION

	RETURN 0
GO

GRANT EXECUTE ON [pjm6BudgetCalculateActualTotals] TO PUBLIC
GO