IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trBudgetLineExpenseUpdate')
	BEGIN
		PRINT 'Dropping Trigger pjm5trBudgetLineExpenseUpdate'
		DROP  Trigger pjm5trBudgetLineExpenseUpdate
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trBudgetLineExpenseUpdate
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: Anton.Paramonov
**		Date: 17/11/2010 15:20:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trBudgetLineExpenseUpdate'
GO
CREATE Trigger pjm5trBudgetLineExpenseUpdate 
ON [BudgetLineExpense] FOR INSERT, UPDATE, DELETE
AS
BEGIN
	IF @@ROWCOUNT = 0
		RETURN
	
	IF  NOT EXISTS(
		SELECT *
		FROM
			[inserted]
			FULL JOIN [deleted]
				ON [deleted].[ID] = [inserted].[ID] 
		WHERE
			(
			[deleted].[PlannedAmount] != [inserted].[PlannedAmount] OR
			[deleted].[TotalPCPlannedExpense] != [inserted].[TotalPCPlannedExpense] OR
			[deleted].[TotalWithVATPCPlannedExpense] != [inserted].[TotalWithVATPCPlannedExpense]) OR
			([deleted].[PlanPurchaseAmount] != [inserted].[PlanPurchaseAmount] OR
			[deleted].[TotalPCPlanPurchase] != [inserted].[TotalPCPlanPurchase] OR
			[deleted].[TotalWithVATPCPlanPurchase] != [inserted].[TotalWithVATPCPlanPurchase]) OR
			([deleted].[ID] IS NULL AND [inserted].[ID] IS NOT NULL AND ([inserted].[State] = 1 OR [inserted].[State] IS NULL)) OR
			([inserted].[ID] IS NULL AND [deleted].[ID] IS NOT NULL AND [deleted].[State] = 1) 
			)
		RETURN

	DECLARE @changed TABLE ([ID] int)
	INSERT INTO @changed ([ID])
	SELECT
		ISNULL([inserted].[BudgetID], [deleted].[BudgetID])
	FROM
		[inserted]
		FULL OUTER JOIN [deleted]
			ON [inserted].[ID] = [deleted].[ID]

	DECLARE 
		@ID								int, 
		@ApplyVAT						bit, 
		@VATIsIncluded					bit,
		@TotalPCPlannedExpense			money, 
		@TotalWithVATPCPlannedExpense	money,
		@VATPCPlanPurchase				money, 
		@TotalPCPlanPurchase			money

	DECLARE @totals TABLE (
		[ID]							int, 
		[TotalPCPlannedExpense]			money, 
		[TotalWithVATPCPlannedExpense]	money,
		[VATPCPlanPurchase]				money,
		[TotalPCPlanPurchase]			money)
	DECLARE lines CURSOR FAST_FORWARD FOR SELECT [ID] FROM @changed

	OPEN lines
	FETCH NEXT FROM lines INTO @ID
	WHILE @@FETCH_STATUS = 0
	BEGIN
		SELECT
			@TotalPCPlannedExpense			= ISNULL(SUM([BudgetLineExpense].[TotalPCPlannedExpense]), 0),
			@TotalWithVATPCPlannedExpense	= ISNULL(SUM(ROUND([BudgetLineExpense].[TotalWithVATPCPlannedExpense], 2)), 0),
			@VATPCPlanPurchase				= ISNULL(SUM(ROUND([BudgetLineExpense].[VATPCPlanPurchase], 2)), 0),
			@TotalPCPlanPurchase			= ISNULL(SUM(ROUND([BudgetLineExpense].[TotalPCPlanPurchase], 2)), 0)
		FROM
			[Budget]
			INNER JOIN [BudgetLineExpense]
				ON [BudgetLineExpense].[BudgetID] = [Budget].[ID]
		WHERE
			[Budget].[ID] = @ID

		INSERT INTO @totals ([ID], [TotalPCPlannedExpense], [TotalWithVATPCPlannedExpense], [VATPCPlanPurchase], [TotalPCPlanPurchase])
		VALUES (@ID, @TotalPCPlannedExpense, @TotalWithVATPCPlannedExpense, @VATPCPlanPurchase, @TotalPCPlanPurchase)
		FETCH NEXT FROM lines INTO @ID
	END
	CLOSE lines
	DEALLOCATE lines

	DECLARE
		@val TVariant,
		@PlanPurchases TBool
	EXEC adfParameterGet @Name='PlanPurchases', @Group='Pjm7', @Value = @val OUTPUT
	SET @PlanPurchases = CAST(@val as bit)

	UPDATE
		[Budget]
	SET
		[WarningFlagID] = NULL,
		[TotalPCPlannedExpense] = ISNULL([Total].[TotalPCPlannedExpense], 0),
		[TotalWithVATPCPlannedExpense] = ISNULL([Total].[TotalWithVATPCPlannedExpense], 0),
		[ExpenseBudgetBottom] = (CASE 
									WHEN [Budget].[ExpenseBudgetBottomEqualsPlan] = 1 THEN 
									(CASE
										WHEN [Budget].[PlanPurchases] = 1 THEN
										(CASE
											WHEN @PlanPurchases = 1 THEN
											(CASE
												WHEN [Budget].[VATRate] IS NOT NULL AND [Budget].[VATIsIncluded] = 1 THEN
													([Total].[VATPCPlanPurchase] + [Total].[TotalPCPlanPurchase])
												ELSE
													[Total].[TotalPCPlanPurchase]
											END)
											ELSE
											(CASE
												WHEN [Budget].[VATRate] IS NOT NULL AND [Budget].[VATIsIncluded] = 1 THEN
													ROUND(ISNULL([Total].[TotalWithVATPCPlannedExpense] + dbo.fnPjm6GetBudgetTotalDiscount	(	[DiscountViewExpense],
																																				[DiscountPercentExpense],
																																				[DiscountTotalExpense],
																																				[Total].[TotalWithVATPCPlannedExpense]
																																			), 0), 2)
												ELSE
													ROUND(ISNULL([Total].[TotalPCPlannedExpense] + dbo.fnPjm6GetBudgetTotalDiscount	(	[DiscountViewExpense],
																																		[DiscountPercentExpense],
																																		[DiscountTotalExpense],
																																		[Total].[TotalPCPlannedExpense]
																																	), 0), 2)
											END)
										END)
										ELSE
										(CASE
											WHEN [Budget].[VATRate] IS NOT NULL AND [Budget].[VATIsIncluded] = 1 THEN
												ROUND(ISNULL([Total].[TotalWithVATPCPlannedExpense] + dbo.fnPjm6GetBudgetTotalDiscount	(	[DiscountViewExpense],
																																			[DiscountPercentExpense],
																																			[DiscountTotalExpense],
																																			[Total].[TotalWithVATPCPlannedExpense]
																																		), 0), 2)
											ELSE
												ROUND(ISNULL([Total].[TotalPCPlannedExpense] + dbo.fnPjm6GetBudgetTotalDiscount	(	[DiscountViewExpense],
																																	[DiscountPercentExpense],
																																	[DiscountTotalExpense],
																																	[Total].[TotalPCPlannedExpense]
																																), 0), 2)
										END)
									END)
									ELSE 
										[ExpenseBudgetBottom] 
								END),
		[ExpenseBudgetHigh] = (CASE 
								WHEN [Budget].[ExpenseBudgetHighEqualsPlan] = 1 THEN
								(CASE
									WHEN [Budget].[VATRate] IS NOT NULL AND [Budget].[VATIsIncluded] = 1 THEN
										ROUND(ISNULL([Total].[TotalWithVATPCPlannedExpense] + dbo.fnPjm6GetBudgetTotalDiscount	(	[DiscountViewExpense],
																																	[DiscountPercentExpense],
																																	[DiscountTotalExpense],
																																	[Total].[TotalWithVATPCPlannedExpense]
																																), 0), 2)
									ELSE
										ROUND(ISNULL([Total].[TotalPCPlannedExpense] + dbo.fnPjm6GetBudgetTotalDiscount	(	[DiscountViewExpense],
																															[DiscountPercentExpense],
																															[DiscountTotalExpense],
																															[Total].[TotalPCPlannedExpense]
																														), 0), 2)
								END)
								ELSE 
									[ExpenseBudgetHigh] 
							END),
		[Budget].[VATPCPlanPurchase]	=	(CASE
												WHEN [Budget].[VATRate] IS NULL THEN
													0
												ELSE
													[Total].[VATPCPlanPurchase]
											END),
		[Budget].[TotalPCPlanPurchase]	= [Total].[TotalPCPlanPurchase]
	FROM
		[Budget]
		INNER JOIN @totals AS [Total]
			ON [Budget].[ID] = [Total].[ID]
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
END
GO