﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6ProjectBrowseSelectorDialogForBudget]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6ProjectBrowseSelectorDialogForBudget'
		DROP PROCEDURE [dbo].[pjm6ProjectBrowseSelectorDialogForBudget]
	END
GO

PRINT 'Creating procedure pjm6ProjectBrowseSelectorDialogForBudget'
GO

/******************************************************************************
**		File: ProjectBrowseSelectorDialogForBudget.sql
**		Name: pjm6ProjectBrowseSelectorDialogForBudget
**		Desc: Процедура возвращает список доступных проектов, для которых
**			  сотрудник может создать бюджет
**
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      	----------						-----------
**
**		Auth: Anton.Paramonov
**		Date: 24/05/2011 11:54:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------
**
*******************************************************************************/
CREATE PROCEDURE [pjm6ProjectBrowseSelectorDialogForBudget]
	@EmployeeID TIdentifier,
	@OnlyActive bit,
	@ContractOnly bit,
	@OnlyProjectMember bit,
	@ProjectState int = 2,
	@ProjectSelector bit = 0,
	@SupportsRequestManagement bit
AS
	SET NOCOUNT ON

DECLARE @ProjectClass TClass
SET @ProjectClass = dbo.adfGetClassByName('Pjm5.Project')
	
IF(@ProjectState < 10)
SELECT DISTINCT
		[Project].[ID],
		[Project].[Class],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		[Project].[FileAs],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		[Employee].[FileAs] AS [Manager],
		[Supplier].[FileAs] AS [Supplier],
		[Customer].[FileAs] AS [Customer]
	FROM
		[Project]
		LEFT OUTER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
		LEFT OUTER JOIN [Company] AS [Supplier]
			ON [Supplier].[ID] = [Project].[SupplierCompanyID]
		LEFT OUTER JOIN [Company] AS [Customer]
			ON [Customer].[ID] = [Project].[CustomerCompanyID]
		INNER JOIN 
		dbo.fnPjm6GetAvailableProjectsForBudgetProjectSelectorDialog (
			@EmployeeID,
			@OnlyActive,
			@ContractOnly,
			@OnlyProjectMember,
			@ProjectState,
			@ProjectSelector,
			@SupportsRequestManagement) AS [AvialableProject]
		ON [Project].[ID] = [AvialableProject].[ID]
	WHERE
		[Project].[MsProjectID] IS NULL AND 
		NOT EXISTS (SELECT * FROM [Budget] WHERE [Budget].[DocumentID] = [Project].[ID])
ELSE
BEGIN
	IF(@ProjectState = 11)	
		SELECT DISTINCT
				[Project].[ID],
				[Project].[Class],
				[Project].[State],
				[Project].[Flag],
				[Project].[Date],
				[Project].[Number],
				[Project].[FileAs],
				[Project].[SupplierCompanyID],
				[Project].[ProjectManagerEmployeeID],
				[Project].[CustomerCompanyID],
				[Project].[CustomerFinanceManagerID],
				[Project].[ResponsiblePersonEmployeeID],
				[Project].[Created],
				[Project].[CreatedBy],
				[Project].[Modified],
				[Project].[ModifiedBy],
				[Project].[Timestamp],
				[Employee].[FileAs] AS [Manager],
				[Supplier].[FileAs] AS [Supplier],
				[Customer].[FileAs] AS [Customer],
				[LastDocument].[TimeStamp] 
			FROM
				[Project]
				INNER JOIN [LastDocument] 
					ON [LastDocument].[EmployeeID] = @EmployeeID AND 
					[LastDocument].[DocumentClass] = @ProjectClass AND
					[Project].[ID] = [LastDocument].[DocumentID]
				LEFT OUTER JOIN [Employee]
					ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
				LEFT OUTER JOIN [Company] AS [Supplier]
					ON [Supplier].[ID] = [Project].[SupplierCompanyID]
				LEFT OUTER JOIN [Company] AS [Customer]
					ON [Customer].[ID] = [Project].[CustomerCompanyID]
			WHERE 
				[Project].[SupportsRequestManagement] = 1
				AND 
				[Project].[MsProjectID] IS NULL AND 
				NOT EXISTS (SELECT * FROM [Budget] WHERE [Budget].[DocumentID] = [Project].[ID])
			ORDER BY [LastDocument].[TimeStamp] 

	ELSE
		SELECT DISTINCT
			[Project].[ID],
			[Project].[Class],
			[Project].[State],
			[Project].[Flag],
			[Project].[Date],
			[Project].[Number],
			[Project].[FileAs],
			[Project].[SupplierCompanyID],
			[Project].[ProjectManagerEmployeeID],
			[Project].[CustomerCompanyID],
			[Project].[CustomerFinanceManagerID],
			[Project].[ResponsiblePersonEmployeeID],
			[Project].[Created],
			[Project].[CreatedBy],
			[Project].[Modified],
			[Project].[ModifiedBy],
			[Project].[Timestamp],
			[Employee].[FileAs] AS [Manager],
			[Supplier].[FileAs] AS [Supplier],
			[Customer].[FileAs] AS [Customer],
			[LastDocument].[TimeStamp] 
		FROM
			[Project]
			INNER JOIN [LastDocument] 
				ON [LastDocument].[EmployeeID] = @EmployeeID AND 
				[LastDocument].[DocumentClass] = @ProjectClass AND
				[Project].[ID] = [LastDocument].[DocumentID]
			LEFT OUTER JOIN [Employee]
				ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
			LEFT OUTER JOIN [Company] AS [Supplier]
				ON [Supplier].[ID] = [Project].[SupplierCompanyID]
			LEFT OUTER JOIN [Company] AS [Customer]
				ON [Customer].[ID] = [Project].[CustomerCompanyID]
		WHERE
			[Project].[MsProjectID] IS NULL AND 
		NOT EXISTS (SELECT * FROM [Budget] WHERE [Budget].[DocumentID] = [Project].[ID])
		ORDER BY [LastDocument].[TimeStamp] 
END	 
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm6ProjectBrowseSelectorDialogForBudget] TO PUBLIC
GO