IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5CalculationAddExpenseLines]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5CalculationAddExpenseLines'
		DROP PROCEDURE [dbo].[pjm5CalculationAddExpenseLines]
	END
GO

PRINT 'Creating procedure pjm5CalculationAddExpenseLines'
GO

/******************************************************************************
**		File: pjm5CalculationAddExpenseLines.sql
**		Name: pjm5CalculationAddExpenseLines
**		Desc:       
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Anton.Paramonov
**		Date: 05.07.2012 15:06:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		17.12.12	SOV				        
**									   
**		04.03.13	SOV				 OPENXML  XML
**		06.03.13	SOV				 :       
**		05.04.13	SOV				   . -
**		28.02.14	SAP				 :       
**		25.03.14	SAP				       
*******************************************************************************/
CREATE PROCEDURE pjm5CalculationAddExpenseLines
	@CalculationID TIdentifier,
	@Xml xml,
	@UseVariousCurrency bit = 0
AS
SET NOCOUNT ON
	DECLARE
			@ID TIdentifier,
			@DocumentClass TClass,
			@RatesWithVAT TBool,
			@ProjectID TIdentifier,
			@State	TState,
			@Scale TCount,
			@VATRate TPercent,
			@EmployeeID TIdentifier,
			@doc int,
			@value TVariant,
			@NationalCurrency TCode3

	DECLARE @lines TABLE (
		[DocumentID] int,
		[Description] nvarchar(max)
		)
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()

	SELECT 
		@ID = [Calculation].[ID],
		@DocumentClass = [Calculation].[DocumentClass],
		@RatesWithVAT = [RatesWithVAT],
		@ProjectID = [Calculation].[ProjectID],
		@Scale = [Calculation].[Scale],
		@VATRate = [Calculation].[VATRate],
		@State = [Calculation].[State]
	FROM
		[Calculation]
	WHERE
		[ID] = @CalculationID

	EXEC adfParameterGet @Name='NationalCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @NationalCurrency = CAST(@value as char(3))

	IF dbo.adfHasAccessRightByName('ManageAllCalculations') = 0 AND
		dbo.fnPjm5IsProjectManager(@ProjectID, @EmployeeID) = 0 AND
		dbo.fnPjm5IsProjectMember(@ProjectID, @EmployeeID) = 0 AND
		dbo.fnPjm7IsFinanceManager(@ProjectID, @EmployeeID) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
			
	IF ISNULL(@State, 0) = 3
	BEGIN
		RAISERROR('#TransitionTemplateCouldNotBeFound', 18, -1)
		RETURN 1
	END

	INSERT INTO @lines
	SELECT
		list.value('DocumentID[1]', 'int'),
		list.value('Description[1]', 'nvarchar(max)')
	FROM
		@Xml.nodes('/pjm5CalculationGet/CalculationLine') as List(list)

	BEGIN TRANSACTION

	INSERT INTO [CalculationLine] ([CalculationID], [DocumentClass], [DocumentID], [Description], [Amount], [Price], [VATIsIncluded], [VAT])
	SELECT
		@ID, 
		@DocumentClass, 
		l.[DocumentID], 
		l.[Description],
		[Expense].[Amount], 
		CASE
			WHEN @UseVariousCurrency = 1 AND [Expense].[CurrencyRate] IS NOT NULL
			THEN 
				CASE
					--       ?
					WHEN [Expense].[FromCurrencyCode] <> @NationalCurrency
					THEN 
						CASE
							WHEN [Expense].[VATRate] = @VATRate AND [Expense].[Amount] <> 0								
							THEN 
								CASE
									WHEN [Expense].[VATIsIncluded] = 1 
									THEN ROUND(ROUND(ROUND([Expense].[Price]*[Expense].[Amount],2)* [Expense].[CurrencyRate],2)/[Expense].[Amount],2) 
									ELSE ROUND(ROUND(ROUND(ROUND(([Expense].[Price]*[Expense].[Amount] + [Expense].[VAT]),2) * [Expense].[CurrencyRate],2) - ROUND(ROUND(ROUND(([Expense].[Price]*[Expense].[Amount] + [Expense].[VAT]),2) * [Expense].[CurrencyRate],2) * @VATRate/(1 + @VATRate),2),2)/[Expense].[Amount],2)
								END
					ELSE
								CASE
									WHEN [Expense].[VATIsIncluded] = 1 
									THEN ROUND(ROUND(ROUND(ROUND([Expense].[Price]*[Expense].[Amount] - [Expense].[VAT],2) * (1+@VATRate),2) * [Expense].[CurrencyRate],2)/[Expense].[Amount],2) 
									ELSE ROUND(ROUND(ROUND(ROUND(([Expense].[Price]*[Expense].[Amount] + [Expense].[VAT]),2) * [Expense].[CurrencyRate],2) - ROUND(ROUND(ROUND(([Expense].[Price]*[Expense].[Amount] + [Expense].[VAT]),2) * [Expense].[CurrencyRate],2) * [Expense].[VATRate]/(1 + [Expense].[VATRate]),2),2)/[Expense].[Amount],2)
								END 							
						END					
			ELSE
				CASE
					WHEN [Expense].[VATRate] = @VATRate AND [Expense].[Amount] <> 0								
					THEN 
						CASE
							WHEN [Expense].[VATIsIncluded] = 1 
							THEN ROUND(ROUND(ROUND([Expense].[Price]*[Expense].[Amount],2) / [Expense].[CurrencyRate],2)/[Expense].[Amount],2) 
							ELSE ROUND(ROUND(ROUND(ROUND(([Expense].[Price]*[Expense].[Amount] + [Expense].[VAT]),2) / [Expense].[CurrencyRate],2) - ROUND(ROUND(ROUND(([Expense].[Price]*[Expense].[Amount] + [Expense].[VAT]),2) / [Expense].[CurrencyRate],2) * @VATRate/(1 + @VATRate),2),2)/[Expense].[Amount],2)
						END
					ELSE
						CASE
							WHEN [Expense].[VATIsIncluded] = 1 
							THEN ROUND(ROUND(ROUND(ROUND([Expense].[Price]*[Expense].[Amount] - [Expense].[VAT],2) * (1+@VATRate),2) / [Expense].[CurrencyRate],2)/[Expense].[Amount],2) 
							ELSE ROUND(ROUND(ROUND(ROUND(([Expense].[Price]*[Expense].[Amount] + [Expense].[VAT]),2) / [Expense].[CurrencyRate],2) - ROUND(ROUND(ROUND(([Expense].[Price]*[Expense].[Amount] + [Expense].[VAT]),2) / [Expense].[CurrencyRate],2) * [Expense].[VATRate]/(1 + [Expense].[VATRate]),2),2)/[Expense].[Amount],2)
						END 							
					END					
				END
			ELSE
				CASE 
					WHEN [Expense].[VATIsIncluded] = 0 OR [Expense].[VATRate] = @VATRate
						THEN [Expense].[Price]
					WHEN [Expense].[Amount] != 0
						THEN ([Expense].[Price] - [Expense].[VAT] / [Expense].[Amount]) * (1 + @VATRate)
					ELSE ([Expense].[Price] / (1 + [Expense].[VATRate])) * (1 + @VATRate)
				END
		END,
		[Expense].[VATIsIncluded], 
		CASE
			WHEN @UseVariousCurrency = 1 AND [Expense].[CurrencyRate] IS NOT NULL
			THEN 
				CASE
					--       ?
					WHEN [Expense].[FromCurrencyCode] <> @NationalCurrency
					THEN 
						CASE
							WHEN [Expense].[VATRate] = @VATRate								
							THEN 
								CASE
									WHEN [Expense].[VATIsIncluded] = 1 
									THEN ROUND(ROUND(ROUND([Expense].[Price]*[Expense].[Amount],2)* [Expense].[CurrencyRate],2) * @VATRate/(1 + @VATRate),2) 
									ELSE ROUND(ROUND(ROUND(([Expense].[Price]*[Expense].[Amount] + [Expense].[VAT]),2) * [Expense].[CurrencyRate],2) * @VATRate/(1 + @VATRate),2)
								END
							ELSE 
								CASE
									WHEN [Expense].[VATIsIncluded] = 1 
									THEN ROUND(ROUND(ROUND([Expense].[Price]*[Expense].[Amount]-[Expense].[VAT],2)* [Expense].[CurrencyRate],2) * @VATRate,2) 
									ELSE ROUND(ROUND(ROUND(ROUND(([Expense].[Price]*[Expense].[Amount] + [Expense].[VAT]),2) * [Expense].[CurrencyRate],2) - ROUND(ROUND(ROUND(([Expense].[Price]*[Expense].[Amount] + [Expense].[VAT]),2) * [Expense].[CurrencyRate],2) * [Expense].[VATRate]/(1 + [Expense].[VATRate]),2),2) * @VATRate,2)
								END
						END
					ELSE
						CASE
							WHEN [Expense].[VATRate] = @VATRate								
							THEN 
								CASE
									WHEN [Expense].[VATIsIncluded] = 1 
									THEN ROUND(ROUND(ROUND([Expense].[Price]*[Expense].[Amount],2) / [Expense].[CurrencyRate],2) * @VATRate/(1 + @VATRate),2) 
									ELSE ROUND(ROUND(ROUND(([Expense].[Price]*[Expense].[Amount] + [Expense].[VAT]),2) / [Expense].[CurrencyRate],2) * @VATRate/(1 + @VATRate),2)
								END
							ELSE 
								CASE
									WHEN [Expense].[VATIsIncluded] = 1 
									THEN ROUND(ROUND(ROUND([Expense].[Price]*[Expense].[Amount]-[Expense].[VAT],2)/ [Expense].[CurrencyRate],2) * @VATRate,2) 
									ELSE ROUND(ROUND(ROUND(([Expense].[Price]*[Expense].[Amount]),2) / [Expense].[CurrencyRate],2) * @VATRate,2)
								END
						END
				END
			ELSE
				CASE 
					WHEN [Expense].[VATRate] = @VATRate
						THEN [Expense].[VAT]
					ELSE CASE
						WHEN [Expense].[VATIsIncluded] = 1 AND [Expense].[Amount] != 0
							THEN ([Expense].[Price] - [Expense].[VAT] / [Expense].[Amount]) * @VATRate							
						WHEN [Expense].[VATIsIncluded] = 1 AND [Expense].[Amount] = 0
							THEN ([Expense].[Price] / (1 + [Expense].[VATRate])) * @VATRate
						ELSE [Expense].[Price] * @VATRate
					END
			END
		END
	FROM 
		@lines l
		INNER JOIN [pjm5vwExpense] AS [Expense]
			ON  l.[DocumentID] = [Expense].[ID] AND @DocumentClass = [Expense].[Class] 
	WHERE 
		[Expense].[Billable] = 1 AND
		NOT EXISTS (
			SELECT * 
			FROM [CalculationLine] 
			WHERE [CalculationLine].[CalculationID] = @ID AND 
				[DocumentClass] = @DocumentClass AND [DocumentID] = l.[DocumentID])
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
			
	COMMIT TRANSACTION

	RETURN 0
GO

GRANT EXECUTE ON pjm5CalculationAddExpenseLines TO PUBLIC
GO