IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5CalendarBrowse')
	BEGIN
		PRINT 'Dropping Procedure pjm5CalendarBrowse'
		DROP  Procedure  pjm5CalendarBrowse
	END

GO

PRINT 'Creating Procedure pjm5CalendarBrowse'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure pjm5CalendarBrowse
	/* Param List */
AS
	SET NOCOUNT ON

	SELECT
		[Date],
		[NonWorkingTime],
		[Recurrent],
		[Description]
	FROM
		[Calendar]
	
	RETURN 0
GO

GRANT EXEC ON pjm5CalendarBrowse TO PUBLIC

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5CalendarCreate')
	BEGIN
		PRINT 'Dropping Procedure pjm5CalendarCreate'
		DROP  Procedure  pjm5CalendarCreate
	END

GO

PRINT 'Creating Procedure pjm5CalendarCreate'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure pjm5CalendarCreate
	@Date			datetime,
	@NonWorkingTime int, 
	@Recurrent		int, 
	@Description	varchar(256)
AS
	SET NOCOUNT ON
	
	IF EXISTS(SELECT * FROM [Calendar] WHERE [Calendar].[Date] = @Date AND [Calendar].[Recurrent] = @Recurrent )
	BEGIN
		RAISERROR('#CalendarEntryAlreadyExists', 18, -1)
		RETURN 1
	END
	
	DECLARE
		@value			TVariant,
		@WorkTime		decimal(18,2),
		@day			int, 
		@month	    	int
	
	SET @day = DATEPART(day, @Date)
	SET @month = DATEPART(month, @Date)
	
	EXEC adfParameterGet 'WorkTime', 'Pjm5', @value OUTPUT  
	SET @WorkTime = CAST(@value AS decimal(18,2))

	INSERT INTO [Calendar]
		([Date], [NonWorkingTime], [Recurrent], [Description])
	VALUES
		(@Date, @NonWorkingTime, @Recurrent, @Description)
		
	UPDATE 
		[CompanyCalendar]
	SET
		[CompanyCalendar].[Working] = CASE @NonWorkingTime
										WHEN 1 THEN 0
										WHEN 0 THEN @WorkTime
									  END		
	WHERE 
		(
			@Recurrent = 0 AND
			(CAST(CONVERT(varchar(8), [CompanyCalendar].[Date], 112) AS DATETIME) = @Date)
		) OR
		(
			@Recurrent = 1 AND (DATEPART(day, [CompanyCalendar].[Date]) = @day) AND
			(DATEPART(month, [CompanyCalendar].[Date]) = @month) AND
			[CompanyCalendar].[Date] >= CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
		)	
	
	RETURN 0
GO

GRANT EXEC ON pjm5CalendarCreate TO PUBLIC

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5CalendarUpdate')
	BEGIN
		PRINT 'Dropping Procedure pjm5CalendarUpdate'
		DROP  Procedure  pjm5CalendarUpdate
	END

GO

PRINT 'Creating Procedure pjm5CalendarUpdate'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure pjm5CalendarUpdate
	@Date			datetime,
	@NonWorkingTime int, 
	@Recurrent		int, 
	@Description	varchar(256)
AS
	SET NOCOUNT ON
	
	DECLARE
		@value			TVariant,
		@WorkTime		decimal(18,2),
		@day			int, 
		@month	    	int
	
	SET @day = DATEPART(day, @Date)
	SET @month = DATEPART(month, @Date)
	
	EXEC adfParameterGet 'WorkTime', 'Pjm5', @value OUTPUT  
	SET @WorkTime = CAST(@value AS decimal(18,2))
		
	UPDATE 
		[Calendar]
	SET
		[Calendar].[Date] = @Date,
		[Calendar].[NonWorkingTime] = @NonWorkingTime,
		[Calendar].[Recurrent] = @Recurrent,
		[Calendar].[Description] = @Description
	WHERE 
		[Calendar].[Date] = @Date AND 
		[Calendar].[Recurrent] = @Recurrent 
		
	UPDATE 
		[CompanyCalendar]
	SET
		[CompanyCalendar].[Working] = CASE @NonWorkingTime
										WHEN 1 THEN 0
										WHEN 0 THEN @WorkTime
									  END		
	WHERE 
		(
			@Recurrent = 0 AND
			(CAST(CONVERT(varchar(8), [CompanyCalendar].[Date], 112) AS DATETIME) = @Date)
		) OR
		(
			@Recurrent = 1 AND (DATEPART(day, [CompanyCalendar].[Date]) = @day) AND
			(DATEPART(month, [CompanyCalendar].[Date]) = @month) AND
			[CompanyCalendar].[Date] >= CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
		)
			
	
	RETURN 0
GO

GRANT EXEC ON pjm5CalendarUpdate TO PUBLIC

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5CalendarDelete')
	BEGIN
		PRINT 'Dropping Procedure pjm5CalendarDelete'
		DROP  Procedure  pjm5CalendarDelete
	END

GO

PRINT 'Creating Procedure pjm5CalendarDelete'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure pjm5CalendarDelete
	@Date			datetime,
	@Recurrent		int
	
AS
	SET NOCOUNT ON
	
	DECLARE
		@value			TVariant,
		@WorkTime		decimal(18,2),
		@day			int, 
		@month	    	int
	
	SET @day = DATEPART(day, @Date)
	SET @month = DATEPART(month, @Date)
	
	EXEC adfParameterGet 'WorkTime', 'Pjm5', @value OUTPUT  
	SET @WorkTime = CAST(@value AS decimal(18,2))
		
	DELETE FROM [Calendar] 
	WHERE 
		[Calendar].[Date] = @Date AND 
		[Calendar].[Recurrent] = @Recurrent 
		
	UPDATE 
		[CompanyCalendar]
	SET
		[CompanyCalendar].[Working] = CASE dbo.fnPjm5IsWorkingDay([CompanyCalendar].[Date])
										WHEN 0 THEN 0
										WHEN 1 THEN @WorkTime
									  END		
	WHERE 
		(
			@Recurrent = 0 AND
			(CAST(CONVERT(varchar(8), [CompanyCalendar].[Date], 112) AS DATETIME) = @Date)
		) OR
		(
			@Recurrent = 1 AND (DATEPART(day, [CompanyCalendar].[Date]) = @day) AND
			(DATEPART(month, [CompanyCalendar].[Date]) = @month)AND
			[CompanyCalendar].[Date] >= CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
		)	
		
	RETURN 0
GO

GRANT EXEC ON pjm5CalendarDelete TO PUBLIC

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5CompanyCalendarUpdate')
	BEGIN
		PRINT 'Dropping Procedure pjm5CompanyCalendarUpdate'
		DROP  Procedure  pjm5CompanyCalendarUpdate
	END

GO

PRINT 'Creating Procedure pjm5CompanyCalendarUpdate'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure pjm5CompanyCalendarUpdate
	
AS
	SET NOCOUNT ON
	
	DECLARE
		@value			TVariant,
		@WorkTime		decimal(18,2)
				
	EXEC adfParameterGet 'WorkTime', 'Pjm5', @value OUTPUT  
	SET @WorkTime = CAST(@value AS decimal(18,2))
				
	UPDATE 
		[CompanyCalendar]
	SET
		[CompanyCalendar].[Working] = CASE dbo.fnPjm5IsWorkingDay([CompanyCalendar].[Date])
										WHEN 0 THEN 0
										WHEN 1 THEN @WorkTime
									  END
	WHERE 
		[CompanyCalendar].[Date] >= CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
										  		
				
	
	RETURN 0
GO

GRANT EXEC ON pjm5CompanyCalendarUpdate TO PUBLIC

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5EmployeeCalendarUpdate')
	BEGIN
		PRINT 'Dropping Procedure pjm5EmployeeCalendarUpdate'
		DROP  Procedure  pjm5EmployeeCalendarUpdate
	END

GO

PRINT 'Creating Procedure pjm5EmployeeCalendarUpdate'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure pjm5EmployeeCalendarUpdate
	
AS
	SET NOCOUNT ON
	
	DECLARE
		@value			TVariant,
		@WorkTime		decimal(18,2)
				
	EXEC adfParameterGet 'WorkTime', 'Pjm5', @value OUTPUT  
	SET @WorkTime = CAST(@value AS decimal(18,2))
				
	UPDATE 
		[EmployeeCalendar]
	SET
		[EmployeeCalendar].[Working] = CASE dbo.fnPjm5IsWorkingDay([EmployeeCalendar].[Date])
										WHEN 0 THEN 0
										WHEN 1 THEN @WorkTime
									  END
	WHERE 
		[EmployeeCalendar].[Date] >= CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
										  		
				
	
	RETURN 0
GO

GRANT EXEC ON pjm5EmployeeCalendarUpdate TO PUBLIC

GO


