IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ExportStatement')
	BEGIN
		PRINT 'Dropping Procedure ExportStatement'
		DROP  Procedure  ExportStatement
	END

GO

PRINT 'Creating Procedure ExportStatement'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2011 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
**-------------------------------------------------------------------------------------
**	DATE		Author		Comments
--  ---------   ----------  -----------------------------------------------------------
**	31.05.10	SPV			     
	31.08.11    SAM                
	28.02.14	BAO			      
	13.03.14	BAO			    
--------------------------------------------------------------------------------------*/
CREATE Procedure ExportStatement
	@ID TIdentifier
AS
	SET NOCOUNT ON
	
	DECLARE
		@StatementClass TClass,
		@Value TVariant,
		@NationalCurrencyCode TCode3,
		@State TState,
		@EmployeeClass TClass,
		@CompanyClass TClass,
		@val TVariant

	SET @EmployeeClass = dbo.adfGetClassByName('Adf.Employee')
	SET @CompanyClass = dbo.adfGetClassByName('Adf.Company')

	IF EXISTS (
		SELECT
			[Statement].[ID]
		FROM
			[Statement]
			INNER JOIN [Project]
				ON [Project].[ID] = [Statement].[ProjectID]
		WHERE
			[Statement].[ID] = @ID AND
			[Project].[ContractDate] IS NULL AND
			[Project].[ContractNumber] IS NULL AND
			[Project].[ExchangeSystemName] IS NULL	)	
	BEGIN
		RAISERROR('#emptycontractfields', 18, -1)
		RETURN 1
	END
		
	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @val OUTPUT	
	SET @NationalCurrencyCode = CAST(@val AS varchar(3))
	
	SET @StatementClass = dbo.adfGetClassByName('Pjm5.Statement')
	
	SELECT @State = [State] FROM [Statement] WHERE [ID] = @ID
	
	IF @State = 4
	BEGIN
		exec pjm6ExportAnnualDocument @StatementClass, @ID
		RETURN
	END
	
	-- ID Udf- " ".    	
	DECLARE @ServiceTypeClass TClass, @ServiceTypeUDF TIdentifier
	SET @ServiceTypeClass = dbo.adfGetClassByName('Pjm5.ServiceType')
	SELECT
		@ServiceTypeUDF = [Property].[ID]
	FROM
		[Property]
	WHERE
		[Property].[Class] = @ServiceTypeClass AND [Property].[Name] = ' '
	
	------------------	
	DECLARE @StatementInvoice TABLE
	(
		[StatementID] TIdentifier,
		[InvoiceID] TIdentifier
	)
	----
		INSERT INTO @StatementInvoice
		SELECT
			[Statement].[ID],
			[Invoice].[ID]
		FROM
			[Invoice]
			INNER JOIN [Attachment]
				ON [Invoice].[Class] = [Attachment].[DocumentClass]
					AND [Invoice].[ID] = [Attachment].[DocumentID]
			INNER JOIN [Statement]
				ON [Statement].[Class] = [Attachment].[LinkDocumentClass]
					AND [Statement].[ID] = [Attachment].[LinkDocumentID]
		WHERE
			[Statement].[ID] = @ID
		UNION
		SELECT
			[Statement].[ID],
			[Invoice].[ID]
		FROM
			[Statement]
			INNER JOIN [Attachment]
				ON [Statement].[Class] = [Attachment].[DocumentClass]
					AND [Statement].[ID] = [Attachment].[DocumentID]
			INNER JOIN [Invoice]
				ON [Invoice].[Class] = [Attachment].[LinkDocumentClass]
					AND [Invoice].[ID] = [Attachment].[LinkDocumentID]
		WHERE
			[Statement].[ID] = @ID
		----
		SELECT
			GETDATE() as 'Period/@StartDate',
			GETDATE() as 'Period/@EndDate',
			0 as 'Period/@PeriodType',
			(
				SELECT
					[Company].[ID] as '@SupplierID',
					[Company].[FileAs] as '@Name',
					'' as '@SupplierType',
					[Company].[LegalName] as '@LegalName',
					dbo.fnPjm5AddressAsString([LegalAddress].[Street], [LegalAddress].[City],[LegalAddress].[Region],[LegalAddress].[PostalCode],[LegalAddress].[Country]) as '@LegalAddress',
					dbo.fnPjm5AddressAsString([PostalAddress].[Street], [PostalAddress].[City],[PostalAddress].[Region],[PostalAddress].[PostalCode],[PostalAddress].[Country]) as '@PostalAddress',
					[BasicPhone].[Phone] as '@BasePhone',
					[Fax].[Phone] as '@Fax',
					[Company].[LegalCode] as '@LegalCode',
					[Company].[KPP] as '@KPP',
		(
		SELECT
			[Statement].[ID] as '@ID',
			[Statement].[State] as '@State',
			[Statement].[Date] as '@Date',
			[Statement].[Number] as '@Number',

			[Statement].[PeriodStart] as '@StartDate',
			[Statement].[PeriodEnd] as '@EndDate',
			[Currency].[Code] as '@CurrencyCode',
			[Currency].[NumericCode] as '@CurrencyNumericCode',
			[Statement].[CurrencyRate] as '@CurrencyRate',
			dbo.pjm6fnCurrencyGetRate([Statement].[CurrencyCode], [Statement].[Date], @NationalCurrencyCode) as '@NationalCurrencyRate',
			[Statement].[Total] as '@Total',
			[Statement].[TotalWithVAT] as '@NTotalWithVAT',
			[Statement].[VAT] as '@VAT',
			(SELECT TOP(1)[StatementLine].[VATRate] FROM [StatementLine] WHERE [StatementLine].[StatementID] = [Statement].[ID]) as '@VATRate',
			CASE WHEN (SELECT TOP(1) [StatementLine].[VATRate] FROM [StatementLine] WHERE [StatementLine].[StatementID] = [Statement].[ID]) > 0 THEN 1 ELSE 0 END as '@ApplyVAT',
			dbo.fnPjm6GetLastEditDate([Statement].[ID], [Statement].[Class]) as '@Modified',
			-----------contract
			(
			SELECT
				[Project].[ID] as '@ContractID',
				[Project].[ContractNumber] as '@ContractNumber',
				dbo.fnMask ([Project].[ExchangeSystemName], [Project].[ContractNumber],
			        [Project].[ContractDate]) as '@ExchangeSystemName',
				[Project].[ContractDate] as '@ContractDate',
				[Project].[ContractEndDate] as '@ContractEndDate',
				[Currency].[Code] as '@CurrencyCode',
				[Currency].[NumericCode] as '@CurrencyNumericCode',
				[CostCenter].[ID] as '@CostCenterID',
				[CostCenter].[Code] as '@CostCenterCode',
				[CostCenter].[FileAs] as '@CodeCenterFileAs',
				CASE
					WHEN [Project].[CurrencyCode] != @NationalCurrencyCode THEN
						CASE
							WHEN ISNULL([ContractBankAccount].[CurrencyCode], [DefaultBankAccount].[CurrencyCode]) != @NationalCurrencyCode THEN 'INT'
							ELSE 'UE'
						END
					ELSE
						'NAT'
				END as '@CurrencyContractType',
				[Project].[InvoiceExpirationPeriod] as '@InvoiceExpirationPeriod',
				[Project].[InvoiceExpirationPeriodType] as '@InvoiceExpirationPeriodType',
				[Project].[IsConsignor] as '@IsConsignor',
				[Project].[ConsignorID] as '@ConsignorID',
				CASE [Project].[ConsignorClass] WHEN @EmployeeClass THEN 'Employee' WHEN @CompanyClass THEN 'Company' ELSE 'None' END as '@ConsignorType',
				[BusinessCard].[FileAs] as '@Consignor',
				[Project].[ConsignorContract] as '@ConsignorContract'
			FROM
				[Project]
				LEFT OUTER JOIN [CostCenter]
					ON [Project].[CostCenterID] = [CostCenter].[ID]
				LEFT OUTER JOIN [Company]
					ON [Company].[ID] = [Project].[SupplierCompanyID]
				LEFT OUTER JOIN [BankAccount] [DefaultBankAccount]
					ON [DefaultBankAccount].[ID] = ISNULL([Company].[BankAccountID], -1)
				LEFT OUTER JOIN [BankAccount] [ContractBankAccount]
					ON [ContractBankAccount].[ID] = ISNULL([Project].[BankAccountID], -1)
				LEFT OUTER JOIN [Currency]
					ON [Currency].[Code] = [Project].[CurrencyCode]
				LEFT OUTER JOIN [BusinessCard]
					ON [BusinessCard].[Class] = [Project].[ConsignorClass] AND [BusinessCard].[ID] = [Project].[ConsignorID]
			WHERE [Project].[ID] = [Statement].[ProjectID]
			FOR XML PATH('Contract'), TYPE
			),
			---------------Bank account
			(
				SELECT
					[BankAccount].[ID] as '@BankAccountID',
					[BankAccount].[Account] as '@BankAccount',
					[BankAccount].[BankName] as '@Bank',
					[BankAccount].[City] as '@CityBank',
					[BankAccount].[IntermediaryAccount] as '@IntermediaryAccount',
					[BankAccount].[BankCode] as '@BankCode',
					[Currency].[Code] as '@CurrencyCode',
					[Currency].[NumericCode] as '@CurrencyNumericCode'
				FROM
					[Project]
					INNER JOIN [BankAccount]
						ON [BankAccount].[ID] = ISNULL([Project].[BankAccountID], [Company].[BankAccountID])
					INNER JOIN [Currency]
						ON [BankAccount].[CurrencyCode] = [Currency].[Code]	
				WHERE
					[Statement].[SupplierCompanyID] = [Company].[ID]
					AND [Project].[ID] = [Statement].[ProjectID]
				FOR XML PATH('BankAccount'), TYPE
			),
			---------------Customer Bank account
			(
			SELECT
				[BankAccount].[ID] as '@BankAccountID',
				[BankAccount].[Account] as '@BankAccount',
				[BankAccount].[BankName] as '@Bank',
				[BankAccount].[City] as '@CityBank',
				[BankAccount].[IntermediaryAccount] as '@IntermediaryAccount',
				[BankAccount].[BankCode] as '@BankCode',
				[Currency].[Code] as '@CurrencyCode',
				[Currency].[NumericCode] as '@CurrencyNumericCode'
			 FROM
				[Company]
				INNER JOIN [BankAccount]
					ON [Company].[BankAccountID] = [BankAccount].[ID]
				INNER JOIN [Currency]
					ON [BankAccount].[CurrencyCode] = [Currency].[Code]
			WHERE
				[Statement].[CustomerCompanyID] = [Company].[ID]
			 FOR XML PATH('ConsigneeBankAccount'), TYPE
			),
			-------------Customer
			(
				SELECT	
					[Company].[ID] as '@ID',
					[Company].[FileAs]  as '@Name',
					dbo.fnPjm6GetLegalFormType([Company].[LegalCode], ISNULL([LegalAddress].[Country], '')) as '@LegalFormType',
					[Company].[LegalName]  as '@LegalName',
					dbo.fnPjm5AddressAsString([LegalAddress].[Street], [LegalAddress].[City],[LegalAddress].[Region],[LegalAddress].[PostalCode],[LegalAddress].[Country])  as '@LegalAddress',
					dbo.fnPjm5AddressAsString([PostalAddress].[Street], [PostalAddress].[City],[PostalAddress].[Region],[PostalAddress].[PostalCode],[PostalAddress].[Country]) as '@PostAddress',
					[BasicPhone].[Phone] as '@Phone',
					[Fax].[Phone] as '@Fax',
					[Company].[LegalCode]  as '@LegalCode',
					[Company].[KPP] as '@KPP'
				FROM
					[Company]
					LEFT OUTER JOIN [Address] as [LegalAddress]
						ON [LegalAddress].[BusinessCardID] = [Company].[ID] AND 
							[LegalAddress].[BusinessCardClass] = [Company].[Class] AND
							[LegalAddress].[AddressTypeID] = 1
					LEFT OUTER JOIN [Address] as [PostalAddress]
						ON [PostalAddress].[BusinessCardID] = [Company].[ID] AND 
							[PostalAddress].[BusinessCardClass] = [Company].[Class] AND
							[PostalAddress].[AddressTypeID] = 5
					LEFT OUTER JOIN [Phone] as [BasicPhone]
						ON [BasicPhone].[BusinessCardID] = [Company].[ID] AND 
							[BasicPhone].[BusinessCardClass] = [Company].[Class] AND
							[BasicPhone].[PhoneTypeID] = 11
					LEFT OUTER JOIN [Phone] as [Fax]
						ON [Fax].[BusinessCardID] = [Company].[ID] AND 
							[Fax].[BusinessCardClass] = [Company].[Class] AND
							[Fax].[PhoneTypeID] = 8 
				WHERE [Company].[ID] = [Statement].[CustomerCompanyID]
				FOR XML PATH('Customer'), TYPE
			),
			-------------Consignee
			(
				SELECT	
					[Company].[ID] as '@ID',
					[Company].[FileAs]  as '@Name',
					dbo.fnPjm6GetLegalFormType([Company].[LegalCode], ISNULL([LegalAddress].[Country], '')) as '@LegalFormType',
					[Company].[LegalName]  as '@LegalName',
					dbo.fnPjm5AddressAsString([LegalAddress].[Street], [LegalAddress].[City],[LegalAddress].[Region],[LegalAddress].[PostalCode],[LegalAddress].[Country])  as '@LegalAddress',
					dbo.fnPjm5AddressAsString([PostalAddress].[Street], [PostalAddress].[City],[PostalAddress].[Region],[PostalAddress].[PostalCode],[PostalAddress].[Country]) as '@PostAddress',
					[BasicPhone].[Phone] as '@Phone',
					[Fax].[Phone] as '@Fax',
					[Company].[LegalCode]  as '@LegalCode',
					[Company].[KPP] as '@KPP'
				FROM
					[Company]
					LEFT OUTER JOIN [Address] as [LegalAddress]
						ON [LegalAddress].[BusinessCardID] = [Company].[ID] AND 
							[LegalAddress].[BusinessCardClass] = [Company].[Class] AND
							[LegalAddress].[AddressTypeID] = 1
					LEFT OUTER JOIN [Address] as [PostalAddress]
						ON [PostalAddress].[BusinessCardID] = [Company].[ID] AND 
							[PostalAddress].[BusinessCardClass] = [Company].[Class] AND
							[PostalAddress].[AddressTypeID] = 5
					LEFT OUTER JOIN [Phone] as [BasicPhone]
						ON [BasicPhone].[BusinessCardID] = [Company].[ID] AND 
							[BasicPhone].[BusinessCardClass] = [Company].[Class] AND
							[BasicPhone].[PhoneTypeID] = 11
					LEFT OUTER JOIN [Phone] as [Fax]
						ON [Fax].[BusinessCardID] = [Company].[ID] AND 
							[Fax].[BusinessCardClass] = [Company].[Class] AND
							[Fax].[PhoneTypeID] = 8 
				WHERE [Company].[ID] = [Statement].[CustomerCompanyID]
				FOR XML PATH('Consignee'), TYPE
			),
			------------Statement Lines
			(
				SELECT
					[StatementLine].[ID] as '@ID',
					[ServiceType].[ID] as '@ServiceTypeID',
					[ServiceType].[FileAs] as '@ServiceType',
					[ServiceType].[Code] as '@ServiceTypeCode',
					CASE [PropertyValue].[Value] WHEN 'True' THEN 1 ELSE 0 END as '@LineTypeIncludeSKU',
					[Service].[ID] as '@ServiceID',
					[Service].[FileAs] as '@Service',
					[Service].[Code] as '@ServiceCode',
					[StatementLine].[Amount] as '@Amount',
					[StatementLine].[VATRate] as '@VATRate',
					[UOM].[FileAs] '@UOM',
					CASE 
					WHEN [StatementLine].[VATIsIncluded] = 1 AND [StatementLine].[Amount] != 0
						THEN ([StatementLine].[Price] * [StatementLine].[Amount] - [StatementLine].[VAT]) / [StatementLine].[Amount]
					ELSE [StatementLine].[Price] 
					END  as '@Price',
					[StatementLine].[Amount] * 	
						CASE 
							WHEN [StatementLine].[VATIsIncluded] = 1 AND [StatementLine].[Amount] != 0
								THEN ([StatementLine].[Price] * [StatementLine].[Amount] - [StatementLine].[VAT]) / [StatementLine].[Amount]
							ELSE [StatementLine].[Price]
						END  as '@Total',
					CASE 
						WHEN [StatementLine].[VATIsIncluded] = 0 AND [StatementLine].[Amount] != 0
							THEN ([StatementLine].[Price] * [StatementLine].[Amount] + [StatementLine].[VAT]) / [StatementLine].[Amount]
						ELSE [StatementLine].[Price]
					END  as '@PriceWithVAT',
					[StatementLine].[Amount] * 	
					CASE 
						WHEN [StatementLine].[VATIsIncluded] = 0 AND [StatementLine].[Amount] != 0
							THEN ([StatementLine].[Price] * [StatementLine].[Amount] + [StatementLine].[VAT]) / [StatementLine].[Amount]
						ELSE [StatementLine].[Price]
					END as '@TotalWithVAT',
					[StatementLine].[VAT] as '@VAT',
					[StatementLine].[Description] as '@Description'
				FROM
					[StatementLine]
					LEFT OUTER JOIN [ServiceType]
						ON [StatementLine].[ServiceTypeID] = [ServiceType].[ID]
					LEFT OUTER JOIN [UOM]
						ON [StatementLine].[UOMID] = [UOM].[ID]
					LEFT OUTER JOIN [ServiceAssignment]
							ON [ServiceAssignment].[Class] = [StatementLine].[DocumentClass]
							AND [ServiceAssignment].[ID] = [StatementLine].[DocumentID]
					LEFT OUTER JOIN [Service]
							ON [Service].[ID] = [ServiceAssignment].[ServiceID]
					LEFT OUTER JOIN [PropertyValue]
						ON [PropertyValue].[DocumentClass] = [ServiceType].[Class] AND
						 [PropertyValue].[DocumentID] = [ServiceType].[ID] AND [PropertyValue].[PropertyID] = @ServiceTypeUDF
				WHERE
					[StatementLine].[StatementID] = [Statement].[ID]
				FOR XML PATH('StatementLine'), TYPE
			),
			---------------------State Invoices
			(
				SELECT
					[Invoice].[ID] as '@ID',
					[Invoice].[Number] as '@Number',
					[Invoice].[Date] as '@Date',
					[Invoice].[Total] as '@Sum'
				FROM
					[StatementAdvanceInvoice] [SI]
					INNER JOIN [Invoice]
						ON [SI].[AdvanceInvoiceID] = [Invoice].[ID] AND [Invoice].[Advance] = 1
				WHERE
					[SI].[StatementID] = @ID
				FOR XML PATH('AInvoice'), TYPE
			) as 'AInvoices',
			------------
			(
				SELECT
					[Invoice].[ID] as '@ID',
					[Invoice].[Number] as '@Number',
					[Invoice].[Date] as '@Date',
					[Invoice].[Total] as '@Sum'
				FROM
					@StatementInvoice [SI]
					INNER JOIN [Invoice]
						ON [SI].[InvoiceID] = [Invoice].[ID] AND [Invoice].[Advance] = 0
				WHERE
					[SI].[StatementID] = [Statement].[ID]
				FOR XML PATH('PInvoice'), TYPE
			) as 'PInvoices'
			
			-------------------------------
		FROM
			[Statement] 
			INNER JOIN [Project]
				ON [Project].[ID] = [Statement].[ProjectID]
			INNER JOIN [Currency]
				ON [Currency].[Code] = [Statement].[CurrencyCode]
		WHERE
			[Statement].[ID] = @ID AND [Statement].[State] IN (2, 3)
			
		FOR XML PATH('Statement'), TYPE
		) as 'Statements'
	FROM
		[Statement]
		INNER JOIN [Project]
			ON [Statement].[ProjectID] = [Project].[ID] AND [Statement].[ID] = @ID
		INNER JOIN [Company] 
			ON [Company].[ID] = [Project].[SupplierCompanyID]
		LEFT OUTER JOIN [Address] as [LegalAddress]
			ON [LegalAddress].[BusinessCardID] = [Company].[ID] AND 
				[LegalAddress].[BusinessCardClass] = [Company].[Class] AND
				[LegalAddress].[AddressTypeID] = 1
		LEFT OUTER JOIN [Address] as [PostalAddress]
			ON [PostalAddress].[BusinessCardID] = [Company].[ID] AND 
				[PostalAddress].[BusinessCardClass] = [Company].[Class] AND
				[PostalAddress].[AddressTypeID] = 5
		LEFT OUTER JOIN [Phone] as [BasicPhone]
			ON [BasicPhone].[BusinessCardID] = [Company].[ID] AND 
				[BasicPhone].[BusinessCardClass] = [Company].[Class] AND
				[BasicPhone].[PhoneTypeID] = 11
		LEFT OUTER JOIN [Phone] as [Fax]
			ON [Fax].[BusinessCardID] = [Company].[ID] AND 
				[Fax].[BusinessCardClass] = [Company].[Class] AND
				[Fax].[PhoneTypeID] = 8
	FOR XML PATH('Supplier'), TYPE) as 'Suppliers'
FOR XML PATH('Documents')
	
	DECLARE @ExportFinanceOnce TBool
	SELECT
		@ExportFinanceOnce = [Company].[ExportFinanceOnce]
	FROM
		[Statement]
		INNER JOIN [Company]
			ON [Statement].[SupplierCompanyID] = [Company].[ID]
	WHERE
		[Statement].[ID] = @ID
	
	DECLARE @ExportItemID TIdentifier, @SupplierID TIdentifier, @Date TDate
	SELECT @SupplierID = [SupplierCompanyID], @Date = [Date] FROM [Statement] WHERE [ID] = @ID
	EXEC pjm6CreateExportItem @SupplierID, @Date, @Date, 3
	SET @ExportItemID = @@IDENTITY
	
	UPDATE
		[Statement]
	SET
		[Statement].[ExportItemID] = @ExportItemID,
		[Statement].[ExchangeBanned] = @ExportFinanceOnce
	WHERE
		[Statement].[ID] = @ID AND [Statement].[State] IN (2, 3) AND [Statement].[ExchangeBanned] = 0
	
	RETURN 0
GO

GRANT EXEC ON ExportStatement TO PUBLIC

GO
