 IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnFolderHasRightAccess]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnFolderHasRightAccess'
		DROP FUNCTION [dbo].[fnFolderHasRightAccess]
	END

GO

PRINT 'Creating function fnFolderHasRightAccess'
GO
/******************************************************************************
**		File: 
**		Name: fnFolderHasRightAccess
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		27.06.11	SPV				Optimization
*******************************************************************************/
CREATE FUNCTION fnFolderHasRightAccess(
	@FolderID TIdentifier,
	@UserID TIdentifier,
	@Right TName
)
RETURNS BIT
AS
BEGIN
	IF @FolderID = 0
		RETURN 1
		
	DECLARE 
		@ManageDocumentCard int,
		@CompanyID TIdentifier,
		@RightID int, 
		@Owner int, 
		@Visible int, 
		@OwnerOrVisible int,
		@CreateSubfolder int
	SET @ManageDocumentCard = dbo.adfHasAccessRight(dbo.adfGetRightID('ManageDocumentCard'))
	
	SET @CreateSubfolder = 0x0004
	SET @Owner = 0x0008
	SET @Visible = 0x0020
	SET @OwnerOrVisible = (@Owner | @Visible)
	
	IF UPPER(@Right) = 'CREATEITEMS'
		SET @RightID = 0x0001
	ELSE IF UPPER(@Right) = 'READITEMS'
		SET @RightID = 0x0002
	ELSE IF UPPER(@Right) = 'CREATESUBFOLDER'
        SET @RightID = 0x0004
	ELSE IF UPPER(@Right) = 'FOLDEROWNER'
        SET @RightID = 0x0008
	ELSE IF UPPER(@Right) = 'FOLDERPUBLICATION'
        SET @RightID = 0x0010
	ELSE IF UPPER(@Right) = 'FOLDERVISIBLE'
        SET @RightID = 0x0020
	ELSE IF UPPER(@Right) = 'EDITOWN'
        SET @RightID = 0x0100
	ELSE IF UPPER(@Right) = 'EDITALL'
        SET @RightID = 0x0200
	ELSE IF UPPER(@Right) = 'DELETEOWN'
        SET @RightID = 0x1000
	ELSE IF UPPER(@Right) = 'DELETEALL'
        SET @RightID = 0x2000
	ELSE 
		RETURN 0
	
	IF @ManageDocumentCard = 1
	BEGIN
		IF @RightID NOT IN (@Owner, @Visible, @CreateSubfolder)
		BEGIN
			IF EXISTS(SELECT * FROM [Folder] WHERE [ID]=@FolderID AND [CompanyID] IS NOT NULL)
			BEGIN
				IF EXISTS(
					SELECT * 
					FROM 
						[FolderAccessControl] 
					WHERE 
						[FolderID] = @FolderID AND 
						[TrusteeID] = @UserID AND 
						([AccessRights] & @OwnerOrVisible) = @OwnerOrVisible) 
					RETURN 1
					
				IF EXISTS
				(
					SELECT * 
					FROM
						[FolderAccessControl] 
					WHERE 
						[FolderAccessControl].[FolderID] = @FolderID AND 
						([AccessRights] & @OwnerOrVisible) = @OwnerOrVisible AND
						[FolderAccessControl].[TrusteeID] IN
						(
							SELECT [UserRole].[RoleID] FROM [UserRole] WHERE [UserRole].[UserID] = @UserID
						)
				)
					RETURN 1
			END
		END
	END	
	
	IF EXISTS(
		SELECT * 
		FROM 
			[FolderAccessControl] 
		WHERE 
			[FolderID] = @FolderID AND 
			[TrusteeID] = @UserID AND 
			([AccessRights] & @RightID) = @RightID) 
		RETURN 1
		
	IF EXISTS
	(
		SELECT * 
		FROM
			[FolderAccessControl] 
		WHERE 
			[FolderAccessControl].[FolderID] = @FolderID AND 
			([AccessRights] & @RightID) = @RightID AND
			[FolderAccessControl].[TrusteeID] IN
			(
				SELECT [UserRole].[RoleID] FROM [UserRole] WHERE [UserRole].[UserID] = @UserID
			)
	)
		RETURN 1

	RETURN 0
END
GO

GRANT EXEC ON fnFolderHasRightAccess TO PUBLIC
GO
