IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5InvoiceCreateRecurrence]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5InvoiceCreateRecurrence'
		DROP PROCEDURE [dbo].[pjm5InvoiceCreateRecurrence]
	END
GO

PRINT 'Creating procedure pjm5InvoiceCreateRecurrence'
GO

/******************************************************************************
**		File: pjm5InvoiceCreateRecurrence.sql
**		Name: pjm5InvoiceCreateRecurrence
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: andrew.maklakov
**		Date: 08/02/2005 14:07:25
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		01.07.11	SYV				 WarningFlagID,   
**		20.04.12	ASA				    [InvoiceLine],       
**									 [Invoice],    [TotalBC]  [TotalWithVATBC]
**		10.12.13	SAP				  
*******************************************************************************/
CREATE PROCEDURE [pjm5InvoiceCreateRecurrence]
	@ID TIdentifier
AS
	DECLARE 
			@Flag TFlag,
			@Class TClass,
			@State TState,
			@InvoiceState TState,
			@Number TCode,
			@FileAs TName,
			@ProjectID TIdentifier,
			@Date TDate,
			@DueDate TDate,
			@SupplierBankAccountID TIdentifier,
			@CurrencyRate TAmount,
			@BaseCurrencyRate TAmount,
			@CurrencyCode TCode3,
			@ProjectCurrencyCode TCode3,
			@BaseCurrencyCode TCode3,
			@Comments TNotes,
			@PaymentCurrencyPoint TIdentifier,
			@Advance TBool,
			@RecurrenceID TIdentifier,
			@InvoiceExpirationPeriod TCount,
			@SupplierCompanyID TIdentifier,
			@CustomerCompanyID TIdentifier,
			@Scale TCount,
			@rv int,
			@value TVariant,
			@WarningFlagID TIdentifier,
			@PrevCurrencyRate TAmount,
			@PrevBaseCurrencyRate TAmount,
			@NationalCurrencyCode TCode3
			
	SET NOCOUNT ON

	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @value OUTPUT	
	SET @NationalCurrencyCode = CAST(@value AS varchar(3))
	
	SELECT
		@Flag = [Invoice].[Flag],
		@Class = [Invoice].[Class],
		@InvoiceState = [Invoice].[State],
		@Number = '',
		@FileAs = '',
		@ProjectID = [Invoice].[ProjectID],
		@Date = [Invoice].[Date],
		@DueDate = [Invoice].[DueDate],
		@SupplierBankAccountID = [Invoice].[SupplierBankAccountID],
		@CurrencyCode = [Invoice].[CurrencyCode],
		@PaymentCurrencyPoint = [Invoice].[PaymentCurrencyPoint],
		@Advance = [Invoice].[Advance],
		@Comments = [Invoice].[Comments],
		@InvoiceExpirationPeriod = [Project].[InvoiceExpirationPeriod],
		@SupplierCompanyID = [Invoice].[SupplierCompanyID],
		@CustomerCompanyID = [Invoice].[CustomerCompanyID],
		@Scale = [Invoice].[Scale],
		@ProjectCurrencyCode = [Project].[CurrencyCode],
		@PrevCurrencyRate = [Invoice].[CurrencyRate],
		@PrevBaseCurrencyRate = [Invoice].[BaseCurrencyRate]
	FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Project].[ID] = [Invoice].[ProjectID]
	WHERE
		[Invoice].[ID] = @ID
	
	SELECT
		@RecurrenceID = [RecurrencePatternID]
	FROM
		[Document]
	WHERE
		[Class] = @Class AND [ID] = @ID
	IF @RecurrenceID IS NULL
		RETURN 0
		
	DECLARE 
		@NewID TIdentifier,
		@NewDate TDatetime,
		@NewDueDate TDatetime,
		@CurrentDate TDatetime

	SET @CurrentDate = GETDATE()
	SET @NewDate = dbo.fnPjm5RecurrenceGetNextDateTime(@RecurrenceID, @Date, @CurrentDate)
	IF @NewDate IS NULL
		RETURN 0

	EXEC adfParameterGet 'BaseCurrency', 'CommonBusiness', @value OUTPUT
	SET @BaseCurrencyCode = CAST(@value AS varchar(3))
	SET @CurrencyRate = dbo.fnCurrencyGetExactRate(@CurrencyCode, @ProjectCurrencyCode, @NewDate)
	SET @BaseCurrencyRate = dbo.fnCurrencyGetExactRate(@BaseCurrencyCode, @ProjectCurrencyCode, @NewDate)

	SET @State = dbo.adfwfGetInitialState('98b8f49e-202e-4b46-8074-421734078da6')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageAllInvoices')) = 0  AND
		dbo.fnPjm5HasFinansDataAccess(@ProjectID, @EmployeeID, NULL, NULL) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	SET @WarningFlagID = NULL

	IF @CurrencyRate IS NULL
	BEGIN
		IF @PrevCurrencyRate > 1
			SET @CurrencyRate = -1.0 * @PrevCurrencyRate
		ELSE
			SET @CurrencyRate = @PrevCurrencyRate


		SET @WarningFlagID = 6
	END

	IF @BaseCurrencyRate IS NULL
	BEGIN
		SET @BaseCurrencyRate = @PrevBaseCurrencyRate
		SET @WarningFlagID = 6
	END

	SET @NewDueDate = dbo.fnPjm5AddWorkingDays(@NewDate, @InvoiceExpirationPeriod)
	INSERT INTO [Invoice]
		([Flag], [State], [Date], [Number], [FileAs],
		 [SupplierBankAccountID], [ProjectID],
		 [CurrencyRate], [BaseCurrencyRate], 
		 [CurrencyCode], [Comments], [PaymentCurrencyPoint], 
		 [Advance], [DueDate],
		 [SupplierCompanyID], [CustomerCompanyID],
		 [Scale], [WarningFlagID])
	VALUES
		(@Flag, @State, @NewDate, @Number, @FileAs, 
		 @SupplierBankAccountID, @ProjectID,
		 CASE WHEN @CurrencyRate < 0.0 THEN -1.0 * @CurrencyRate  ELSE @CurrencyRate END,
		 CASE WHEN @BaseCurrencyRate < 0.0 THEN -1.0 * @BaseCurrencyRate ELSE @BaseCurrencyRate END,
		 @CurrencyCode, @Comments, @PaymentCurrencyPoint, 
		 @Advance, @NewDueDate,
		 @SupplierCompanyID, @CustomerCompanyID,
		 @Scale, @WarningFlagID)
	IF @@ERROR != 0
		RETURN 1

	SET @NewID = SCOPE_IDENTITY()

	INSERT INTO [InvoiceLine]									-- [CurrencyRate], [BaseCurrencyRate]
		([InvoiceID], [DocumentClass], [DocumentID], 
		[Description], [Amount], [UOMID], [Price], [VATIsIncluded], [VATRate], [VAT],
		[PricePC], [VATPC], [ServiceTypeID], [BasePrice], [SortKey], [TotalBC], [TotalWithVATBC])
	SELECT
		@NewID, 
		[DocumentClass], 
		[DocumentID], 
		[Description], 
		[Amount], 
		[UOMID], 
		CASE WHEN @CurrencyRate < 0 THEN -1.0 * [PricePC] * @CurrencyRate ELSE [PricePC] / @CurrencyRate END, 
		[VATIsIncluded], 
		[VATRate], 
		CASE WHEN @CurrencyRate < 0 THEN -1.0 * [InvoiceLine].[VATPC] * @CurrencyRate ELSE [InvoiceLine].[VATPC] / @CurrencyRate END,
		[PricePC],
		[InvoiceLine].[VATPC],
		[ServiceTypeID], 
		[BasePrice],
		[SortKey],
		[TotalBC] = CASE WHEN [Invoice].[BaseCurrencyRate] IS NOT NULL 
					THEN
						ROUND(CASE 
							WHEN @ProjectCurrencyCode = @BaseCurrencyCode
								THEN [PricePC] * [Amount] - [VATIsIncluded] * [InvoiceLine].[VATPC]
							WHEN @CurrencyCode = @BaseCurrencyCode
								THEN [Price] * [Amount] - [VATIsIncluded] * [InvoiceLine].[VAT]
							WHEN @ProjectCurrencyCode = @NationalCurrencyCode
								THEN ([PricePC] * [Amount] - [VATIsIncluded] * [InvoiceLine].[VATPC]) / [Invoice].[BaseCurrencyRate]
							ELSE ([PricePC] * [Amount] - [VATIsIncluded] * [InvoiceLine].[VATPC]) * [Invoice].[BaseCurrencyRate]
						END, 2)
					ELSE NULL
					END,
		[TotalWithVATBC] =	CASE WHEN [Invoice].[BaseCurrencyRate] IS NOT NULL 
							THEN
								ROUND(CASE 
								WHEN @ProjectCurrencyCode = @BaseCurrencyCode
									THEN [PricePC] * [Amount] + (1 - [VATIsIncluded]) * [InvoiceLine].[VATPC]
								WHEN @CurrencyCode = @BaseCurrencyCode
									THEN [Price] * [Amount] + (1 - [VATIsIncluded]) * [InvoiceLine].[VAT]
								WHEN @ProjectCurrencyCode = @NationalCurrencyCode
									THEN ([PricePC] * [Amount] + (1 - [VATIsIncluded]) * [InvoiceLine].[VATPC]) / [Invoice].[BaseCurrencyRate]
								ELSE ([PricePC] * [Amount] + (1 - [VATIsIncluded]) * [InvoiceLine].[VATPC]) * [Invoice].[BaseCurrencyRate]
								END, 2)
							ELSE NULL
							END
	FROM
		[InvoiceLine]
		JOIN [Invoice] ON [InvoiceLine].[InvoiceID] = [Invoice].[ID]
	WHERE
		[InvoiceID] = @ID AND
		(
			[DocumentClass] IS NULL OR
			[DocumentClass] = dbo.adfGetClassByName('Pjm5.ServiceAssignment')
		)
	IF @@ERROR != 0
		RETURN 1

	EXEC @rv = adfDocumentCategoryCopy @Class, @ID, @NewID
	IF @rv != 0
		RETURN @rv

	EXEC @rv = adfDocumentContactCopy @Class, @ID, @NewID
	IF @rv != 0
		RETURN @rv

	UPDATE
		[Document]
	SET
		[RecurrencePatternID] = @RecurrenceID
	WHERE
		[Class] = @Class AND [ID] = @NewID

	IF @@ERROR != 0
		RETURN 1
	DECLARE @Occurrences TCount
	SELECT @Occurrences = [Occurrences] FROM [RecurrencePattern] WHERE [ID] = @RecurrenceID
	IF ISNULL(@Occurrences, 0) > 0
	BEGIN
		UPDATE
			[RecurrencePattern]
		SET
			[Occurrences] = @Occurrences - 1
		WHERE
			[ID] = @RecurrenceID
		IF @@ERROR != 0
			RETURN 1
	END
	
	IF @InvoiceState != @State
	BEGIN
		UPDATE
			[Invoice]
		SET
			[Invoice].[State] = @InvoiceState,
			[Invoice].[Modified] = DEFAULT,
			[Invoice].[ModifiedBy] = DEFAULT
		WHERE
			[Invoice].[ID] = @NewID

		IF @@ERROR != 0
			RETURN 1
	END
	
	DECLARE 
		@UserID TIdentifier,
		@InvoiceClass TClass,
		@ReminderPublishState TState,
		@ReminderPublishInterval TTimeSpan,
		@ReminderState TState,
		@ReminderInterval TTimeSpan
	
	SELECT
		@UserID = dbo.adfGetCurrentUserID(),
		@InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice'),
		@ReminderPublishState = dbo.fnPjm5GetUserInitialReminderState(@InvoiceClass, 'VA', @UserID),
		@ReminderPublishInterval = dbo.fnPjm5GetReminderInterval(@InvoiceClass, 'VA', @UserID),
		@ReminderState = dbo.fnPjm5GetUserInitialReminderState(@InvoiceClass, 'VP', @UserID),
		@ReminderInterval = dbo.fnPjm5GetReminderInterval(@InvoiceClass, 'VP', @UserID)

	EXEC @rv = pjm7InvoiceReminderCreate @NewID, 'VP',
		@NewDueDate, @ReminderState, @ReminderInterval
	IF @rv != 0
	BEGIN
		RETURN @rv
	END
	
	EXEC @rv = pjm7InvoiceReminderCreate @NewID, 'VA',
		@NewDate, @ReminderPublishState, @ReminderPublishInterval
	IF @rv != 0
	BEGIN
		RETURN @rv
	END
	
	RETURN 0
GO

GRANT EXECUTE ON pjm5InvoiceCreateRecurrence TO PUBLIC
GO   