IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5InvoiceOverdueBrowse')
	BEGIN
		PRINT 'Dropping Procedure pjm5InvoiceOverdueBrowse'
		DROP  Procedure  pjm5InvoiceOverdueBrowse
	END

GO

PRINT 'Creating Procedure pjm5InvoiceOverdueBrowse'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure pjm5InvoiceOverdueBrowse
	@ProjectCategoryID TIdentifier
AS
	SET NOCOUNT ON
	DECLARE 
		@Date TDateTime,
		@value TVariant,
	    @NationalCurrency varchar(8)
		
	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @value OUTPUT	
	SET @NationalCurrency = CAST(@value AS varchar(8))
	SET @Date = GETDATE()
	
	DECLARE @balance TABLE (
		[Class] smallint,
		[ID] int,
		[State] int,
		[FileAs] varchar(256),
		[SupplierCompanyID] int,
		[CustomerCompanyID] int,
		[CurrencyCode] varchar(3),
		[PaymentCurrencyPoint] int,
		[ProjectManagerID] int,
		[CompanyID] int,
		[CostCenterID] int,
		[d30] money,
		[d60] money,
		[d90] money,
		[Over90] money,
		[Total] money,
		[AverageDaysToPay] int,
		[AverageDaysToPayYTD] int,
		[SalesMTD] money,
		[SalesYTD] money,
		[SalesLY] money,
		[PaymentMTD] money,
		[PaymentYTD] money,
		[PaymentLY] money,
		[LifetimeSales] money
		)

	DECLARE @invoice TABLE (
		[ID] int,
		[DimensionID] int,
		[State] int,
		[Date] datetime,
		[DueDate] datetime,
		[CurrencyRate] money,
		[Total] money,
		[Payment] money
		)

	INSERT INTO @balance ([Class], [ID], [State], [FileAs], 
		[SupplierCompanyID], [CustomerCompanyID], [CurrencyCode], [PaymentCurrencyPoint],
		[ProjectManagerID], [CompanyID], [CostCenterID],
		[d30], [d60], [d90], [Over90], [Total],
		[AverageDaysToPay], [AverageDaysToPayYTD],
		[SalesMTD], [SalesYTD], [SalesLY],
		[PaymentMTD], [PaymentYTD], [PaymentLY],
		[LifetimeSales])
	SELECT
		[Project].[Class],
		[Project].[ID], 
		[Project].[State],
		[Project].[FileAs],
		[Project].[SupplierCompanyID], [Project].[CustomerCompanyID], [Project].[CurrencyCode], [Project].[PaymentCurrencyPoint],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CostCenterID],
		0,0,0,0,[Project].[BaseInitialBalance],0,0,0,0,0,0,0,0,0
	FROM 
		[Project]
	WHERE
		[Project].[State] IN (2,3,4)				 

	UPDATE
		@balance
	SET
		[Total] = [Total] + ISNULL((
			SELECT SUM([CreditMemo].[TotalWithVATBC])
			FROM [CreditMemo]
			WHERE
				[CreditMemo].[ProjectID] = [balance].[ID] AND
				[CreditMemo].[State] = 2
			), 0)
	FROM
		@balance AS [balance]

	INSERT INTO @invoice ([ID], [DimensionID], [State], [Date], [DueDate], [CurrencyRate], [Total], [Payment])
	SELECT
		[Invoice].[ID],
		[Project].[ID],
		[Invoice].[State],
		[Invoice].[Date],
		[Invoice].[DueDate],
		[Invoice].[BaseCurrencyRate],
		ISNULL([Invoice].[TotalWithVATBC], 0)- 
				ISNULL((SELECT 
					SUM(i.[TotalWithVATBC]) 
				FROM [AdvanceInvoice] INNER JOIN [Invoice] i
					ON i.[ID] = [AdvanceInvoice].[AdvanceInvoiceID]
				WHERE
					[AdvanceInvoice].[InvoiceID] = [Invoice].[ID])
				, 0),
		ISNULL(SUM(CASE WHEN [Project].[CurrencyCode] = @NationalCurrency
															THEN [PaymentDetail].[Value] / [Invoice].[BaseCurrencyRate]
															ELSE [PaymentDetail].[Value] * [Invoice].[BaseCurrencyRate]
														END), 0)
	FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Project].[ID] = [Invoice].[ProjectID]
		LEFT OUTER JOIN [PaymentDetail]
			ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]
		LEFT OUTER JOIN [Payment]
			ON [PaymentDetail].[PaymentID] = [Payment].[ID]
	WHERE
		[Invoice].[State] = 2  AND 
		[Project].[State] IN (2,3,4)			
	GROUP BY
		[Invoice].[ID],
		[Project].[ID],
		[Invoice].[State],
		[Invoice].[Date],
		[Invoice].[DueDate],
		[Invoice].[TotalWithVATBC],
		[Invoice].[BaseCurrencyRate]

	UPDATE
		@balance
	SET
		[d30] = CASE WHEN [invoice].[d30] < 0 THEN 0
					ELSE [invoice].[d30]
				END,
		[d60] = CASE WHEN [invoice].[d60] < 0 THEN 0
					ELSE [invoice].[d60]
				END,
		[d90] = CASE WHEN [invoice].[d90] < 0 THEN 0
					ELSE [invoice].[d90]
				END,
		[Over90] = CASE WHEN [invoice].[Over90] < 0 THEN 0
					ELSE [invoice].[Over90]
				END,
		[Total] = CASE WHEN ([balance].[Total] + [invoice].[Total]) < 0 THEN 0
					ELSE [balance].[Total] + [invoice].[Total]
				END
	FROM
		@balance AS [balance]
		INNER JOIN (
			SELECT
				[DimensionID],
				SUM(CASE 
					WHEN [DueDate] < @Date AND [DueDate] >= DATEADD(day, -30, @Date) 
						THEN ROUND([Total], 2) - ROUND([Payment], 2)
					ELSE 0 END) AS [d30],
				SUM(CASE 
					WHEN [DueDate] < DATEADD(day, -30, @Date) AND [DueDate] >= DATEADD(day, -60, @Date) 
						THEN ROUND([Total], 2) - ROUND([Payment], 2)
					ELSE 0 END) AS [d60],
				SUM(CASE 
					WHEN [DueDate] < DATEADD(day, -60, @Date) AND [DueDate] >= DATEADD(day, -90, @Date) 
						THEN ROUND([Total], 2) - ROUND([Payment], 2)
					ELSE 0 END) AS [d90],
				SUM(CASE 
					WHEN [DueDate] < DATEADD(day, -90, @Date) 
						THEN ROUND([Total], 2) - ROUND([Payment], 2)
					ELSE 0 END) AS [Over90],
				SUM(ROUND([Total], 2) - ROUND([Payment], 2)) AS [Total]
			FROM
				@invoice
			WHERE
				[Total] != [Payment]
			GROUP BY
				[DimensionID]
			) AS [invoice]
			ON [invoice].[DimensionID] = [balance].[ID]
			
	DECLARE
		@CurrentEmployeeID TIdentifier,
		@ViewAllProjects TBool,
		@ViewAllFinance TBool,
		@ViewFinance TBool

	SET @ViewAllProjects = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects'))
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @ViewFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance'))
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	
	SELECT DISTINCT
		[balance].[Class],
		[balance].[ID], 
		-1 AS [State],
		[balance].[FileAs],
		[balance].[SupplierCompanyID], [balance].[CustomerCompanyID], [balance].[CurrencyCode], [balance].[PaymentCurrencyPoint],
		[balance].[ProjectManagerID],
		[balance].[CompanyID],
		[balance].[CostCenterID],
		[Company].[ManagerEmployeeID],
		[balance].[d30] + [balance].[d60] + [balance].[d90] + [balance].[Over90] AS [Overdue],
		[balance].[d30],
		[balance].[d60],
		[balance].[d90],
		[balance].[Over90],
		[balance].[Total],
		[Project].[CreatedBy],
		[Project].[Created],
		[Project].[ModifiedBy],
		[Project].[Modified],
		[Project].[Comments]
	FROM
		@balance AS [balance]
		INNER JOIN [Company]
			ON [Company].[ID] = [balance].[CompanyID]
		INNER JOIN [Project]
			ON [Project].[ID] = [balance].[ID]
		LEFT OUTER JOIN [adfvwDocumentCategory]
			ON ([Project].[Class] = [adfvwDocumentCategory].[DocumentClass] AND [Project].[ID] = [adfvwDocumentCategory].[DocumentID])
	WHERE 
		(
			(@ViewAllFinance = 1) OR
			(
				@ViewFinance = 1 AND
				(
					@ViewAllProjects = 1 OR
					[Company].[ManagerEmployeeID] = @CurrentEmployeeID OR 
					[balance].[ProjectManagerID] = @CurrentEmployeeID OR
					dbo.fnPjm5HasFinansDataAccess([Project].[ID], @CurrentEmployeeID, NULL, NULL) = 1
				)
			)
		) 
		AND
		[balance].[Total] > 0.00
		AND
		(
			@ProjectCategoryID is NULL
			OR ISNULL([adfvwDocumentCategory].[CategoryID], 0) = ISNULL(@ProjectCategoryID, 0)
		)
				
		

RETURN 0
GO

GRANT EXEC ON pjm5InvoiceOverdueBrowse TO PUBLIC

GO
