IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6IssueStatistics]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6IssueStatistics'
		DROP PROCEDURE [dbo].[pjm6IssueStatistics]
	END
GO

PRINT 'Creating procedure pjm6IssueStatistics'
GO

/******************************************************************************
**		File: pjm6IssueStatistics.sql
**		Name: pjm6IssueStatistics
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: MAV
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm6IssueStatistics]
	@CostCenter TCode,
	@Week INT,
	@Year INT
AS


	SET NOCOUNT ON
	IF @Week IS NULL SET @Week = DATEPART(week, GETDATE())
	IF @Year IS NULL SET @Year = YEAR(GETDATE())
	
	DECLARE @CostCenterID INT
	SELECT @CostCenterID = [ID] FROM [CostCenter] WHERE [Code] = @CostCenter
	
	;WITH 
	[Executed] ([EmployeeID], [Count]) AS
	(
		SELECT
			[Issue].[EmployeeID],
			COUNT(DISTINCT [Issue].[ID])
		FROM
			[Issue]
			INNER JOIN [Project]
				ON [Project].[ID] = [Issue].[ProjectID]
			INNER JOIN [Transition]
				ON [Transition].[Class] = [Issue].[Class] AND
					[Transition].[DocumentID] = [Issue].[ID] AND
					YEAR([Transition].[Created]) = @Year AND
					DATEPART(week, [Transition].[Created]) = @Week
			INNER JOIN [TransitionTemplate]
				ON [TransitionTemplate].[ID] = [Transition].[TransitionTemplateID] AND
					[TransitionTemplate].[ToState] = 4 AND
					[TransitionTemplate].[FromState] != 4
		WHERE
			[Issue].[State] IN (4, 5) AND
			ISNULL([Project].[CostCenterID], -1) = ISNULL(@CostCenterID, -1)
		GROUP BY
			[Issue].[EmployeeID]
	),
	[Assigned] ([EmployeeID], [Count]) AS
	(
		SELECT
			[Issue].[EmployeeID],
			COUNT(DISTINCT [Issue].[ID])
		FROM
			[Issue]
			INNER JOIN [Project]
				ON [Project].[ID] = [Issue].[ProjectID]
			INNER JOIN [Transition]
				ON [Transition].[Class] = [Issue].[Class] AND
					[Transition].[DocumentID] = [Issue].[ID] AND
					YEAR([Transition].[Created]) = @Year AND
					DATEPART(week, [Transition].[Created]) = @Week
			INNER JOIN [TransitionTemplate]
				ON [TransitionTemplate].[ID] = [Transition].[TransitionTemplateID] AND
					[TransitionTemplate].[ToState] = 3 AND
					[TransitionTemplate].[FromState] != 3 
		WHERE
			[Issue].[State] = 3 AND
			ISNULL([Project].[CostCenterID], -1) = ISNULL(@CostCenterID, -1)
		GROUP BY
			[Issue].[EmployeeID]
	),
	[Postponed] ([EmployeeID], [Count]) AS
	(
		SELECT
			[Issue].[EmployeeID],
			COUNT(DISTINCT [Issue].[ID])
		FROM
			[Issue]
			INNER JOIN [Project]
				ON [Project].[ID] = [Issue].[ProjectID]
		WHERE
			[Issue].[State] = 6 AND
			ISNULL([Project].[CostCenterID], -1) = ISNULL(@CostCenterID, -1)
		GROUP BY
			[Issue].[EmployeeID]
	)
	SELECT
		[Employee].[Initials],
		[Employee].[FileAs],
		ISNULL([Executed].[Count], 0) AS [Executed],
		ISNULL([Assigned].[Count], 0) AS [Assigned],
		ISNULL([Postponed].[Count], 0) AS [Postponed]
	FROM
		[Employee]
		LEFT OUTER JOIN [Executed]
			ON [Executed].[EmployeeID] = [Employee].[ID]
		LEFT OUTER JOIN [Assigned]
			ON [Assigned].[EmployeeID] = [Employee].[ID]
		LEFT OUTER JOIN [Postponed]
			ON [Postponed].[EmployeeID] = [Employee].[ID]
	WHERE
		COALESCE([Executed].[Count], [Assigned].[Count], [Postponed].[Count]) IS NOT NULL
	ORDER BY
		[Employee].[Initials]
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm6IssueStatistics] TO PUBLIC
GO
 