IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5MeetingRequestSendUpdate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5MeetingRequestSendUpdate'
		DROP PROCEDURE [dbo].[pjm5MeetingRequestSendUpdate]
	END
GO

PRINT 'Creating procedure pjm5MeetingRequestSendUpdate'
GO

/******************************************************************************
**		File: pjm5MeetingRequestSendUpdate.sql
**		Name: pjm5MeetingRequestSendUpdate
**		Desc: sends update to attendees of the meeting
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Dmitry.Kolchev
**		Date: 10/12/2006 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		18.04.13	SOV				. -   
*******************************************************************************/
CREATE PROCEDURE pjm5MeetingRequestSendUpdate @ID TIdentifier

AS
	SET NOCOUNT ON
	DECLARE @EmployeeID TIdentifier,
		@ProjectID TIdentifier, @IsManager TBool, @IsManagerAssistant TBool
	
	SELECT 
		@ProjectID = [ProjectID] 
	FROM 
		[MeetingRequest] 
	WHERE 
		[ID]=@ID

	SET @EmployeeID = dbo.adfGetCurrentEmployeeID();
	SET @IsManager = dbo.fnPjm5IsProjectManager(@ProjectID, @EmployeeID)
	SET @IsManagerAssistant = dbo.fnPjm7IsManagerAssistant(@ProjectID, @EmployeeID)
	
	IF @EmployeeID NOT IN (SELECT [OriginatorEmployeeID] FROM [MeetingRequest] WHERE [ID]=@ID) AND
		@IsManager = 0 AND @IsManagerAssistant = 0
	BEGIN
		RAISERROR('#accessdenied', 16, -1);
		RETURN 1; 
	END
	
	UPDATE [MeetingRequest] SET [SendUpdate] = 0 WHERE [ID] = @ID
	
	EXEC pjm5PostDocumentChangeNotificationEvent 'MeetingRequestUpdated', 'Pjm5.MeetingRequest', @ID, NULL
	
	RETURN 0
GO

GRANT EXECUTE ON pjm5MeetingRequestSendUpdate TO PUBLIC
GO 