﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7QuickReminderForUserCreate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7QuickReminderForUserCreate'
		DROP PROCEDURE [dbo].[pjm7QuickReminderForUserCreate]
	END
GO

PRINT 'Creating procedure pjm7QuickReminderForUserCreate'
GO

/******************************************************************************
**		File: pjm7QuickReminderForUserCreate.sql
**		Name: pjm7QuickReminderForUserCreate
**		Desc: Процедура создает напоминание для пользователя через быстрые напоминания
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      @QuickReminderType:				-----------
**		0 - Сегодня
**		1 - Завтра
**		2 - Текущая неделя
**		3 - Следующая неделя
**
**		Auth: 
**		Date: 24.05.2012 17:30:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		19.11.12	SAP				Исправление напоминаний на следующую неделю
**									теперь появляется в понедельник,а не в пятницу
*******************************************************************************/
CREATE PROCEDURE [pjm7QuickReminderForUserCreate]
	@DocumentClass TClass,
	@DocumentID TIdentifier,
	@UserID TIdentifier,
	@QuickReminderType int,								--Тип быстрого напоминания
	@AutoExecute TBool = 0								--Признак автоматического вызова процедуры
AS
	SET NOCOUNT ON
	SET DATEFIRST 1

	DECLARE
		@ReminderEventTime		TDate,
		@ReminderDescription	TName,
		@Time					int,
		@WorkWeek				TVariant,
		@MaxDayOfWorkWeek		int,						--Номер последнего рабочего дня в неделе (отсчет от 0)
		@daymask				int,
		@CurrentDayInWeek		int,
		@rv						int,
		@Lang					TLanguage

	SET @Lang = dbo.adfGetLanguage()
	SELECT @Time = -dbo.fnPjm5GetReminderInterval(@DocumentClass, 'UR', @UserID)

	SELECT @WorkWeek = Value FROM [F41AB0F8-FDF0-4FAD-9B71-8F17B4A51B53] WHERE [Name]='WorkDaysOfWeek' AND [Group]='Pjm5'
	SET @daymask = CAST(@WorkWeek as int)
	SET @CurrentDayInWeek = (DATEPART(WEEKDAY,GETDATE())+@@DATEFIRST-2)%7

	DECLARE 
		@index	int,
		@bit	int,
		@temp	int
			
	--Код определяет последний рабочий день недели, через анализ битов
	SET @index = 0
	SET @MaxDayOfWorkWeek = 0
	WHILE @index < 7
	BEGIN
		SET @bit = @daymask & (1 * power(2, @index))
		SET @temp = (@index + 7 - @@DATEFIRST) % 7
		if(@bit != 0 AND @temp > @MaxDayOfWorkWeek)
			SET @MaxDayOfWorkWeek = @temp
		SET @index = @index + 1
	END
	
	
	IF @QuickReminderType = 0
	BEGIN
		SET @ReminderEventTime = DATEADD(minute, @Time, CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME))
		IF @ReminderEventTime <= GETDATE()
			SET @ReminderEventTime = DATEADD(minute, 1, @ReminderEventTime)
	END
	ELSE IF @QuickReminderType = 1
	BEGIN
		SET @ReminderEventTime = DATEADD(day, 1 ,DATEADD(minute, @Time, CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)))
	END
	ELSE IF @QuickReminderType = 2
	BEGIN
		SET	@ReminderEventTime = DATEADD(minute, @Time, DATEADD(day, @MaxDayOfWorkWeek - @CurrentDayInWeek, CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)))
	END
	ELSE IF @QuickReminderType = 3
	BEGIN
		SET	@ReminderEventTime = DATEADD(minute, @Time, DATEADD(day, /*@MaxDayOfWorkWeek*/0 - @CurrentDayInWeek + 7, CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)))
	END

	IF @ReminderEventTime <= GETDATE()
				SET @ReminderEventTime = DATEADD(minute, 1, GETDATE())
	
	IF @Lang = 'ru'
		SET @ReminderDescription = 'К исполнению'
	ELSE IF @Lang = 'en'
		SET @ReminderDescription = 'To execution'

	IF (NOT EXISTS(
		SELECT *FROM 
			[Reminder] 
			INNER JOIN [UserReminder]
				ON [Reminder].[ID] = [UserReminder].[ReminderID]
		WHERE 
			[DocumentClass] = @DocumentClass AND [DocumentID] = @DocumentID AND [Subtype] = 'UR'
			AND [EventTime] = @ReminderEventTime
			AND [UserReminder].[State] = 1 AND [UserReminder].[OriginalInterval] = 0 AND 
			[UserReminder].[NextInterval] = 0 AND [UserReminder].[Description] = @ReminderDescription))
	BEGIN
	
	
	
		EXEC @rv = pjm7ReminderForUserCreate	@DocumentClass,
												@DocumentID, 
												@UserID, 
												'UR',
												@ReminderEventTime,
												1,
												0,
												@ReminderDescription
		IF @rv != 0
			RETURN 1

	END
	SET DATEFIRST 7

	RETURN 0
GO

GRANT EXECUTE ON [pjm7QuickReminderForUserCreate] TO PUBLIC
GO