/*=====================================================================*/
/* Stored procedure:       */
/*=====================================================================*/
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[pjm5SubscriptionEventCreate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[pjm5SubscriptionEventCreate]
go

create procedure pjm5SubscriptionEventCreate
	@SubscriptionTypeID TIdentifier,
	@DocumentClass		TClass,
	@DocumentID			TIdentifier,
	@ContainerClass		TClass,
	@ContainerID		TIdentifier,
	@UserID				TIdentifier,
	@Value				int,
	@OwnerUserID		TIdentifier
as

DECLARE 
	@State						TState,
	@SubscriptionRuleID			TIdentifier,
	@ExternalSubscriptionRule	TBool,
	@NotificationWayID			TIdentifier,
	@RuleUserID					TIdentifier,
	@RuleEmployeeID				TIdentifier,
	@SpecialCase bit,
	@IsAssignCompanyManagerEvent	TBool,
	@res int,
	@doc int
	
SET NOCOUNT ON

SELECT @State = dbo.fnPjm5GetInitialEventState()
IF @State IS NULL
BEGIN
	RETURN 1
END

SELECT @OwnerUserID = [ModifiedBy]
FROM [Document] WHERE [Class] = @DocumentClass AND [ID] = @DocumentID

SET @SpecialCase = 0
IF (@SubscriptionTypeID =
	dbo.fnPjm5GetSubscriptionTypeByCode('ExclusionFromProjectManager') OR
	@SubscriptionTypeID =
	dbo.fnPjm5GetSubscriptionTypeByCode('ExclusionFromProject') OR
	@SubscriptionTypeID =
	dbo.fnPjm5GetSubscriptionTypeByCode('AssignProjectManager') OR
	@SubscriptionTypeID =
	dbo.fnPjm5GetSubscriptionTypeByCode('AssignOnProject') OR
	@SubscriptionTypeID =
	dbo.fnPjm5GetSubscriptionTypeByCode('AssignCompanyManager') OR
	@SubscriptionTypeID =
	dbo.fnPjm5GetSubscriptionTypeByCode('ExclusionFromCompanyManager'))
BEGIN
	SET @SpecialCase = 1
END

SET @IsAssignCompanyManagerEvent = 0

IF (@SubscriptionTypeID = dbo.fnPjm5GetSubscriptionTypeByCode('AssignCompanyManager'))
	SET @IsAssignCompanyManagerEvent = 1


BEGIN TRANSACTION
	
DECLARE events CURSOR LOCAL FORWARD_ONLY READ_ONLY FOR
SELECT
	[Subscription].[SubscriptionRuleID],
	[SubscriptionRuleNotificationWay].[NotificationWayID],
	[SubscriptionRule].[UserID],
	[Employee].[ID],
	[SubscriptionRule].[ExternalInitiator]
FROM
	[Subscription]
	INNER JOIN [SubscriptionRuleNotificationWay]
		ON [SubscriptionRuleNotificationWay].[SubscriptionRuleID] = [Subscription].[SubscriptionRuleID]
	INNER JOIN [SubscriptionType]
		ON [SubscriptionType].[ID] = [Subscription].[SubscriptionTypeID]
	INNER JOIN [SubscriptionRule]
		ON [SubscriptionRule].[ID] = [Subscription].[SubscriptionRuleID]
	INNER JOIN [Employee]
		ON [Employee].[UserID] = [SubscriptionRule].[UserID]
WHERE
	[Subscription].[SubscriptionTypeID] = @SubscriptionTypeID AND
	[SubscriptionRule].[State] = 1

OPEN events

FETCH NEXT FROM events INTO @SubscriptionRuleID, @NotificationWayID, @RuleUserID, @RuleEmployeeID, @ExternalSubscriptionRule
WHILE @@FETCH_STATUS = 0
BEGIN
	IF ((@RuleUserID != @OwnerUserID OR @ExternalSubscriptionRule = 1) AND
		(@UserID IS NULL OR @UserID = @RuleUserID) AND NOT(@IsAssignCompanyManagerEvent = 1 AND @UserID IS NULL))
	BEGIN
		SET @res = dbo.fnPjm5CheckRuleDocumentConstraint(@ContainerClass,
						@ContainerID, @SubscriptionRuleID, @RuleEmployeeID)
		IF (@SpecialCase = 1 OR @res = 1)
		BEGIN
			INSERT INTO [Event]
			([State], [SubscriptionTypeID], [DocumentClass], [DocumentID],
			 [ContainerClass], [ContainerID], [Value],
			 [SubscriptionRuleID], [NotificationWayID], [AlertTime])	
			VALUES
			(@State, @SubscriptionTypeID, @DocumentClass, @DocumentID,
			 @ContainerClass, @ContainerID, @Value,
			 @SubscriptionRuleID, @NotificationWayID, GETDATE())
			IF @@ERROR != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
		END
	END
	FETCH NEXT FROM events INTO @SubscriptionRuleID, @NotificationWayID, @RuleUserID, @RuleEmployeeID, @ExternalSubscriptionRule
END

CLOSE events
DEALLOCATE events

COMMIT TRANSACTION

return 0

go

grant execute on [dbo].[pjm5SubscriptionEventCreate] to [public]
go 