IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ExportAppointment')
	BEGIN
		PRINT 'Dropping Procedure ExportAppointment'
		DROP  Procedure  ExportAppointment
	END

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'PjmSyncExportAppointment')
	BEGIN
		PRINT 'Dropping Procedure PjmSyncExportAppointment'
		DROP  Procedure  PjmSyncExportAppointment
	END

GO

PRINT 'Creating Procedure PjmSyncExportAppointment'
GO

--------------------------------------------------------------------------------------
CREATE Procedure PjmSyncExportAppointment
	@DeviceID varchar(40),
	@DaysBeforeThis int,
	@TimeStamp bigint,
	@CreateDeleted BIT
	
AS
	SET NOCOUNT ON
	DECLARE @EmployeeID Tidentifier

	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()

DECLARE @t TABLE
(
	[ID] TIdentifier,
	[Class] TClass,
	[ItemID] TCode,

	[Body] TNotes,
	[Start] TDate,
	[End] TDate,
	[Subject] varchar(512),
	[ReminderMinutesBeforeStart] TTimeSpan,
	[ReminderSet] varchar(5),
	[Categories] TNotes,
	[Location] TName,
	[Timestamp] bigint
)

INSERT INTO @t
(	[ID],
	[Class],
	[ItemID],

	[Body],
	[Start],
	[End],
	[Subject],
	[ReminderMinutesBeforeStart],
	[ReminderSet],
	[Categories],
	[Location],
	[Timestamp]  
) SELECT [ID],
	[Class],
	[ItemID],
	[Body],
	[Start],
	[End],
	[Subject],
	[ReminderMinutesBeforeStart],
	[ReminderSet],
	[Categories],
	[Location],
	[Timestamp]
	FROM
dbo.PjmSyncExportAppointmentFunction(@DeviceID,
	@DaysBeforeThis,
	@TimeStamp,
	@CreateDeleted)
	
	SELECT [ID],
	[Class],
	[ItemID],

	[Body],
	[Start],
	[End],
	[Subject],
	[ReminderMinutesBeforeStart],
	[ReminderSet],
	[Categories],
	[Location],
	[Timestamp]
	FROM @t


SELECT 
		[Table].[ID],
		[Table].[Class],
		ISNULL([Employee].[FirstName] + ISNULL(' ' + [Employee].[LastName], ''), [Employee].[FileAs]) AS [Name],
		COALESCE([Email].[Email],[Email2].[Email],[Email3].[Email], ' ') AS [Address]
	
	FROM 
		@t AS [Table]
		INNER JOIN [Attendee]
			ON [Table].[ID] = [Attendee].[MeetingRequestID] AND
				[Table].[Class]= dbo.adfGetClassByName('Pjm5.MeetingRequest')
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Attendee].[EmployeeID]
		LEFT OUTER JOIN [Email]
			ON [Email].[BusinessCardID] = [Employee].[ID] AND 
			[Email].[BusinessCardClass] = [Employee].[Class] AND
			[Email].[EmailTypeID] = 1
		LEFT OUTER JOIN [Email] AS [Email2]
			ON [Email2].[BusinessCardID] = [Employee].[ID] AND 
			[Email2].[BusinessCardClass] = [Employee].[Class] AND
			[Email2].[EmailTypeID] = 2
		LEFT OUTER JOIN [Email] AS [Email3]
			ON [Email3].[BusinessCardID] = [Employee].[ID] AND 
			[Email3].[BusinessCardClass] = [Employee].[Class] AND
			[Email3].[EmailTypeID] = 3
	WHERE 
		([Table].[TimeStamp] > @TimeStamp OR [Table].[ItemID] IS NULL OR @CreateDeleted=1)
		AND
		[Employee].[ID]!=@EmployeeID
UNION

SELECT 
	[Table].[ID],
	[Table].[Class],
	ISNULL([Employee].[FirstName] + ISNULL(' ' + [Employee].[LastName], ''), [Employee].[FileAs]) AS [Name],
	COALESCE([Email].[Email],[Email2].[Email],[Email3].[Email], ' ') AS [Address]
	
	FROM 
		@t AS [Table] INNER JOIN [MeetingRequest]
			ON [Table].[ID] = [MeetingRequest].[ID]
			AND [Table].[Class]= dbo.adfGetClassByName('Pjm5.MeetingRequest')
		INNER JOIN [Employee]
			ON [MeetingRequest].[OriginatorEmployeeID] = [Employee].[ID]
		LEFT OUTER JOIN [Email]
			ON [Email].[BusinessCardID] = [Employee].[ID] AND 
			[Email].[BusinessCardClass] = [Employee].[Class] AND
			[Email].[EmailTypeID] = 1
		LEFT OUTER JOIN [Email] AS [Email2]
			ON [Email2].[BusinessCardID] = [Employee].[ID] AND 
			[Email2].[BusinessCardClass] = [Employee].[Class] AND
			[Email2].[EmailTypeID] = 2
		LEFT OUTER JOIN [Email] AS [Email3]
			ON [Email3].[BusinessCardID] = [Employee].[ID] AND 
			[Email3].[BusinessCardClass] = [Employee].[Class] AND
			[Email3].[EmailTypeID] = 3
	WHERE ([Table].[TimeStamp] > @TimeStamp OR [Table].[ItemID] IS NULL OR @CreateDeleted=1) AND 
			[Employee].[ID]!=@EmployeeID

RETURN 0
GO

GRANT EXEC ON PjmSyncExportAppointment TO PUBLIC
GO
