
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[PjmSyncExportAppointmentFunction]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function PjmSyncExportAppointmentFunction'
		DROP FUNCTION [dbo].[PjmSyncExportAppointmentFunction]
	END

GO

PRINT 'Creating function PjmSyncExportAppointmentFunction'
GO

CREATE FUNCTION PjmSyncExportAppointmentFunction (
				@DeviceID varchar(40),
				@DaysBeforeThis int,
				@TimeStamp bigint,
				@CreateDeleted BIT)

RETURNS @Result TABLE ([ID] TIdentifier, 
					[Class] TClass,
					[ItemID] TCode,
					[Body] TNotes,
					[Start] TDate,
					[End] TDate,
					[Subject] varchar(512),
					[ReminderMinutesBeforeStart] TTimeSpan,
					[ReminderSet] varchar(5),
					[Categories] TNotes,
					[Location] TName,
					[Timestamp] bigint)
AS
BEGIN

DECLARE @EmployeeID Tidentifier

	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()

DECLARE @t TABLE
(
	[ID] TIdentifier, 
	[Class] TClass,
	[ItemID] TCode,
	[Body] TNotes,
	[Start] TDate,
	[End] TDate,
	[Subject] varchar(512),
	[ReminderMinutesBeforeStart] TTimeSpan,
	[ReminderSet] varchar(5),
	[Categories] TNotes,
	[Location] TName,
	[Timestamp] bigint
)

INSERT INTO @t
(	[ID],
	[Class],
	[ItemID],

	[Body],
	[Start],
	[End],
	[Subject],
	[ReminderMinutesBeforeStart],
	[ReminderSet],
	[Categories],
	[Location],
	[Timestamp]  
)

SELECT 
	[MeetingRequest].[ID],
	[MeetingRequest].[Class],
	[ExternalLink].[ItemID],

	REPLACE(REPLACE([MeetingRequest].[Comments], CHAR(13) + CHAR(10), CHAR(10)), CHAR(10), CHAR(13) + CHAR(10)),
	[MeetingRequest].[StartTime] AS [Start],
	DATEADD(minute,[MeetingRequest].[Duration],[MeetingRequest].[StartTime]),
	[MeetingRequest].[FileAs]+ ISNULL('('+ [Project].[Number]+')', ''),
	[UserReminder].[OriginalInterval] AS [ReminderMinutesBeforeStart],
	CASE [UserReminder].[State] WHEN 1 THEN 'true' ELSE 'false' END ,
	ISNULL([dbo].[fnPjm5CategoriesConcat] ([MeetingRequest].[Class], [MeetingRequest].[ID])+', ','')+ 'PjmSync',
	[MeetingRequest].[Location],
	CAST([MeetingRequest].[Timestamp] as bigint)
FROM
	[MeetingRequest]	
	LEFT OUTER JOIN [Project]
		ON [Project].[ID] = [MeetingRequest].[ProjectID]
	LEFT OUTER JOIN [Attendee]
		ON [Attendee].[MeetingRequestID] = [MeetingRequest].[ID] 			
	LEFT OUTER JOIN [Reminder]
		ON [Reminder].[DocumentClass] = [MeetingRequest].[Class] AND
		[Reminder].[DocumentID] = [MeetingRequest].[ID]
	LEFT OUTER JOIN [UserReminder]
		ON [Reminder].[ID] = [UserReminder].[ReminderID] AND
		[UserReminder].[UserID] = dbo.adfGetCurrentUserID()	
	LEFT OUTER JOIN [ExternalLink]
		ON [ExternalLink].[DeviceID] = @DeviceID AND
			[ExternalLink].[DocumentID] = [MeetingRequest].[ID] AND
			 [ExternalLink].[DocumentClass] = [MeetingRequest].[Class]

WHERE DATEADD(minute,[MeetingRequest].[Duration],[MeetingRequest].[StartTime]) >= DATEADD(day,-@DaysBeforeThis,GETDATE()) AND 
	([Attendee].[EmployeeID] = @EmployeeID OR
		[MeetingRequest].[OriginatorEmployeeID] = @EmployeeID)
		AND [MeetingRequest].[State] NOT IN (3, 4)
		
			
UNION

SELECT 
	[TimeEntry].[ID],
	[TimeEntry].[Class],
	[ExternalLink].[ItemID],

	REPLACE(REPLACE([TimeEntry].[Comments], CHAR(13) + CHAR(10), CHAR(10)), CHAR(10), CHAR(13) + CHAR(10)) ,
	[TimeEntry].[StartTime] AS [Start],
	DATEADD(minute,[TimeEntry].[Duration],[TimeEntry].[StartTime]) AS [End],
	[TimeEntry].[FileAs]+ISNULL(' ('+ [Project].[Number]+')', '') AS [Subject],
	[UserReminder].[OriginalInterval] AS [ReminderMinutesBeforeStart],
	CASE [UserReminder].[State] WHEN 1 THEN 'true' ELSE 'false' END AS [ReminderSet],
	ISNULL([dbo].[fnPjm5CategoriesConcat] ([TimeEntry].[Class], [TimeEntry].[ID])+', ','')+ 'PjmSync' AS [Categories],
	NULL,
	CAST([TimeEntry].[Timestamp] as bigint) as [Timestamp]
FROM
	[TimeEntry]
	INNER JOIN [Employee]
		ON [TimeEntry].[EmployeeID] = [Employee].[ID]
	LEFT OUTER JOIN [Project]
		ON [Project].[ID] = [TimeEntry].[ProjectID]			
	LEFT OUTER JOIN [Reminder]
		ON [Reminder].[DocumentClass] = [TimeEntry].[Class] AND
		[Reminder].[DocumentID] = [TimeEntry].[ID]
	LEFT OUTER JOIN [UserReminder]
		ON [Reminder].[ID] = [UserReminder].[ReminderID] AND
		[UserReminder].[UserID] = dbo.adfGetCurrentUserID()
	LEFT OUTER JOIN [ExternalLink]
		ON [ExternalLink].[DeviceID] = @DeviceID AND
			[ExternalLink].[DocumentID] = [TimeEntry].[ID] AND
			 [ExternalLink].[DocumentClass] = [TimeEntry].[Class]

WHERE 
	DATEADD(minute,[TimeEntry].[Duration],[TimeEntry].[StartTime]) >= DATEADD(day,-@DaysBeforeThis,GETDATE()) AND
	[TimeEntry].[EmployeeID]=@EmployeeID

INSERT INTO @Result
(
	[ID],
	[Class],
	[ItemID],
	[Body],
	[Start],
	[End],
	[Subject],
	[ReminderMinutesBeforeStart],
	[ReminderSet],
	[Categories],
	[Location],
	[Timestamp]  
)
SELECT
	[ID],
	[Class],
	[ItemID],

	[Body],
	[Start],
	[End],
	[Subject],
	[ReminderMinutesBeforeStart],
	[ReminderSet],
	[Categories],
	[Location],
	[Timestamp]  
FROM @t
WHERE [TimeStamp] > @TimeStamp OR [ItemID] IS NULL OR @CreateDeleted=1

UNION

SELECT 
	-[ExternalLink].[DocumentID],
	[ExternalLink].[DocumentClass],
	[ExternalLink].[ItemID],

	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL
	FROM [ExternalLink]
	LEFT OUTER JOIN @t AS [Table]
	ON [Table].[Class]=[ExternalLink].[DocumentClass] AND
		[Table].[ID]=[ExternalLink].[DocumentID]
WHERE [Table].[ItemID] IS NULL AND 
		[ExternalLink].[DeviceID] = @DeviceID AND
	[ExternalLink].[DocumentClass] IN (dbo.adfGetClassByName('Pjm5.TimeEntry'),dbo.adfGetClassByName('Pjm5.MeetingRequest'))

UNION

SELECT 
		-[ExternalLink].[DocumentID],
		[ExternalLink].[DocumentClass],
		[ExternalLink].[ItemID],
		NULL,
		NULL,
		NULL,
		NULL,
		NULL,
		NULL,
		NULL,
		NULL,
		NULL	
	FROM 
		[ExternalLink]
			INNER JOIN [MeetingRequest]		
			ON [MeetingRequest].[Class] = [ExternalLink].[DocumentClass] AND
				[MeetingRequest].[ID] = [ExternalLink].[DocumentID]	
	WHERE DATEADD(minute,[MeetingRequest].[Duration],[MeetingRequest].[StartTime])< DATEADD(day,-@DaysBeforeThis,GETDATE()) AND
			@DeviceID = [ExternalLink].[DeviceID]

	UNION

	SELECT 
		-[ExternalLink].[DocumentID],
		[ExternalLink].[DocumentClass],
		[ExternalLink].[ItemID],
		NULL,
		NULL,
		NULL,
		NULL,
		NULL,
		NULL,
		NULL,
		NULL,
		NULL
	FROM 
		[ExternalLink]
			INNER JOIN [TimeEntry]		
			ON [TimeEntry].[Class] = [ExternalLink].[DocumentClass] AND
				[TimeEntry].[ID] = [ExternalLink].[DocumentID]	
	WHERE DATEADD(minute,[Duration],[TimeEntry].[StartTime]) < DATEADD(day,-@DaysBeforeThis,GETDATE()) AND
			@DeviceID = [ExternalLink].[DeviceID]	

	RETURN
END
GO