IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5ProjectCreate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5ProjectCreate'
		DROP PROCEDURE [dbo].[pjm5ProjectCreate]
	END
GO

PRINT 'Creating procedure pjm5ProjectCreate'
GO

/******************************************************************************
**		File: pjm5ProjectCreate.sql
**		Name: pjm5ProjectCreate
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 11:01:32
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		30.09.09	syv				  BankAccountID
**
**		6.05.10		KOV				  ApplyVAT,     INSERT
**
**		7.05.10		KOV				 @PaymentCurrencyPoint    
**		13.11.10	SYV				  [GroupingAdvanceCalculations]
**		24.11.10	SYV				  [StatementCurrencyPoint]
**		22.04.11	SYV				 GroupingAdvanceCalculations   int
**		04.02.13	SAP				  Color
**		22.02.13	SAP				  OPENXML
**		17.04.13	SOV				  . -  
**		13.06.13	SOV				  -  
**		05.07.13	SOV				 , ,     
**									   
**		18.07.13	MAB				     
**		27.08.13	BAO				  [GroupByProjects]
*******************************************************************************/
CREATE PROCEDURE [pjm5ProjectCreate]  
@Xml	XML
AS
	DECLARE @State TState,
			@ID TIdentifier,
			@Date TDate,
			@Number TCode,
			@FileAs TName,
			@SupplierCompanyID TIdentifier,
			@CustomerCompanyID TIdentifier,
			@ResponsiblePersonEmployeeID TIdentifier,
			@PriorityID TIdentifier,
			@StartDate TDate,
			@DueDate TDate,
			@EndDate TDate,
			@CurrencyCode TCode3,
			@CostCenterID TIdentifier,
			@ManHour TAmount,
			@Budget TMoney,
			@ContractNumber TCode,
			@ContractDate TDate,
			@ContractSubject TName,
			@ServiceLevelID TIdentifier,
			@WSSDocumentsURL THref,
			@Comments TNotes,			
			@AssignmentState TState,
			@AssignmentID TIdentifier,
			@EmployeeName TName,
			@QualificationID TIdentifier,
			@StandardRate TMoney,
			@OvertimeRate TMoney,
			@rv int,
			@value TVariant,
			@InvoiceExpirationPeriod TCount,
			@InvoiceExpirationPeriodType TIdentifier,
			@ProjectTypeID TIdentifier,
			@PaymentCurrencyPoint TIdentifier,
			@GroupCalculationLines TBool,
			@Flag TFlag,
			@ProjectManagerEmployeeID TIdentifier,
			@CustomerFinanceManagerID TIdentifier,
			@StatementCurrencyPoint TIdentifier,
			@UseSubProjects TBool,
			@Color TColor,
			@GroupByProjects TBool
	
	SET NOCOUNT ON

	IF @Xml.value('(/pjm5ProjectGet/Project/ParentProjectID)[1]','int') IS NOt NULL
	BEGIN 
		EXEC @ID = pjm7SubProjectCreate @Xml
	END
	ELSE
	BEGIN
	SET @State = dbo.adfwfGetInitialState('e64c30d7-1ade-4f9e-8bde-c35357ea6e8a')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	SELECT
		@ManHour = @Xml.value('(/pjm5ProjectGet/Project/ManHour)[1]','decimal(18,4)'), 
		@Budget = @Xml.value('(/pjm5ProjectGet/Project/Budget)[1]','money'),
		@CurrencyCode = @Xml.value('(/pjm5ProjectGet/Project/CurrencyCode)[1]','char(3)'),
		@ProjectTypeID = @Xml.value('(/pjm5ProjectGet/Project/ProjectTypeID)[1]','int'),
		@Flag = @Xml.value('(/pjm5ProjectGet/Project/Flag)[1]','int')
				
	IF @Flag IS NULL
	BEGIN
		SET @Flag = 0
	END
		
	IF @Budget IS NOT NULL AND @Budget < 0
	BEGIN
		RAISERROR('#BudgetIsInvalid', 18, -1)
		RETURN 1
	END
	IF @ManHour IS NOT NULL AND @ManHour < 0
	BEGIN
		RAISERROR('#ManHourIsInvalid', 18, -1)
		RETURN 1
	END
	
	-- Global parameters
	DECLARE @RoundInterval int,
			@RoundingMode int,
			@DefaultMoneyScale TCount,
			@StatementPrintCurrency TCount,
			@InvoicePrintCurrency TCount,
			@FacturePrintCurrency TCount,
			@ApplyVAT TBool,
			@CheckTaskWorkOverdraft TBool,
			@GroupingAdvanceCalculations TCount,
			@SupportsRequestManagement bit,
			@ShowActivityTypes TBool,
			@ShowPrice TBool,
			@ProjectLanguageCode	TCode,
			@ManagerAssistantEmployeeID			TIdentifier,
			@AddManagerAssistantToParticipants TBool,
			@AddManagerToParticipants TBool
	
	EXEC adfParameterGet @Name='StatementPrintCurrency', @Group='Pjm5', @Value = @value OUTPUT
	SET @StatementPrintCurrency = CAST(@value as int)
	EXEC adfParameterGet @Name='InvoicePrintCurrency', @Group='Pjm5', @Value = @value OUTPUT
	SET @InvoicePrintCurrency = CAST(@value as int)
	EXEC adfParameterGet @Name='FacturePrintCurrency', @Group='Pjm5', @Value = @value OUTPUT
	SET @FacturePrintCurrency = CAST(@value as int)

	EXEC adfParameterGet @Name='DefaultMoneyScale', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @DefaultMoneyScale = ISNULL(CAST(@value as int), 2)

	EXEC adfParameterGet @Name='InvoiceExpirationPeriod', @Group='Pjm5', @Value = @value OUTPUT
	SET @InvoiceExpirationPeriod = CAST(@value as int)

	EXEC adfParameterGet @Name='InvoiceExpirationPeriodType', @Group='Pjm5', @Value = @value OUTPUT
	IF @value IS NOT NULL
		SET @InvoiceExpirationPeriodType = CAST(@value as int)
	ELSE
		SET @InvoiceExpirationPeriodType = 1

	EXEC adfParameterGet @Name='RoundInterval', @Group='Pjm5', @Value = @value OUTPUT
	SET @RoundInterval = CAST(@value as int)
	EXEC adfParameterGet @Name='RoundingMode', @Group='Pjm5', @Value = @value OUTPUT
	SET @RoundingMode = CAST(@value as int)
	
	EXEC adfParameterGet @Name='GroupCalculationLines', @Group='Pjm5', @Value = @value OUTPUT
	SET @GroupCalculationLines = ISNULL(CAST(@value as bit), 0)
	
	EXEC adfParameterGet @Name='ShowActivityTypes', @Group='Pjm5', @Value = @value OUTPUT
	SET @ShowActivityTypes = ISNULL(CAST(@value as bit), 0)

	EXEC adfParameterGet @Name='ShowPrice', @Group='Pjm5', @Value = @value OUTPUT
	SET @ShowPrice = ISNULL(CAST(@value as bit), 0)

	EXEC adfParameterGet @Name='CheckTaskWorkOverdraft', @Group='Pjm6', @Value = @value OUTPUT
	SET @CheckTaskWorkOverdraft = ISNULL(CAST(@value as bit), 0)

	EXEC adfParameterGet @Name='GroupingAdvanceCalculations', @Group='Pjm6', @Value = @value OUTPUT
	SET @GroupingAdvanceCalculations = ISNULL(CAST(@value as int), 0)
	
	EXEC adfParameterGet @Name='StatementCurrencyPoint', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @StatementCurrencyPoint = ISNULL(CAST(@value as bit), 0)

	EXEC adfParameterGet @Name='UseSubProjects', @Group='Pjm6', @Value = @value OUTPUT
	SET @UseSubProjects = ISNULL(CAST(@value as bit), 0)

	EXEC adfParameterGet @Name='ProjectLanguageCode', @Group='Pjm6', @Value = @value OUTPUT
	SET @ProjectLanguageCode = ISNULL(CAST(@value as VARCHAR(32)), NULL)

	EXEC adfParameterGet @Name='GroupByProjects', @Group='Pjm5', @Value = @value OUTPUT
	SET @GroupByProjects = ISNULL(CAST(@value as bit), 0)

	SELECT
		@Date = CAST(@Xml.value('(/pjm5ProjectGet/Project/Date)[1]','varchar(19)') as datetime),
		@Number = @Xml.value('(/pjm5ProjectGet/Project/Number)[1]','varchar(32)'),
		@FileAs = @Xml.value('(/pjm5ProjectGet/Project/FileAs)[1]','nvarchar(256)'),
		@ProjectTypeID=@Xml.value('(/pjm5ProjectGet/Project/ProjectTypeID)[1]','int'),
		@SupplierCompanyID = @Xml.value('(/pjm5ProjectGet/Project/SupplierCompanyID)[1]','int'),
		@ProjectManagerEmployeeID=@Xml.value('(/pjm5ProjectGet/Project/ProjectManagerEmployeeID)[1]','int'),
		@CustomerCompanyID = @Xml.value('(/pjm5ProjectGet/Project/CustomerCompanyID)[1]','int'),
		@CustomerFinanceManagerID = @Xml.value('(/pjm5ProjectGet/Project/CustomerFinanceManagerID)[1]','int'),
		@ResponsiblePersonEmployeeID = @Xml.value('(/pjm5ProjectGet/Project/ResponsiblePersonEmployeeID)[1]','int'),
		@PriorityID= @Xml.value('(/pjm5ProjectGet/Project/PriorityID)[1]','int'),
		@CurrencyCode = @Xml.value('(/pjm5ProjectGet/Project/CurrencyCode)[1]','char(3)'),
		@CostCenterID= @Xml.value('(/pjm5ProjectGet/Project/CostCenterID)[1]','int'),
		@Budget=@Xml.value('(/pjm5ProjectGet/Project/Budget)[1]','money'),
		@WSSDocumentsURL=@Xml.value('(/pjm5ProjectGet/Project/WSSDocumentsURL)[1]','varchar(512)'),
		@Comments=@Xml.value('(/pjm5ProjectGet/Project/Comments)[1]','nvarchar(max)'),
		@SupportsRequestManagement=@Xml.value('(/pjm5ProjectGet/Project/SupportsRequestManagement)[1]','varchar(5)'),
		@Color = @Xml.value('(/pjm5ProjectGet/Project/Color)[1]','int'),
		@ManagerAssistantEmployeeID = @Xml.value('(/pjm5ProjectGet/Project/ManagerAssistantEmployeeID)[1]','int'),
		@AddManagerAssistantToParticipants = @Xml.value('(/pjm5ProjectGet/Project/AddManagerAssistantToParticipants)[1]','bit'),
		@AddManagerToParticipants = @Xml.value('(/pjm5ProjectGet/Project/AddManagerToParticipants)[1]','bit')


	EXEC adfParameterGet @Name='ApplyVAT', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @ApplyVAT = ISNULL((SELECT TOP (1) [Company].[ApplyVAT] FROM [Company] WHERE [Company].[ID] = @SupplierCompanyID AND [Company].[Own] = 1), CAST(@value as int))

	EXEC adfParameterGet @Name='PaymentCurrencyPoint', @Group='CommonBusiness', @Value = @value OUTPUT
	SET @PaymentCurrencyPoint = ISNULL((SELECT TOP (1) [Company].[PaymentCurrencyPoint] FROM [Company] WHERE [Company].[ID] = @SupplierCompanyID AND [Company].[Own] = 1), CAST(@value as int))

	BEGIN TRANSACTION
	
	INSERT INTO [Project]
		([State], [Flag], [Date], [Number], [FileAs], [ProjectTypeID],
		[ProjectManagerEmployeeID], [SupplierCompanyID], [CustomerCompanyID],
		[CustomerFinanceManagerID],	[ResponsiblePersonEmployeeID], 
		[PriorityID], [CurrencyCode], [CostCenterID],
		[Budget], [ContractNumber], [ContractDate], 
		[ContractSubject], [ApplyVAT], [InvoiceExpirationPeriod], [InvoiceExpirationPeriodType], [WSSDocumentsURL],
		[Comments], [RoundingInterval],	[RoundingMode], [Billable],
		[SupportsRequestManagement], [PaymentCurrencyPoint],
		[Scale],
		[StatementCurrency], [InvoiceCurrency], [FactureCurrency], 
		[GroupCalculationLines], [CheckTaskWorkOverdraft], [ShowActivityTypes],
		[GroupingAdvanceCalculations], [ShowPrice],
		[StatementCurrencyPoint], [UseSubProjects],
		[ProjectLanguageCode],[Color],[GroupByProjects])
	VALUES
		(@State,	@Flag, @Date,@Number,@FileAs,@ProjectTypeID,
		@ProjectManagerEmployeeID, @SupplierCompanyID,@CustomerCompanyID,
		@CustomerFinanceManagerID,@ResponsiblePersonEmployeeID,
		@PriorityID,@CurrencyCode,@CostCenterID,
		@Budget,@Number,@Date,
		@FileAs,(CASE @ApplyVAT WHEN '1' THEN 'true' ELSE 'false' END),@InvoiceExpirationPeriod,@InvoiceExpirationPeriodType,	@WSSDocumentsURL,
		@Comments,	dbo.fnPjm5GetRoundInterval(@RoundInterval),	@RoundingMode,	(CASE  WHEN @ProjectTypeID IN (1) THEN 1 ELSE 0 END),
		(CASE @SupportsRequestManagement WHEN 'false' THEN 0 ELSE 1 END),	@PaymentCurrencyPoint,	
		@DefaultMoneyScale,
		@StatementPrintCurrency, @InvoicePrintCurrency, @FacturePrintCurrency,
		@GroupCalculationLines,	@CheckTaskWorkOverdraft, @ShowActivityTypes,
		@GroupingAdvanceCalculations, @ShowPrice,
		@StatementCurrencyPoint, @UseSubProjects,
		@ProjectLanguageCode, @Color, @GroupByProjects)
		
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	SET @ID = SCOPE_IDENTITY()
		
	INSERT INTO [ProjectDetail] 
		([ID], [DueDate])
	SELECT
		@ID,
		CAST(@Xml.value('(/pjm5ProjectGet/Project/DueDate)[1]','varchar(19)') as datetime)

	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	INSERT INTO [ProjectActivityType]
		([ProjectID], [ActivityTypeID], [Billable], [Actively])
	SELECT
		@ID,
		[ID],
		[Billable],
		1
	FROM
		[ActivityType]
	WHERE
		([ProjectTypeID] = @ProjectTypeID OR [ProjectTypeID] IS NULL)
	AND
		[AddToNewProject] = 1 AND [State] = 1
		
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION		
		RETURN 1
	END

	DECLARE @Error INT

	--     
	SET @AddManagerToParticipants = ISNULL(@AddManagerToParticipants, 0)
	IF @AddManagerToParticipants = 1
	BEGIN
		DECLARE	@XmlEmployee Xml =
			'<Employee>
				<Assignments>
				</Assignments>
			</Employee>'
		
		SET @XmlEmployee.modify('
		insert <ID>{sql:variable("@ProjectManagerEmployeeID")}</ID>
		into (Employee/Assignments)[1]')

		EXEC @Error = pjm6AssignmentsAdd @Xml = @XmlEmployee, @ProjectID = @ID, @GetAssignment = 0
		IF @Error != 0 BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END	
	
	--    . -,     
	IF (@ManagerAssistantEmployeeID IS NOT NULL)
	BEGIN		
		SET @AddManagerAssistantToParticipants = ISNULL(@AddManagerAssistantToParticipants, 0)
		EXEC @Error = pjm7ChangeManagerAssistant @ProjectID = @ID, @EmployeeID = @ManagerAssistantEmployeeID,
			@AddToParticipants = @AddManagerAssistantToParticipants
				
		IF @Error != 0 BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END

	INSERT INTO [ProjectExpenseCode]
			([ProjectID], [ExpenseCodeID], [Billable], [Actively])
	SELECT
		@ID,
		[ID],
		[Billable],
		1
	FROM
		[ExpenseCode]
	WHERE
		([ProjectTypeID] = @ProjectTypeID OR [ProjectTypeID] IS NULL)
	AND
		[AddToNewProject] = 1 AND [State] = 1
		
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	DECLARE @result INT	
	
	EXEC @result = pjm7ProjectAutoAssign @ID
	IF @result != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN @result
	END

	COMMIT TRANSACTION

	END

	EXEC pjm5ProjectGet @ID
	RETURN 0
GO

GRANT EXECUTE ON pjm5ProjectCreate TO PUBLIC
GO
