IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm6ProjectBrowseMineBudgetOverdraft')
	BEGIN
		PRINT 'Dropping Procedure pjm6ProjectBrowseMineBudgetOverdraft'
		DROP  Procedure  pjm6ProjectBrowseMineBudgetOverdraft
	END

GO

PRINT 'Creating Procedure pjm6ProjectBrowseMineBudgetOverdraft'
GO
/******************************************************************************
**		File: pjm6ProjectBrowseMineBudgetOverdraft.sql
**		Name: pjm6ProjectBrowseMineBudgetOverdraft
**		Desc:       
**			    
**			  /  /    
**
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**      30.03.09	ENB				 ,    
**									:      , 
**									      
**									     	
**		04.04.13	SOV				 ,     . -;
**									  : . -  . - 
**		29.04.13	SOV				    
*******************************************************************************/
CREATE Procedure pjm6ProjectBrowseMineBudgetOverdraft
	@ForFinanceManager TBool = 0 --    . -?
AS

	SET NOCOUNT ON

--        
	IF @ForFinanceManager = 0 AND dbo.adfHasAccessRight(dbo.adfGetRightID('ManageProject')) = 0 BEGIN
	    RAISERROR('#NotEnoughPermissions', 18, -1)
		RETURN 1
	END

--     . -
	IF @ForFinanceManager = 1 AND dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance')) = 0 AND
		dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance')) = 0 BEGIN
	    RAISERROR('#NotEnoughPermissions', 18, -1)
		RETURN 1
	END


--   ,         
-- 
	DECLARE 
		@CurrentEmployeeID  TIdentifier

	SELECT 
		@CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()


	SELECT
		[Project].[Class],
		[Project].[ID],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		[Project].[FileAs],
		[Project].[ProjectTypeID],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[PriorityID],
		[ProjectDetail].[DueDate],
		[Project].[EndDate],
		[Project].[CurrencyCode],
		[Project].[CostCenterID],
		[Project].[ContractNumber],
		[Project].[ContractDate],
		[Project].[ContractEndDate],
		[Project].[ContractSubject],
		[Budgets].[PlannedManHour],
		[Budgets].[PlannedManHour] / 60.0 AS [ManHour],
		[Project].[ExchangeSystemName],
		[Projects].[RealManHour],
		CASE
			WHEN [Projects].[ViewFinance] = 1 
				THEN [Budgets].[PlannedBudget]
				ELSE -1
		END AS [PlannedBudget],
		CASE
			WHEN [Projects].[ViewFinance] = 1 
				THEN [Project].[Budget]
				ELSE -1
		END AS [Budget],
		CASE
			WHEN [Budgets].[PlannedBudget] != 0 THEN
				CAST([Projects].[EstimatedBudget] as decimal(18,2))/[Budgets].[PlannedBudget]
			ELSE 0
		END AS [EstimatedBudgetPercent],
		CASE
			WHEN [Budgets].[PlannedBudget] != 0 THEN
				CAST([Projects].[RealBudget] as decimal(18,2))/[Budgets].[PlannedBudget]
			ELSE 0
		END AS [RealBudgetPercent],
		[Project].[Comments],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		[ProjectDetail].[PercentComplete],
		(CAST([ProjectDetail].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		[Project].[IsConsignor],
		[BusinessCard].[FileAs] as 'Consignor',
		[Project].[ConsignorContract],
		[Projects].[ParentProjectID] AS [ParentProjectID],
		[Project].[ManagerAssistantEmployeeID],
		[Project].[FinanceManagerEmployeeID]
	FROM
		[Project]
		INNER JOIN pjm6GetAvailableProjectsForOverdraft (
            @CurrentEmployeeID, @ForFinanceManager
		)   AS [Projects]
			ON [Projects].[ID] = [Project].[ID]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		LEFT OUTER JOIN [BusinessCard]
			ON [BusinessCard].[Class] = [Project].[ConsignorClass] AND [BusinessCard].[ID] = [Project].[ConsignorID]
		LEFT OUTER JOIN fnpjm6GetSubprojectsForBrowse() AS [SubProjects]
			ON [SubProjects].[SubprojectID] = [Project].[ID]
		INNER JOIN dbo.fnPjm7GetProjectsBudgets() AS [Budgets]
			ON [Budgets].[ProjectID] = [Project].[ID]
		
	RETURN 0
GO

GRANT EXEC ON pjm6ProjectBrowseMineBudgetOverdraft TO PUBLIC
GO
 