IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7ProjectBrowseByManagerAssistantOrFinanceManager]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7ProjectBrowseByManagerAssistantOrFinanceManager'
		DROP PROCEDURE [dbo].[pjm7ProjectBrowseByManagerAssistantOrFinanceManager]
	END
GO

PRINT 'Creating procedure pjm7ProjectBrowseByManagerAssistantOrFinanceManager'
GO

/******************************************************************************
**		File: pjm7ProjectBrowseByManagerAssistantOrFinanceManager.sql
**		Name: pjm7ProjectBrowseByManagerAssistantOrFinanceManager
**		Desc:     / .   / . 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		29.04.13	SOV				    
*********************************************************************************/
CREATE PROCEDURE [pjm7ProjectBrowseByManagerAssistantOrFinanceManager]
	@StateSelector INT,
	@CustomerStateSelector INT,
	@DateSelector	INT,
	@PeriodStart	datetime,
	@PeriodEnd		datetime,
	@EmployeeID		TIdentifier,
	@ForManagerAssistant TBool
AS

	SET NOCOUNT ON

--         
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects')) = 0 BEGIN
		RAISERROR('#NotEnoughPermissions', 18, -1)
		RETURN 1
	END

	DECLARE 
		@date datetime
		
	SET @date = GETDATE()
	
	IF @DateSelector = 1
		SELECT
			@PeriodStart = CAST(CAST(YEAR(@date) AS varchar(4)) + '0101' AS datetime),
			@PeriodEnd = DATEADD(year, 1, @PeriodStart)
	IF @DateSelector = 2
		SELECT
			@PeriodStart = CAST(CAST(YEAR(@date)-1 AS varchar(4)) + '0101' AS datetime),
			@PeriodEnd = DATEADD(year, 1, @PeriodStart)
	IF @DateSelector = 3
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime))
	
	SELECT
		[Project].[Class],
		[Project].[ID],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		[Project].[FileAs],
		[Project].[ProjectTypeID],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[PriorityID],
		[ProjectDetail].[DueDate],
		[Project].[EndDate],
		[Project].[CurrencyCode],
		[Project].[CostCenterID],
		[Budgets].[PlannedManHour] / 60.0 AS [ManHour],
		CASE
			WHEN [Projects].[ViewFinance] = 1 
			THEN [Project].[Budget]
			ELSE -1
		END AS [Budget],
		[Budgets].[PlannedManHour],
		CASE
			WHEN [Projects].[ViewFinance] = 1
			THEN [Budgets].[PlannedBudget]
			ELSE -1
		END AS [PlannedBudget],
		[Project].[Billable],
		[Project].[RoundingInterval],
		[Project].[RoundingMode],
		[Project].[ContractNumber],
		[Project].[ContractDate],
		[Project].[ContractEndDate],
		[Project].[ContractSubject],
		[Project].[ServiceLevelID],
		[Project].[ApplyVAT],
		[Project].[InvoiceExpirationPeriod],
		[Project].[InvoiceExpirationPeriodType],
		[Project].[Comments],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[ExchangeSystemName],
		[Project].[Timestamp],
		[ProjectDetail].[PercentComplete],
		(CAST([ProjectDetail].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		[Project].[PaymentCurrencyPoint],
		[Project].[IsConsignor],
		[BusinessCard].[FileAs] as 'Consignor',
		[Project].[ConsignorContract],
		[Projects].[ParentProjectID] AS [ParentProjectID],
		[Project].[ManagerAssistantEmployeeID],
		[Project].[FinanceManagerEmployeeID]
	FROM
		[Project]
		INNER JOIN dbo.fnPjm7GetAvailableProjectsForProjectManagerAssistantOrFinanceManager(
			@EmployeeID,		-- ID    
			@StateSelector,		--    
			@ForManagerAssistant
		) AS [Projects]
			ON [Project].[ID] = [Projects].[ID]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		LEFT OUTER JOIN [BusinessCard]
			ON [BusinessCard].[Class] = [Project].[ConsignorClass] AND [BusinessCard].[ID] = [Project].[ConsignorID]
		INNER JOIN dbo.fnPjm7GetProjectsBudgets() AS [Budgets]
			ON [Budgets].[ProjectID] = [Project].[ID]
	WHERE
		( 
			(@CustomerStateSelector = 0) OR 
			(@CustomerStateSelector = 1 AND [Project].[ProjectTypeID] = 1) OR
			(@CustomerStateSelector = 2 AND [Project].[ProjectTypeID] = 2) OR
			([Project].[ProjectTypeID] NOT IN (1, 2) AND @CustomerStateSelector = 3)
		) AND
		(
			@DateSelector = 0 OR
			([Project].[Date] < @PeriodEnd AND ISNULL([Project].[EndDate], @date) > @PeriodStart)
		) 
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm7ProjectBrowseByManagerAssistantOrFinanceManager] TO PUBLIC
GO

