﻿
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7SubProjectBrowseSelectorDialogForProject]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7SubProjectBrowseSelectorDialogForProject'
		DROP PROCEDURE [dbo].[pjm7SubProjectBrowseSelectorDialogForProject]
	END
GO

PRINT 'Creating procedure pjm7SubProjectBrowseSelectorDialogForProject'
GO

/******************************************************************************
**		File: pjm7SubProjectBrowseSelectorDialogForProject.sql
**		Name: pjm7SubProjectBrowseSelectorDialogForProject
**		Desc: процедура выполняет выборуку проектов для включения проекта в 
**		основной проект
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      	----------						-----------
**
**		Auth: MAB
**		Date: 22.07.13
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------
**    	01.08.13	SAP			Исправление выборки поля [Project].[FileAs]			
*******************************************************************************/
CREATE PROCEDURE [dbo].[pjm7SubProjectBrowseSelectorDialogForProject]
	@EmployeeID					TIdentifier,
	@OnlyActive					bit,
	@ContractOnly				bit,
	@OnlyProjectMember			bit,
	@ProjectState				int = 2,
	@ProjectSelector			bit = 0,
	@SupportsRequestManagement	bit,
	@CurrencyCode				TCode3 = NULL,
	@ApplyVAT					TBool = NULL,
	@RatesWithVAT				TBool = NULL,
	@ParentProjectID			TIdentifier,
	@ProjectTypeID				TIdentifier
AS
	SET NOCOUNT ON

DECLARE @ProjectClass TClass
SET @ProjectClass = dbo.adfGetClassByName('Pjm5.Project')
	
IF(@ProjectState < 10)
	SELECT DISTINCT
			[Project].[ID],
			[Project].[Class],
			[Project].[State],
			[Project].[Flag],
			[Project].[Date],
			[Project].[Number],
			[Project].[FileAs],
			--CASE @ProjectTypeID
			--	WHEN 1 THEN 
			--		ISNULL('№'+[Project].[ContractNumber]+' от '+CONVERT(varchar(10), [Project].[ContractDate], 104) + ' г.', [Project].[FileAs])
			--	ELSE 
			--		[Project].[FileAs]
			--END AS [FileAs],
			[Project].[SupplierCompanyID],
			[Project].[ProjectManagerEmployeeID],
			[Project].[CustomerCompanyID],
			[Project].[CustomerFinanceManagerID],
			[Project].[ResponsiblePersonEmployeeID],
			[Project].[Created],
			[Project].[CreatedBy],
			[Project].[Modified],
			[Project].[ModifiedBy],
			[Project].[Timestamp],
			[Employee].[FileAs] AS [Manager],
			[Supplier].[FileAs] AS [Supplier],
			[Customer].[FileAs] AS [Customer]
		FROM
			[Project]
			LEFT OUTER JOIN [Employee]
				ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
			LEFT OUTER JOIN [Company] AS [Supplier]
				ON [Supplier].[ID] = [Project].[SupplierCompanyID]
			LEFT OUTER JOIN [Company] AS [Customer]
				ON [Customer].[ID] = [Project].[CustomerCompanyID]
			INNER JOIN dbo.fnPjm7GetAvailableProjectsForSubProjectSelectorDialog	(	@EmployeeID,
																						@OnlyActive,
																						@OnlyProjectMember,
																						@ProjectState,
																						@ProjectSelector,
																						@SupportsRequestManagement	
																					) AS [AvialableProject]
				ON [Project].[ID] = [AvialableProject].[ID]
			LEFT JOIN [Task] 
				ON [Project].[ID] = [Task].[SubProjectID]
		WHERE
			[Task].[SubProjectID] IS NULL AND
			[Project].[ID] != @ParentProjectID AND
			(
				@ProjectTypeID IS NULL  OR 
				(
					@ProjectTypeID = 1 AND
					[Project].[ProjectTypeID] = @ProjectTypeID AND
					(@CurrencyCode IS NULL OR [Project].[CurrencyCode] = @CurrencyCode) AND 
					(@ApplyVAT IS NULL OR [Project].[ApplyVAT] = @ApplyVAT) AND
					(@RatesWithVAT IS NULL OR [Project].[RatesWithVAT] = @RatesWithVAT) 
				) OR 
				@ProjectTypeID != 1
			)

			
			
ELSE
	SELECT DISTINCT
		[Project].[ID],
		[Project].[Class],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		[Project].[FileAs],
			--CASE @ProjectTypeID
			--	WHEN 1 THEN 
			--		ISNULL('№'+[Project].[ContractNumber]+' от '+CONVERT(varchar(10), [Project].[ContractDate], 104) + ' г.', [Project].[FileAs])
			--	ELSE 
			--		[Project].[FileAs]
			--END AS [FileAs],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		[Employee].[FileAs] AS [Manager],
		[Supplier].[FileAs] AS [Supplier],
		[Customer].[FileAs] AS [Customer],
		[LastDocument].[TimeStamp] 
	FROM
		[Project]
		INNER JOIN [LastDocument] 
			ON [LastDocument].[EmployeeID] = @EmployeeID AND 
				[LastDocument].[DocumentClass] = @ProjectClass AND
				[Project].[ID] = [LastDocument].[DocumentID]
		LEFT OUTER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
		LEFT OUTER JOIN [Company] AS [Supplier]
			ON [Supplier].[ID] = [Project].[SupplierCompanyID]
		LEFT OUTER JOIN [Company] AS [Customer]
			ON [Customer].[ID] = [Project].[CustomerCompanyID]
		LEFT JOIN [Task] 
				ON [Project].[ID] = [Task].[SubProjectID]
	WHERE
		[Task].[SubProjectID] IS NULL AND
		[Project].[ID] != @ParentProjectID AND
		(
			@ProjectTypeID IS NULL  OR 
			(
				@ProjectTypeID = 1 AND
				[Project].[ProjectTypeID] = @ProjectTypeID AND
				(@CurrencyCode IS NULL OR [Project].[CurrencyCode] = @CurrencyCode) AND 
				(@ApplyVAT IS NULL OR [Project].[ApplyVAT] = @ApplyVAT) AND
				(@RatesWithVAT IS NULL OR [Project].[RatesWithVAT] = @RatesWithVAT) 
			) OR 
			@ProjectTypeID != 1
		)
	ORDER BY [LastDocument].[TimeStamp] 

RETURN 0
GO

GRANT EXECUTE ON [pjm7SubProjectBrowseSelectorDialogForProject] TO PUBLIC
GO
