IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportRevenueByServiceType')
	BEGIN
		PRINT 'Dropping Procedure ReportRevenueByServiceType'
		DROP  Procedure  ReportRevenueByServiceType
	END

GO

PRINT 'Creating Procedure ReportRevenueByServiceType'
GO

CREATE Procedure ReportRevenueByServiceType
		@CompanyID TIdentifier,
		@DateSelector int,
		@QuartalSelector int,
		@PeriodStart TDate,
		@PeriodEnd TDate,
		@InvoiceSelector int,
		@CostCenterSelector int,
		@CostCenterID TIdentifier,
		@ServiceTypeSelector int
		
AS
	SET NOCOUNT ON
	
	IF @CompanyID IS NULL
	BEGIN
		RAISERROR('#CompanyIsNotSelected', 16, -1)
		RETURN 1
	END
	
	DECLARE
		@UserID TIdentifier,
		@UserName TName,
		@Sum float,
		@InvoiceState TName,
		@Value TVariant,
		@CostCenterName TName,
		@ServiceTypeType TName
		
	EXEC adfParameterGet 'BaseCurrency', 'CommonBusiness', @Value OUTPUT		
	IF @DateSelector = 0
		BEGIN
			SET @PeriodStart = CAST(YEAR(GETDATE()) AS char(4))+'0101'
			SET @PeriodEnd = CAST((YEAR(GETDATE()) + 1) AS char(4))+'0101'
		END
	ELSE IF @DateSelector = 1
		BEGIN
			SET @PeriodStart = CAST((YEAR(GETDATE()) - 1) AS char(4))+'0101'
			SET @PeriodEnd = CAST(YEAR(GETDATE()) AS char(4))+'0101'
		END
		ELSE SET @PeriodEnd = DATEADD(day, 1, @PeriodEnd)
	IF @QuartalSelector = 2 SET @PeriodStart = DATEADD(month, 3, @PeriodStart)
	IF @QuartalSelector = 3 SET @PeriodStart = DATEADD(month, 6, @PeriodStart)
    IF @QuartalSelector = 4 SET @PeriodStart = DATEADD(month, 9, @PeriodStart)
	IF @QuartalSelector != 0 SET @PeriodEnd = DATEADD(month, 3, @PeriodStart)
	SET @PeriodEnd = DATEADD(day, -1, @PeriodEnd)	
	
	IF @ServiceTypeSelector = 0 SET @ServiceTypeType = '    '
	IF @ServiceTypeSelector = 1 SET @ServiceTypeType = ''
	IF @ServiceTypeSelector = 2 SET @ServiceTypeType = '  '
	
	IF @InvoiceSelector = 0
		SET @InvoiceState = ' '
	ELSE 
		SET @InvoiceState = ' '
		
	IF @CostCenterSelector = 1 AND @CostCenterID IS NOT NULL					
		SELECT
			@CostCenterName = [FileAs]
		FROM
			[CostCenter]
		WHERE
			[ID] = @CostCenterID
		
		SET @UserID = dbo.adfGetCurrentUserID()
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID	
		
	DECLARE @ServiceType TABLE([ServiceTypeID] TIdentifier, [ServiceTypeName] TName NULL, [Value] TMoney NULL)
	INSERT INTO @ServiceType([ServiceTypeID], [ServiceTypeName], [Value]) 
	SELECT 
		[InvoiceLine].[ServiceTypeID],
		ISNULL([ServiceType].[FileAs],'( )'),
		SUM ([InvoiceLine].[TotalWithVATBC])
	FROM 
		[InvoiceLine]
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
		INNER JOIN [Project]
			ON [Project].[ID] = [Invoice].[ProjectID]
		LEFT OUTER JOIN [ServiceType]
			ON [ServiceType].[ID] = [InvoiceLine].[ServiceTypeID] 								
		LEFT OUTER JOIN [AdvanceInvoice]
			ON [AdvanceInvoice].[AdvanceInvoiceID] = [Invoice].[ID]
		LEFT OUTER JOIN [Invoice] AS [BaseInvoice]
			ON [AdvanceInvoice].[InvoiceID] = [BaseInvoice].[ID] AND
				[BaseInvoice].[State] IN (2,5)
	WHERE
		[Invoice].[SupplierCompanyID] = @CompanyID AND
		[BaseInvoice].[ID] IS NULL AND
		[Invoice].[Date] BETWEEN @PeriodStart AND @PeriodEnd
		AND
		(
			@InvoiceSelector = 0 AND [Invoice].[State] = 5 OR
			@InvoiceSelector = 1 AND [Invoice].[State] IN (2,5)
		)
		AND
		(	@CostCenterSelector = 0 OR
			@CostCenterID IS NULL AND [Project].[CostCenterID] IS NULL OR
			[Project].[CostCenterID] = @CostCenterID
		)
		AND
		(
			@ServiceTypeSelector = 0 OR
			@ServiceTypeSelector = 1 AND ([ServiceType].[RatesDepended] = 1 OR [ServiceType].[ID] IS NULL) OR
			@ServiceTypeSelector = 2 AND [ServiceType].[RatesDepended] = 0
		)
	GROUP BY
		[InvoiceLine].[ServiceTypeID],
		[ServiceType].[FileAs]
	
	SELECT @Sum = SUM([Value]) FROM @ServiceType

	DECLARE @Result TABLE([SortID] int, [ServiceTypeID] TIdentifier, [ServiceTypeName] TName NULL, [Value] int NULL)
	INSERT INTO @Result([SortID], [ServiceTypeID], [ServiceTypeName], [Value])
	SELECT TOP(6)
		1,
		[ServiceTypeID], 
		[ServiceTypeName], 
		[Value]
	FROM
		 @ServiceType
	ORDER BY [Value] DESC 

	DELETE FROM @ServiceType
	FROM
		@ServiceType [S]
		INNER JOIN @Result [R]
			ON ([S].[ServiceTypeID] = [R].[ServiceTypeID] OR
				[S].[ServiceTypeID] IS NULL AND [R].[ServiceTypeID] IS NULL)

	IF EXISTS(SELECT * FROM @ServiceType)
	BEGIN			
	INSERT INTO @Result([SortID],[ServiceTypeID], [ServiceTypeName], [Value])
	SELECT
		2,
		NULL,
		'()',
		SUM([Value])
	FROM 
		@ServiceType
	END
		
	SELECT 
		CASE WHEN @QuartalSelector != 0 THEN (CAST(@QuartalSelector AS Char(1)) + '  ') ELSE '' END + CAST(YEAR(@PeriodStart) AS Char(4)) + ' .' AS [Year],
		@UserName AS [UserName],
		@InvoiceState AS [InvoiceState],
		CAST(@Value as nvarchar(32)) AS [CurrencyCode],
		[Company].[ID],
		[Company].[LegalName],
		[Company].[FileAs],
		ISNULL(@CostCenterName, '( )') AS [CostCenterName],
		@ServiceTypeType as [ServiceTypeType]
	FROM
		[Company]
	WHERE
		[Company].[ID] = @CompanyID
		
	SELECT 
		[ServiceTypeName],
		[Value],
		[Value]/@Sum AS [Percent]
	FROM 
		@Result
	ORDER BY 
		[SortID], 
		[Value] DESC  
	
RETURN 0

GO

GRANT EXEC ON ReportRevenueByServiceType TO PUBLIC

GO