IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportDevelopmentTeamSprint')
	BEGIN
		PRINT 'Dropping Procedure ReportDevelopmentTeamSprint'
		DROP  Procedure  ReportDevelopmentTeamSprint
	END

GO

PRINT 'Creating Procedure ReportDevelopmentTeamSprint'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2010 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/ 
CREATE PROCEDURE [dbo].[ReportDevelopmentTeamSprint]
    @Sprint TCode,
	@ReportType TBool	-- 0 - plan, 1 - result
AS

SET NOCOUNT ON

SELECT
	@Sprint = '07 / 11.05.09 - 22.05.09',
	@ReportType = 1 
	
DECLARE
	@SprintStart TDate,
	@SprintEnd TDate,
	@SprintNumber TCode,
	@SlashPos int,
	@MinusPos int
	
SET @SlashPos = CHARINDEX('/', @Sprint)
SET @MinusPos = CHARINDEX('-', @Sprint)

SELECT
	@SprintNumber = RTRIM(SUBSTRING(@Sprint, 0, @SlashPos)),
	@SprintStart = CONVERT(datetime, RTRIM(LTRIM(SUBSTRING(@Sprint, @SlashPos + 1, @MinusPos - @SlashPos - 1))), 4),
	@SprintEnd = CONVERT(datetime, RTRIM(LTRIM(SUBSTRING(@Sprint, @MinusPos + 1, LEN(@Sprint) - @MinusPos))), 4)

DECLARE @IssueClass TClass
SET @IssueClass = dbo.adfGetClassByName('Pjm5.Issue')

DECLARE @Employees TABLE
(
	[ID] TIdentifier
)

DECLARE @Issues TABLE
(
	[ID] TIdentifier,
	[EmployeeID] TIdentifier
)

IF @ReportType = 0	-- plan report
	BEGIN
		
		INSERT INTO @Issues ([ID], [EmployeeID])
		SELECT [ID], [EmployeeID]
		FROM [Issue]
		WHERE [Issue].[UDF2] = @Sprint AND [Issue].[State] = 3
		
		INSERT INTO @Employees ([ID])
		SELECT [EmployeeID]
		FROM @Issues
		
		INSERT INTO @Issues ([ID], [EmployeeID])
		SELECT
			[Issue].[ID],
			[Issue].[EmployeeID]
		FROM
			@Employees [Employees]
			INNER JOIN [Issue]
				ON [Issue].[EmployeeID] = [Employees].[ID] AND [Issue].[State] = 3
		WHERE
			[Issue].[ID] NOT IN (SELECT [ID] FROM @Issues)
			
		SELECT
			CASE [Issue].[PriorityID]
				WHEN 0 THEN 'Low'
				WHEN 500 THEN 'Standard'
				ELSE 'High'
			END as [Priority],
			[Severity].[FileAs] as [Severity],
			[Issue].[Number],
			[Issue].[FileAs],
			[Employee].[Initials],
			[Issue].[ManHour] as [ManHour],
			[Issue].[ActualManHour],
			([Issue].[ManHour] - [Issue].[ActualManHour]) as [SprintManHour],
			0 as [ActualSprintManHour],
			[State].[Name],
			CASE WHEN [Issue].[UDF2] = @Sprint THEN 0 ELSE 1 END as [IsThrown],
			0 as [Accurancy],
			0 as [Speed]
		FROM
			[Issue]
			INNER JOIN @Issues [Issues]
				ON [Issues].[ID] = [Issue].[ID]
			INNER JOIN [Employee]
				ON [Employee].[ID] = [Issue].[EmployeeID]
			INNER JOIN [Severity]
				ON [Severity].[ID] = [Issue].[SeverityID]
			INNER JOIN [State]
				ON [State].[Class] = [Issue].[Class] AND [State].[State] = [Issue].[State]
		ORDER BY
			[Employee].[Initials] ASC,
			[ManHour] DESC
	END
ELSE	-- result report
	BEGIN
		
		INSERT INTO @Issues ([ID], [EmployeeID])
		SELECT
			[Issue].[ID],
			[Issue].[EmployeeID]
		FROM
			[Issue]
		WHERE
			[Issue].[ID] IN
			(
				SELECT
					DISTINCT [Transition].[DocumentID]
				FROM
					[Transition]
					INNER JOIN [TransitionTemplate]
						ON [Transition].[TransitionTemplateID] = [TransitionTemplate].[ID] AND
						 [Transition].[Class] = @IssueClass AND [TransitionTemplate].[FromState] = 3 AND
						 [Transition].[Created] BETWEEN @SprintStart AND @SprintEnd
			) AND
			[Issue].[UDF2] = @Sprint
				
		
		INSERT INTO @Employees ([ID])
		SELECT [EmployeeID]
		FROM @Issues
		
		INSERT INTO @Issues ([ID], [EmployeeID])
		SELECT
			[Issue].[ID],
			[Issue].[EmployeeID]
		FROM
			@Employees [Employees]
			INNER JOIN [TimeEntry]
				ON [Employees].[ID] = [TimeEntry].[EmployeeID] AND [TimeEntry].[DocumentClass] = @IssueClass AND
					[TimeEntry].[StartTime] BETWEEN @SprintStart AND @SprintEnd
			INNER JOIN [Issue]
				ON [Issue].[ID] = [TimeEntry].[DocumentID]
		WHERE
			[Issue].[ID] NOT IN (SELECT [ID] FROM @Issues)
			
		SELECT
			CASE [Issue].[PriorityID]
				WHEN 0 THEN 'Low'
				WHEN 500 THEN 'Standard'
				ELSE 'High'
			END as [Priority],
			[Severity].[FileAs] as [Severity],
			[Issue].[Number],
			[Issue].[FileAs],
			[Employee].[Initials],
			[Issue].[ManHour] as [ManHour],
			[Issue].[ActualManHour],
			([Issue].[ManHour] - [Issue].[ActualManHour]) as [SprintManHour],
			0 as [ActualSprintManHour],
			[State].[Name],
			CASE WHEN [Issue].[UDF2] = @Sprint THEN 0 ELSE 1 END as [IsThrown],
			0 as [Accurancy],
			0 as [Speed]
		FROM
			[Issue]
			INNER JOIN @Issues [Issues]
				ON [Issues].[ID] = [Issue].[ID]
			INNER JOIN [Employee]
				ON [Employee].[ID] = [Issue].[EmployeeID]
			INNER JOIN [Severity]
				ON [Severity].[ID] = [Issue].[SeverityID]
			INNER JOIN [State]
				ON [State].[Class] = [Issue].[Class] AND [State].[State] = [Issue].[State]
		ORDER BY
			[Employee].[Initials] ASC,
			[ManHour] DESC
	END

RETURN 0
GO

GRANT EXEC ON ReportDevelopmentTeamSprint TO PUBLIC

GO
