IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportEmployeeTimeAllocationByPeriod')
	BEGIN
		PRINT 'Dropping Procedure ReportEmployeeTimeAllocationByPeriod'
		DROP  Procedure  ReportEmployeeTimeAllocationByPeriod
	END

GO

PRINT 'Creating Procedure ReportEmployeeTimeAllocationByPeriod'
GO
/******************************************************************************
**		File: ReportEmployeeTimeAllocationByPeriod.sql
**		Name: ReportEmployeeTimeAllocationByPeriod
**
**         
**		Return values:
**
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		13.12.2011	ASA				First Version
**		29.03.13	SAP				  , 
**									    ,
**									   
**									 .
**		01.04.13	SAP				    . ,
**									    
**		02.04.13	SAP				  
**		12.09.13	SOV				    . -
**		13.09.13	SOV				    , 
**									      -
**		25.12.13	SAP				    ViewAllFinance 
**									  
*******************************************************************************/
CREATE PROCEDURE [dbo].[ReportEmployeeTimeAllocationByPeriod]
        @DateSelector int,
        @StartDate TDateTime,
        @EndDate TDateTime,
        @EmployeeTypeSelector int,
        @WorkingEmployeeID TIdentifier,
        @DismissedEmployeeID TIdentifier,
		@IncludingDrafts int --       -?
AS

SET NOCOUNT ON

DECLARE 
		@EmployeeID TIdentifier,
        @CompanyFileAs TName,
        @DivisionFileAs TName,
        @EmployeeFileAs TName,
        @EmployeeNumber TName,
        @EmployeePosition TName,
        @Date TDate,
        @WorkingDays decimal(18,2),
        @Value TVariant,
        @UserID TIdentifier,
        @UserName TName,
        @BaseCurrency TCode3,
        @NationalCurrency TCode3,
        @num int,
		@CalculationClass TClass,
		@StatementClass TClass,
		@InvoiceClass TClass,
		@HasViewAllFinance int
		
SET	@CalculationClass = dbo.adfGetClassByName('Pjm5.Calculation')
SET	@StatementClass = dbo.adfGetClassByName('Pjm5.Statement')
SET	@InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice')

SET @HasViewAllFinance = dbo.adfHasAccessRightByName('ViewAllFinance') 

EXEC adfParameterGet 'BaseCurrency', 'CommonBusiness', @Value = @Value OUTPUT   
   SET @BaseCurrency = CAST(@Value AS nvarchar(32))
   
EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @Value = @Value OUTPUT   
   SET @NationalCurrency = CAST(@Value AS nvarchar(32))

IF (@EmployeeTypeSelector = 0)
	BEGIN
		IF (@WorkingEmployeeID IS NULL) 
		BEGIN
				RAISERROR('#EmployeeIsNotSelected', 16, -1)
				RETURN 2
		END
		ELSE
		BEGIN
			SET @EmployeeID = @WorkingEmployeeID
		END
	END
ELSE
	BEGIN
		IF (@DismissedEmployeeID IS NULL) 
		BEGIN
				RAISERROR('#EmployeeIsNotSelected', 16, -1)
				RETURN 2
		END
		ELSE
		BEGIN
			SET @EmployeeID = @DismissedEmployeeID
		END
	END

SELECT
    @CompanyFileAs = [Company].[FileAs],
    @DivisionFileAs = [Division].[FileAs],
    @EmployeeFileAs = [Employee].[FileAs],
    @EmployeeNumber =  [Employee].[Number],
    @EmployeePosition = [Position].[FileAs]
FROM
	[Employee]
	INNER JOIN [Company]
		ON  [Company].[ID] = [Employee].[CompanyID]
	LEFT OUTER JOIN [Division]
		ON [Division].[ID] = [Employee].[DivisionID]
	LEFT OUTER JOIN [Position]
		ON [Position].[ID] = [Employee].[PositionID]
WHERE 
	[Employee].[ID] = @EmployeeID

SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
IF @DateSelector = 0 -- current month
	SELECT
		@StartDate = DATEADD(day, 1-DATEPART(day, @Date), @Date),
		@EndDate = DATEADD(day, 1, @Date)
ELSE IF @DateSelector = 1 -- prev month
	SELECT
		@StartDate = DATEADD(day, 1-DATEPART(day, @Date), @Date),
		@StartDate = DATEADD(month, -1, @StartDate),
		@EndDate = DATEADD(month, 1, @StartDate)
ELSE IF @DateSelector = 2 -- quart
	SELECT
		@StartDate = [StartDate],
		@EndDate = DATEADD(day, 1, @Date)
	FROM	
		dbo.adfGetDateInterval(4, @Date, @Date, @Date)
ELSE IF @DateSelector = 3 -- prev quart
	SELECT
		@StartDate = [StartDate],
		@EndDate = [EndDate]
	FROM	
		dbo.adfGetDateInterval(3, @Date, @Date, @Date)
ELSE IF @DateSelector = 4 -- curr year
	SELECT
		@StartDate = CAST(Year(@Date) as varchar(4)),
		@EndDate = DATEADD(day, 1, @Date)
ELSE IF @DateSelector = 5 -- prev year
	SELECT
		@EndDate = CAST(Year(@Date) as varchar(4)),
		@StartDate = CAST(Year(@Date)-1 as varchar(4))
ELSE
	SELECT
		@StartDate = CAST(CONVERT(varchar(8), @StartDate, 112) AS datetime),
		@EndDate = DATEADD(day, 1, CAST(CONVERT(varchar(8), @EndDate, 112) AS datetime))

SET DATEFIRST 7
SET @WorkingDays = dbo.fnPjm5GetWorkingDays(@StartDate, DATEADD(day, -1, @EndDate))
SET DATEFIRST 1

--   ,    
DECLARE @TimeEntriesInFinance TABLE(DocumentID TIdentifier,LinkClass TClass, LinkDocumentID TIdentifier, State	TState, Date TDateTime, ThroughCalculation TFlag)
INSERT INTO @TimeEntriesInFinance(DocumentID, LinkClass, LinkDocumentID, State, ThroughCalculation)
SELECT 
[F].[DocumentID], [F].[LinkClass], [F].[LinkDocumentID], [F].[State], [F].[ThroughCalculation]
FROM
fnReportGetTimeEntriesInFinance(@StartDate, @EndDate, @EmployeeID) AS [F]

SET @UserID = dbo.adfGetCurrentUserID()
SELECT
    @UserName = [Trustee].[DisplayName]
FROM
	[Trustee]
WHERE
	[Trustee].[ID] = @UserID

EXEC adfParameterGet 'BaseCurrency', 'CommonBusiness', @Value = @Value OUTPUT   
SET @BaseCurrency = CAST(@Value AS nvarchar(32))

EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @Value = @Value OUTPUT   
SET @NationalCurrency= CAST(@Value AS nvarchar(32))

DECLARE @TimeType TABLE(ID int)
SET @num = 1

WHILE (@num < 10)
BEGIN
	INSERT INTO @TimeType(ID) SELECT @num
	SET @num = @num + 1
END


DECLARE @PostProcessTable TABLE
(
	[State] int,
	[ProjectType] int,
	[Duration] decimal(18,4),
	[Value1] money,
	[Value2] money
)
--SELECT * FROM @TimeEntriesInFinance
;

WITH TimeEntryTypes ([State], [ProjectType], [Duration], [Value1],[Value2]) AS  
(
	SELECT
        [TimeType].[ID],
        [ProjectType].[ID],
        CASE
	        WHEN	[TimeType].[ID] = 1 
					AND [TimeEntry].[State] IN (3, 6) 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId]
					THEN [TimeEntry].[RoundedDuration]/60.0
            WHEN	[TimeType].[ID] = 2 
					AND [TimeEntry].[State] IN (3, 6) 
					AND [TimeEntry].[Billable] = 1 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId]
					THEN [TimeEntry].[RoundedDuration]/60.0
            WHEN	[TimeType].[ID] = 3								-- 
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1  
					AND [ProjectType].[ID] = [Project].[ProjectTypeId]
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] = 2 OR 
						(@InvoiceClass = [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 5) OR
						(@InvoiceClass != [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 3))) --     
					THEN [EntryAmount].[Amount] 
            WHEN	[TimeType].[ID] = 4								--   
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND [EntryAmount].[Amount] > 0
					THEN 
						CASE WHEN (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] = 2 OR 
								(@InvoiceClass = [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 5) OR
								(@InvoiceClass != [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 3)))
								THEN [EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0
							ELSE 0
						END
			WHEN	[TimeType].[ID] = 5								--   
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND [EntryAmount].[Amount] > 0
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] = 2 OR 
						(@InvoiceClass = [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 5) OR
						(@InvoiceClass != [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 3)))
					AND ([EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0) > 0
					THEN [EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0		
			WHEN	[TimeType].[ID] = 6								--   
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId]
					AND [EntryAmount].[Amount] > 0
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] = 2 OR 
						(@InvoiceClass = [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 5) OR
						(@InvoiceClass != [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 3)))
					AND ([EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0) < 0
					THEN ABS([EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0)
            WHEN	[TimeType].[ID] = 7 
					AND [TimeEntry].[State] in (2) 
					AND [Project].[ProjectTypeID] NOT IN (5,6) 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId]
					THEN [TimeEntry].[RoundedDuration]/60.0
            WHEN	[TimeType].[ID] = 8 
					AND [TimeEntry].[State] in (1, 5)
					AND [Project].[ProjectTypeID] NOT IN (5,6) 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId]
					THEN [TimeEntry].[RoundedDuration]/60.0
            WHEN	[TimeType].[ID] = 9 
					AND [TimeEntry].[State] IN (4)
					AND [Project].[ProjectTypeID] NOT IN (5,6) 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId]
					THEN [TimeEntry].[RoundedDuration]/60.0
            ELSE NULL END,
		-- .   1
        CASE WHEN	[TimeType].[ID] = 2								--   ( )	
					AND [TimeEntry].[State] IN (3, 6) 
					AND [TimeEntry].[Billable] = 1 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					THEN ROUND( 
						[TimeEntry].[RoundedDuration]/60.0, 2) 
					*	
						[TimeEntry].[Rate]
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END)
					*
						CASE [Project].[CurrencyCode]  
						WHEN @BaseCurrency THEN 1 
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency) 
						END 
			--   
            WHEN	[TimeType].[ID] = 3								-- . ,  
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] = 2 OR 
						(@InvoiceClass = [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 5) OR
						(@InvoiceClass != [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 3))) --       
					AND [TimeEntriesInFinance].[LinkClass] <> @CalculationClass
					THEN	
						[EntryAmount].[Amount]
					*	
						[EntryAmount].[Price]
					*   
						(1 -	CASE [Project].[RatesWithVAT]
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate])
								ELSE 0 END)
					*   
						CASE [Project].[CurrencyCode]
						WHEN @BaseCurrency THEN 1 
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency) 
						END 
			WHEN	[TimeType].[ID] = 3 								-- 
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] IN (2, 3))) --      
					AND [TimeEntriesInFinance].[LinkClass] = @CalculationClass
					THEN						
						ROUND(						
						[EntryAmount].[Amount]
					*	
						[EntryAmount].[Price]
					*
						CASE [Calculation].[DiscountType]
						WHEN 1 THEN (1 - [Calculation].[DiscountPercent]) --
						WHEN 2 THEN (1 +  [Calculation].[DiscountPercent]) --
						WHEN 3 THEN --
							CASE 
							WHEN [Calculation].[TotalWithoutDiscount] > [Calculation].[Discount] THEN [Calculation].[DiscountPercent]
							ELSE 1
							END
						WHEN 4 THEN [Calculation].[DiscountPercent]-- 
						ELSE 1
						END
					*   
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1  THEN	 [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 END)
					*	
						CASE [Project].[CurrencyCode] 	
						WHEN @BaseCurrency THEN 1  
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency)  
						END	
						,1)					  
            WHEN	[TimeType].[ID] = 4 --   ,  . ,  
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] = 2 OR 
						(@InvoiceClass = [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 5) OR
						(@InvoiceClass != [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 3))) --      . 
					AND [TimeEntriesInFinance].[LinkClass] <> @CalculationClass					
					THEN 					
						(
						[EntryAmount].[Amount] * [EntryAmount].[Price] --    . 
						- 
						[TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] --      . -
						)	
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END)
					*
						CASE [Project].[CurrencyCode]   
						WHEN @BaseCurrency THEN 1  
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency)   
						END
			WHEN	[TimeType].[ID] = 4 --   ,  
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] IN (2, 3))) --      
					AND [TimeEntriesInFinance].[LinkClass] = @CalculationClass
					THEN 					
						(
							([EntryAmount].[Amount] * [EntryAmount].[Price] --    . 
							*
							CASE [Calculation].[DiscountType]
								WHEN 1 THEN (1 - [Calculation].[DiscountPercent]) --
								WHEN 2 THEN (1 +  [Calculation].[DiscountPercent]) --
								WHEN 3 THEN --
									CASE 
										WHEN [Calculation].[TotalWithoutDiscount] > [Calculation].[Discount] THEN [Calculation].[DiscountPercent]
										ELSE 1
									END
								WHEN 4 THEN [Calculation].[DiscountPercent] -- 
								ELSE 1
							END)
						- 
						[TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] --      . -
						)	
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END)
					*
						CASE [Project].[CurrencyCode]   
						WHEN @BaseCurrency THEN 1  
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency)   
						END
			WHEN	[TimeType].[ID] = 5 --   ,  . ,  
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] = 2 OR 
						(@InvoiceClass = [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 5) OR
						(@InvoiceClass != [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 3))) --       
					AND [TimeEntriesInFinance].[LinkClass] <> @CalculationClass
					AND	([EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate]) > 0					
					THEN 					
						(
						[EntryAmount].[Amount] * [EntryAmount].[Price] --    . 
						- 
						[TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] --      . -
						)	
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END)
					*
						CASE [Project].[CurrencyCode]   
						WHEN @BaseCurrency THEN 1  
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency)   
						END
			WHEN	[TimeType].[ID] = 5 --   ,  
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] IN (2, 3))) --      
					AND [TimeEntriesInFinance].[LinkClass] = @CalculationClass
					AND	(([EntryAmount].[Amount] * [EntryAmount].[Price] *
							CASE [Calculation].[DiscountType]
								WHEN 1 THEN (1 - [Calculation].[DiscountPercent]) --
								WHEN 2 THEN (1 +  [Calculation].[DiscountPercent]) --
								WHEN 3 THEN --
									CASE 
										WHEN [Calculation].[TotalWithoutDiscount] > [Calculation].[Discount] THEN [Calculation].[DiscountPercent]
										ELSE 1
									END
								WHEN 4 THEN [Calculation].[DiscountPercent] -- 
								ELSE 1
							END) - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate]) > 0					
					THEN 					
						(
							([EntryAmount].[Amount] * [EntryAmount].[Price] --    . 
							*
							CASE [Calculation].[DiscountType]
								WHEN 1 THEN (1 - [Calculation].[DiscountPercent]) --
								WHEN 2 THEN (1 +  [Calculation].[DiscountPercent]) --
								WHEN 3 THEN --
									CASE 
										WHEN [Calculation].[TotalWithoutDiscount] > [Calculation].[Discount] THEN [Calculation].[DiscountPercent]
										ELSE 1
									END
								WHEN 4 THEN [Calculation].[DiscountPercent] -- 
								ELSE 1
							END)
						- 
						[TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] --      . -
						)	
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END)
					*
						CASE [Project].[CurrencyCode]   
						WHEN @BaseCurrency THEN 1  
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency)   
						END  
			WHEN	[TimeType].[ID] = 6 --   ,  . ,  
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] = 2 OR 
						(@InvoiceClass = [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 5) OR
						(@InvoiceClass != [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 3))) --       
					AND [TimeEntriesInFinance].[LinkClass] <> @CalculationClass
					AND	([EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate]) < 0					
					THEN 					
						(
						[EntryAmount].[Amount] * [EntryAmount].[Price] --    . 
						- 
						[TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] --      . -
						)	
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END)
					*
						CASE [Project].[CurrencyCode]   
						WHEN @BaseCurrency THEN 1  
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency)   
						END
			WHEN	[TimeType].[ID] = 6 --   ,  
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] IN (2, 3))) --      
					AND [TimeEntriesInFinance].[LinkClass] = @CalculationClass
					AND	(([EntryAmount].[Amount] * [EntryAmount].[Price] *
							CASE [Calculation].[DiscountType]
								WHEN 1 THEN (1 - [Calculation].[DiscountPercent]) --
								WHEN 2 THEN (1 +  [Calculation].[DiscountPercent]) --
								WHEN 3 THEN --
									CASE 
										WHEN [Calculation].[TotalWithoutDiscount] > [Calculation].[Discount] THEN [Calculation].[DiscountPercent]
										ELSE 1
									END
								WHEN 4 THEN [Calculation].[DiscountPercent] -- 
								ELSE 1
							END) - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate]) < 0					
					THEN 					
						(
							([EntryAmount].[Amount] * [EntryAmount].[Price] --    . 
							*
							CASE [Calculation].[DiscountType]
								WHEN 1 THEN (1 - [Calculation].[DiscountPercent]) --
								WHEN 2 THEN (1 +  [Calculation].[DiscountPercent]) --
								WHEN 3 THEN --
									CASE 
										WHEN [Calculation].[TotalWithoutDiscount] > [Calculation].[Discount] THEN [Calculation].[DiscountPercent]
										ELSE 1
									END
								WHEN 4 THEN [Calculation].[DiscountPercent] -- 
								ELSE 1
							END)
						- 
						[TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] --      . -
						)	
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END)
					*
						CASE [Project].[CurrencyCode]   
						WHEN @BaseCurrency THEN 1  
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency)   
						END  
            ELSE NULL                  
        END,
		-- .   2
        CASE WHEN	[TimeType].[ID] = 2 
				AND [TimeEntry].[State] IN (3, 6) 
				AND [TimeEntry].[Billable] = 1 
				AND [Project].[ProjectTypeID] = 1 
				AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
				THEN ROUND(
						[TimeEntry].[RoundedDuration]/60.0,2)
					*
						[TimeEntry].[Rate]
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END) 
					*
						CASE [Project].[CurrencyCode]  
						WHEN @NationalCurrency	THEN 1 
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency) 
						END 
             WHEN	[TimeType].[ID] = 3				-- .   
				AND [TimeEntry].[State] IN (6) 
				AND [Project].[ProjectTypeID] = 1 
				AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
				AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] = 2 OR 
					(@InvoiceClass = [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 5) OR
					(@InvoiceClass != [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 3))) --       
				AND [TimeEntriesInFinance].[LinkClass] <> @CalculationClass
				THEN	
					[EntryAmount].[Amount] 
				* 
					[EntryAmount].[Price] 
				* 
					(1 -	CASE [Project].[RatesWithVAT] 
							WHEN 1  THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
							ELSE 0 
							END)
				*
					CASE [Project].[CurrencyCode]   
					WHEN @NationalCurrency  THEN 1  
					ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency)  
					END  
			----------------------
			 WHEN	[TimeType].[ID] = 3			-- 
				AND [TimeEntry].[State] IN (6) 
				AND [Project].[ProjectTypeID] = 1 
				AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
				AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] IN (2, 3))) --      
				AND [TimeEntriesInFinance].[LinkClass] = @CalculationClass
				THEN					
					ROUND(	  
					[EntryAmount].[Amount]
				*	
					[EntryAmount].[Price]
				*
					CASE [Calculation].[DiscountType]
					WHEN 1 THEN (1 - [Calculation].[DiscountPercent])
					WHEN 2 THEN (1 + [Calculation].[DiscountPercent])
					WHEN 3 THEN 
							CASE 
							WHEN [Calculation].[TotalWithoutDiscount] > [Calculation].[Discount] THEN [Calculation].[DiscountPercent]
							ELSE 1
							END
					WHEN 4 THEN [Calculation].[DiscountPercent]
					ELSE 1 
					END
				*
					(1 -	CASE [Project].[RatesWithVAT] 
							WHEN 1  THEN	 [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
									ELSE 0 END)
				*	
					CASE [Project].[CurrencyCode]   
					WHEN @NationalCurrency  THEN 1  
					ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency)  
					END
					,1)  
			----------------------
             WHEN	[TimeType].[ID] = 4 --   ,  . ,  
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] = 2 OR 
						(@InvoiceClass = [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 5) OR
						(@InvoiceClass != [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 3))) --       
					AND [TimeEntriesInFinance].[LinkClass] <> @CalculationClass					
					THEN 					
						(
						[EntryAmount].[Amount] * [EntryAmount].[Price] --    . 
						- 
						[TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] --      . -
						)	
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END)
					*
						CASE [Project].[CurrencyCode]   
						WHEN @NationalCurrency  THEN 1  
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency)  
						END
			WHEN	[TimeType].[ID] = 4 --   ,  
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] IN (2, 3))) --      
					AND [TimeEntriesInFinance].[LinkClass] = @CalculationClass				
					THEN 					
						(
							([EntryAmount].[Amount] * [EntryAmount].[Price] --    . 
							*
							CASE [Calculation].[DiscountType]
								WHEN 1 THEN (1 - [Calculation].[DiscountPercent]) --
								WHEN 2 THEN (1 +  [Calculation].[DiscountPercent]) --
								WHEN 3 THEN --
									CASE 
										WHEN [Calculation].[TotalWithoutDiscount] > [Calculation].[Discount] THEN [Calculation].[DiscountPercent]
										ELSE 1
									END
								WHEN 4 THEN [Calculation].[DiscountPercent] -- 
								ELSE 1
							END)
						- 
						[TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] --      . -
						)	
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END)
					*
						CASE [Project].[CurrencyCode]   
						WHEN @NationalCurrency  THEN 1  
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency)  
						END
			WHEN	[TimeType].[ID] = 5 --   ,  . ,  
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] = 2 OR 
						(@InvoiceClass = [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 5) OR
						(@InvoiceClass != [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 3)))--       
					AND [TimeEntriesInFinance].[LinkClass] <> @CalculationClass
					AND	([EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate]) > 0					
					THEN 					
						(
						[EntryAmount].[Amount] * [EntryAmount].[Price] --    . 
						- 
						[TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] --      . -
						)	
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END)
					*
						CASE [Project].[CurrencyCode]   
						WHEN @NationalCurrency  THEN 1  
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency)  
						END
			WHEN	[TimeType].[ID] = 5 --   ,  
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] IN (2, 3))) --      
					AND [TimeEntriesInFinance].[LinkClass] = @CalculationClass
					AND	(([EntryAmount].[Amount] * [EntryAmount].[Price] *
							CASE [Calculation].[DiscountType]
								WHEN 1 THEN (1 - [Calculation].[DiscountPercent]) --
								WHEN 2 THEN (1 +  [Calculation].[DiscountPercent]) --
								WHEN 3 THEN --
									CASE 
										WHEN [Calculation].[TotalWithoutDiscount] > [Calculation].[Discount] THEN [Calculation].[DiscountPercent]
										ELSE 1
									END
								WHEN 4 THEN [Calculation].[DiscountPercent] -- 
								ELSE 1
							END) - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate]) > 0					
					THEN 					
						(
							([EntryAmount].[Amount] * [EntryAmount].[Price] --    . 
							*
							CASE [Calculation].[DiscountType]
								WHEN 1 THEN (1 - [Calculation].[DiscountPercent]) --
								WHEN 2 THEN (1 +  [Calculation].[DiscountPercent]) --
								WHEN 3 THEN --
									CASE 
										WHEN [Calculation].[TotalWithoutDiscount] > [Calculation].[Discount] THEN [Calculation].[DiscountPercent]
										ELSE 1
									END
								WHEN 4 THEN [Calculation].[DiscountPercent] -- 
								ELSE 1
							END)
						- 
						[TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] --      . -
						)	
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END)
					*
						CASE [Project].[CurrencyCode]   
						WHEN @NationalCurrency  THEN 1  
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency)  
						END 
			WHEN	[TimeType].[ID] = 6 --   ,  . ,  
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] = 2 OR 
						(@InvoiceClass = [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 5) OR
						(@InvoiceClass != [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 3))) --       
					AND [TimeEntriesInFinance].[LinkClass] <> @CalculationClass
					AND	([EntryAmount].[Amount] * [EntryAmount].[Price] - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate]) < 0					
					THEN 					
						(
						[EntryAmount].[Amount] * [EntryAmount].[Price] --    . 
						- 
						[TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] --      . -
						)	
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END)
					*
						CASE [Project].[CurrencyCode]   
						WHEN @NationalCurrency  THEN 1  
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency)  
						END
			WHEN	[TimeType].[ID] = 6 --   ,  
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] IN (2, 3))) --      
					AND [TimeEntriesInFinance].[LinkClass] = @CalculationClass
					AND	(([EntryAmount].[Amount] * [EntryAmount].[Price] *
							CASE [Calculation].[DiscountType]
								WHEN 1 THEN (1 - [Calculation].[DiscountPercent]) --
								WHEN 2 THEN (1 +  [Calculation].[DiscountPercent]) --
								WHEN 3 THEN --
									CASE 
										WHEN [Calculation].[TotalWithoutDiscount] > [Calculation].[Discount] THEN [Calculation].[DiscountPercent]
										ELSE 1
									END
								WHEN 4 THEN [Calculation].[DiscountPercent] -- 
								ELSE 1
							END) - [TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate]) < 0					
					THEN 					
						(
							([EntryAmount].[Amount] * [EntryAmount].[Price] --    . 
							*
							CASE [Calculation].[DiscountType]
								WHEN 1 THEN (1 - [Calculation].[DiscountPercent]) --
								WHEN 2 THEN (1 +  [Calculation].[DiscountPercent]) --
								WHEN 3 THEN --
									CASE 
										WHEN [Calculation].[TotalWithoutDiscount] > [Calculation].[Discount] THEN [Calculation].[DiscountPercent]
										ELSE 1
									END
								WHEN 4 THEN [Calculation].[DiscountPercent] -- 
								ELSE 1
							END)
						- 
						[TimeEntry].[RoundedDuration]/60.0 * [TimeEntry].[Rate] --      . -
						)	
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END)
					*
						CASE [Project].[CurrencyCode]   
						WHEN @NationalCurrency  THEN 1  
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency)  
						END                   
             ELSE NULL                  
        END
	FROM
        [ProjectType]
        CROSS JOIN @TimeType AS [TimeType]
        CROSS JOIN [TimeEntry] AS [TimeEntry]
        INNER JOIN [EntryAmount]
            ON [EntryAmount].[ID] = [TimeEntry].[ID]
        INNER JOIN [Project]
            ON [Project].[ID] = [TimeEntry].[ProjectID]
		LEFT OUTER JOIN										--    ,   
		@TimeEntriesInFinance AS [TimeEntriesInFinance] 	
			ON [TimeEntriesInFinance].[DocumentID] = [TimeEntry].[ID]
		LEFT OUTER JOIN 
		[Calculation] AS [Calculation]
			ON [Calculation].[ID] = [TimeEntriesInFinance].[LinkDocumentID]
	WHERE 
		[EmployeeID] = @EmployeeID AND
		[StartTime] >= @StartDate AND [StartTime] < @EndDate
		AND ([TimeEntriesInFinance].ThroughCalculation = 0 OR [TimeEntriesInFinance].ThroughCalculation IS NULL)
  )


INSERT INTO @PostProcessTable
SELECT [State],
       [ProjectType],
       ISNULL(ABS(SUM([Duration])),0) AS [Duration],
       ISNULL(SUM([Value1]),0) AS [Value1],
       ISNULL(SUM([Value2]),0) AS [Value2]
FROM [TimeEntryTypes]
GROUP BY [ProjectType],[State]
--HAVING SUM([Duration]) <> 0
ORDER BY [ProjectType],[State]


DECLARE 
	@TmpProjectType int,
	@I int = 1
--  
DECLARE EmptyStringsCursor CURSOR FAST_FORWARD FOR
	SELECT [ProjectType] FROM @PostProcessTable
OPEN EmptyStringsCursor
FETCH NEXT FROM EmptyStringsCursor INTO @TmpProjectType
WHILE @@FETCH_STATUS = 0
BEGIN
	
	WHILE @I < 10
	BEGIN
		--,      
		IF EXISTS (SELECT * FROM @PostProcessTable WHERE [ProjectType] = @TmpProjectType AND [State] = @I AND [Duration] = 0 AND [Value1] = 0 AND [Value2] = 0)
		BEGIN
			--   -  
			DELETE FROM @PostProcessTable 
			WHERE [ProjectType] = @TmpProjectType AND [State] = @I AND [Duration] = 0 AND [Value1] = 0 AND [Value2] = 0
		END
		SET @I = @I + 1
	END
	
	SET @I = 1
	FETCH NEXT FROM EmptyStringsCursor INTO @TmpProjectType
END
CLOSE EmptyStringsCursor
DEALLOCATE EmptyStringsCursor

SET @TmpProjectType = NULL

--   / ,   
DECLARE DeviationCursor CURSOR FAST_FORWARD FOR
	SELECT [ProjectType] FROM @PostProcessTable
OPEN DeviationCursor
FETCH NEXT FROM DeviationCursor INTO @TmpProjectType
WHILE @@FETCH_STATUS = 0
BEGIN

	--  
	IF EXISTS (SELECT * FROM @PostProcessTable WHERE [ProjectType] = @TmpProjectType AND [State] = 4)
	BEGIN
		--     , ..  ,   
		IF NOT EXISTS (SELECT * FROM @PostProcessTable WHERE [ProjectType] = @TmpProjectType AND [State] = 5)
		INSERT INTO @PostProcessTable
		SELECT
			5,
			@TmpProjectType,
			0,
			0,
			0
		
		--     , ..  ,   	
		IF NOT EXISTS (SELECT * FROM @PostProcessTable WHERE [ProjectType] = @TmpProjectType AND [State] = 6)
		INSERT INTO @PostProcessTable
		SELECT
			6,
			@TmpProjectType,
			0,
			0,
			0		
	END
	
	FETCH NEXT FROM DeviationCursor INTO @TmpProjectType
END
CLOSE DeviationCursor
DEALLOCATE DeviationCursor

SELECT	
	[State],
    [ProjectType],
    ISNULL(ABS([Duration]),0) AS [Duration],
    CASE WHEN @HasViewAllFinance = 1 
		THEN ISNULL(ABS([Value1]),0)
		ELSE 0
	END	AS [Value1],
    CASE WHEN @HasViewAllFinance = 1 
		THEN ISNULL(ABS([Value2]),0)
		ELSE 0
	END	AS [Value2]
FROM 
	@PostProcessTable 
ORDER BY 
	[ProjectType],[State]

SELECT @CompanyFileAs AS [CompanyFileAs],
       @DivisionFileAs AS [DivisionFileAs],
       @EmployeeFileAs AS [EmployeeFileAS],
       @EmployeeNumber AS [EmployeeNumber],
       @EmployeePosition AS  [EmployeePosition],
       @WorkingDays AS [WorkingDays],
       @WorkingDays*8 AS [WorkingHours],
       @DateSelector AS [DateSelector],
       @StartDate AS [StartDate],
       DATEADD(day, -1, @EndDate) as [EndDate],
       @UserName AS [UserName],
       @BaseCurrency AS [BaseCurrency],
       @NationalCurrency AS [NationalCurrency]
GO

GRANT EXEC ON ReportEmployeeTimeAllocationByPeriod TO PUBLIC

GO

