IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportProjectPlanOfOperation')
	BEGIN
		PRINT 'Dropping Procedure ReportProjectPlanOfOperation'
		DROP  Procedure  ReportProjectPlanOfOperation
	END

GO

PRINT 'Creating Procedure ReportProjectPlanOfOperation'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportProjectPlanOfOperation
	@PeriodStart		datetime,
	@PeriodEnd			datetime,
	@DateSelector		int,
	@ProjectSelector	int,
	@ActiveProjectID	TIdentifier,
	@NotActiveProjectID TIdentifier,
	@MilestoneSelector	int
	
AS
	IF @ProjectSelector = 0 AND @ActiveProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
	IF @ProjectSelector = 1 AND @NotActiveProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END	
	
	SET NOCOUNT ON
	
	DECLARE 
		@DayCount	int,
		@ProjectID TIdentifier
		
	SET @ProjectID = CASE @ProjectSelector
			WHEN 0 THEN @ActiveProjectID
			WHEN 1 THEN @NotActiveProjectID
			END	
			
	SET @DayCount = DATEPART(day, GETDATE())
	SET @PeriodStart = CASE	@DateSelector
		WHEN 1 THEN CAST(CONVERT(varchar(8), DATEADD(day, 1-@DayCount, GETDATE()), 112) AS datetime)
		WHEN 2 THEN CAST(CONVERT(varchar(8), DATEADD(month, 1, DATEADD(day, 1-@DayCount, GETDATE())), 112) AS datetime)
		ELSE CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime)
	END
	SET @PeriodEnd = DATEADD(month, 1, @PeriodStart)		
		
	EXECUTE ReportProjectPlanOfOperationHeader @ProjectID, @PeriodStart, @PeriodEnd, @DateSelector 
	
	;WITH [SummaryTask] ([ID], [SubCount]) AS
	(
		SELECT
			[Parent].[ID],
			COUNT([Child].[ID]) 
		FROM 
			[Task] AS [Parent] 
			LEFT OUTER JOIN [Task] AS [Child] 
				ON [Child].[ParentID] = [Parent].[ID]
		WHERE
			[Parent].[ProjectID] = @ProjectID
		GROUP BY
			[Parent].[ID]
	)
	SELECT
		CASE WHEN
			[Task].[SubprojectID] IS NULL
			THEN
				[Task].[FileAs]
			ELSE
				[Project].[FileAs]
		END AS [TaskName], -- 
		[Task].[State] AS [TaskState],-- 
		[Task].[Duration] AS [Duration],--    
		[Task].[ManHour] / 60.00 AS [ManHour], -- 
		[Task].[DueDate],--
		[Task].[StartDate],-- 
		dbo.fnPjm5GetAssignmentListByTask([Task].[ID]) AS [AssignmentList]
	FROM
		[Task]
		INNER JOIN [SummaryTask] ON 
		(
			[SummaryTask].[ID] = [Task].[ID]
			AND
			[SummaryTask].[SubCount] = 0
		)
		LEFT OUTER JOIN [Project]
			ON [Project].[ID] = [Task].[SubprojectID]
	WHERE
		[Task].[ProjectID] = @ProjectID AND
		(([Task].[DueDate] >= @PeriodStart AND [Task].[StartDate] < @PeriodEnd) OR @DateSelector = 0) AND
		(([Task].[Milestone] = 1 AND @MilestoneSelector = 1) OR @MilestoneSelector = 0)
	
RETURN 0
GO

GRANT EXEC ON ReportProjectPlanOfOperation TO PUBLIC

GO
