IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportProjectTimeAllocationByEmployee')
	BEGIN
		PRINT 'Dropping Procedure ReportProjectTimeAllocationByEmployee'
		DROP  Procedure  ReportProjectTimeAllocationByEmployee
	END
GO
PRINT 'Creating Procedure ReportProjectTimeAllocationByEmployee'
GO
/******************************************************************************
**		File: ReportProjectTimeAllocationByEmployee.sql
**		Name: ReportProjectTimeAllocationByEmployee
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: MAN
**		Date: 18/11/2010 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		18.11.2010	MAN				First Version
**		22.11.13	BAO				   
**		26.11.13	SAP				   
*******************************************************************************/

CREATE PROCEDURE [dbo].[ReportProjectTimeAllocationByEmployee]
        @CompanyID		TIdentifier, -- ID 
        @DivisionID		TIdentifier, -- ID 
        @DateSelector	TIdentifier, --    (SelectedIndex  )
        @PeriodStart	TdateTime,	 --   
		@PeriodEnd		TdateTime,	 --   
		@RoundedType	TIdentifier  --    : 0 -  , 1 -  
AS
SET NOCOUNT ON

--  
IF  dbo.adfHasAccessRightByName('ViewProjectTimeAllocationByEmployeeReport') = 0 
BEGIN
      RAISERROR('#NotEnoughPermissions', 18, -1)
      RETURN 1
END

DECLARE
	@PeriodName TName --  
-- 
EXEC ReportGetPeriod 
	@DateSelector,			--   
	@PeriodStart OUTPUT,	--  
	@PeriodEnd	 OUTPUT,	--  
	@PeriodName  OUTPUT		--  
-- 	
DECLARE @Result TABLE        
(
	ProjectID		TIdentifier,
	EmployeeID		TIdentifier,
	EmployeeName	TName,		 --  
	ProjectNumber	TName,		 --  
	ProjectOrder	TIdentifier, --    
	TimeDuration	TAmount		 -- 
)
--   (  )
INSERT INTO @Result
(
	ProjectID,
	EmployeeID,
	EmployeeName,
	ProjectNumber,
	ProjectOrder,
	TimeDuration
)
SELECT
	[Project].[ID],
	[Employee].[ID],
	CASE
		WHEN (([Employee].[LastName] IS NULL) OR ([Employee].[LastName] = ''))
			THEN [Employee].[FileAs]  --   ,   " "
		WHEN ((([Employee].[FirstName] IS NULL) OR ([Employee].[FirstName] = '')) 
			AND (([Employee].[MiddleName] IS NULL) OR ([Employee].[MiddleName] = '')))
			THEN [Employee].[LastName]	--     ,   
		WHEN (([Employee].[FirstName] IS NULL) OR ([Employee].[FirstName] = ''))
			THEN [Employee].[LastName]	--   ,   
		WHEN (([Employee].[MiddleName] IS NULL) OR ([Employee].[MiddleName] = ''))	--   ,      
			THEN [Employee].[LastName] + ' ' + SUBSTRING(CAST([Employee].[FirstName] as varchar), 1, 1) + '.'
		ELSE
			[Employee].[LastName] + ' ' + SUBSTRING([Employee].[FirstName], 1, 1) + '.' + SUBSTRING([Employee].[MiddleName], 1, 1) + '.'
	END AS [EmployeeName],
	'', --   (  )
	0, --     
	CASE @RoundedType --    
		WHEN 0 THEN --   
			CASE [Project].[RoundingMode]
				WHEN 0 THEN [TimeEntry].[Duration] 
				ELSE [TimeEntry].[RoundedDuration]
			END
		WHEN 1 THEN [TimeEntry].[Duration]
	END / 60.0 AS [TimeDuration] 
FROM
	[TimeEntry]
	INNER JOIN [Employee]  --         
		ON [TimeEntry].[EmployeeID] = [Employee].[ID] 
	INNER JOIN [Project]
		ON [Project].[ID] = [TimeEntry].[ProjectID]
WHERE
	[TimeEntry].[State] IN (2,3,6) --   , , 
	AND
	[TimeEntry].[StartTime] >= @PeriodStart
	AND
	[TimeEntry].[StartTime] < @PeriodEnd
	AND --   
	(
		(
			@CompanyID IS NULL
			AND
			[Employee].[CompanyID] IN
			(
				SELECT
					[Company].[ID]
				FROM
					[Company]
				WHERE
					[Company].[Own] = 1
			)
		)
		OR
		[Employee].[CompanyID] = @CompanyID
	)
	AND --   
	(
		@DivisionID IS NULL
		OR
		[Employee].[DivisionID] = @DivisionID
	)
--  ""   
INSERT INTO @Result
(
	ProjectID,
	EmployeeID,
	EmployeeName,
	ProjectNumber,
	ProjectOrder,
	TimeDuration
)
SELECT
	[Project].[ID],
	[Employee].[ID],
	CASE
		WHEN (([Employee].[LastName] IS NULL) OR ([Employee].[LastName] = ''))
			THEN [Employee].[FileAs]  
		WHEN ((([Employee].[FirstName] IS NULL) OR ([Employee].[FirstName] = '')) 
			AND (([Employee].[MiddleName] IS NULL) OR ([Employee].[MiddleName] = '')))
			THEN [Employee].[LastName]	
		WHEN (([Employee].[FirstName] IS NULL) OR ([Employee].[FirstName] = ''))
			THEN [Employee].[LastName]	
		WHEN (([Employee].[MiddleName] IS NULL) OR ([Employee].[MiddleName] = ''))	
			THEN [Employee].[LastName] + ' ' + SUBSTRING([Employee].[FirstName], 1, 1) + '.'
		ELSE
			[Employee].[LastName] + ' ' + SUBSTRING([Employee].[FirstName], 1, 1) + '.' + SUBSTRING([Employee].[MiddleName], 1, 1) + '.'
	END AS [EmployeeName],
	CASE [Project].[ProjectTypeID] --   
		WHEN 1 THEN '  '
		WHEN 2 THEN ' '
		WHEN 3 THEN ' '
		WHEN 4 THEN ''
		WHEN 5 THEN ''
		WHEN 6 THEN ''
	END AS [ProjectNumber],
	[Project].[ProjectTypeID], --        
	CASE @RoundedType
		WHEN 0 THEN
			CASE [Project].[RoundingMode]
				WHEN 0 THEN [TimeEntry].[Duration]
				ELSE [TimeEntry].[RoundedDuration]
			END
		WHEN 1 THEN [TimeEntry].[Duration]
	END / 60.0 AS [TimeDuration]
FROM
	[TimeEntry]
	INNER JOIN [Employee]
		ON [TimeEntry].[EmployeeID] = [Employee].[ID]
	INNER JOIN [Project]
		ON [Project].[ID] = [TimeEntry].[ProjectID]
WHERE
	[TimeEntry].[State] IN (2,3,6) --   , , 
	AND
	[TimeEntry].[StartTime] >= @PeriodStart
	AND
	[TimeEntry].[StartTime] < @PeriodEnd
	AND --   
	(
		(
			@CompanyID IS NULL
			AND
			[Employee].[CompanyID] IN
			(
				SELECT
					[Company].[ID]
				FROM
					[Company]
				WHERE
					[Company].[Own] = 1
			)
		)
		OR
		[Employee].[CompanyID] = @CompanyID
	)
	AND --   
	(
		@DivisionID IS NULL
		OR
		[Employee].[DivisionID] = @DivisionID
	)
--  ""   
INSERT INTO @Result
(
	ProjectID,
	EmployeeID,
	EmployeeName,
	ProjectNumber,
	ProjectOrder,
	TimeDuration
)
SELECT
	[Project].[ID],
	[Employee].[ID],
	CASE
		WHEN (([Employee].[LastName] IS NULL) OR ([Employee].[LastName] = ''))
			THEN [Employee].[FileAs]  
		WHEN ((([Employee].[FirstName] IS NULL) OR ([Employee].[FirstName] = '')) 
			AND (([Employee].[MiddleName] IS NULL) OR ([Employee].[MiddleName] = '')))
			THEN [Employee].[LastName]	
		WHEN (([Employee].[FirstName] IS NULL) OR ([Employee].[FirstName] = ''))
			THEN [Employee].[LastName]	
		WHEN (([Employee].[MiddleName] IS NULL) OR ([Employee].[MiddleName] = ''))	
			THEN [Employee].[LastName] + ' ' + SUBSTRING([Employee].[FirstName], 1, 1) + '.'
		ELSE
			[Employee].[LastName] + ' ' + SUBSTRING([Employee].[FirstName], 1, 1) + '.' + SUBSTRING([Employee].[MiddleName], 1, 1) + '.'
	END AS [EmployeeName],
	[Project].[Number] AS [ProjectNumber],
	7, --  :   
	CASE @RoundedType
		WHEN 0 THEN
			CASE [Project].[RoundingMode]
				WHEN 0 THEN [TimeEntry].[Duration]
				ELSE [TimeEntry].[RoundedDuration]
			END
		WHEN 1 THEN [TimeEntry].[Duration]
	END / 60.0 AS [TimeDuration]
FROM
	[TimeEntry]
	INNER JOIN [Employee]
		ON [TimeEntry].[EmployeeID] = [Employee].[ID]
	INNER JOIN [Project]
		ON [Project].[ID] = [TimeEntry].[ProjectID]
WHERE
	[Project].[ProjectTypeID] = 1 --   
	AND
	[TimeEntry].[State] IN (2,3,6) --   , , 
	AND
	[TimeEntry].[StartTime] >= @PeriodStart
	AND
	[TimeEntry].[StartTime] < @PeriodEnd
	AND --   
	(
		(
			@CompanyID IS NULL
			AND
			[Employee].[CompanyID] IN
			(
				SELECT
					[Company].[ID]
				FROM
					[Company]
				WHERE
					[Company].[Own] = 1
			)
		)
		OR
		[Employee].[CompanyID] = @CompanyID
	)
	AND --   
	(
		@DivisionID IS NULL
		OR
		[Employee].[DivisionID] = @DivisionID
	)

--  
SELECT
	-1 as [ProjectID],
	[@Result].[EmployeeID],
	[@Result].[EmployeeName],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
WHERE 
	[@Result].[ProjectNumber] = '  '
GROUP BY
	[@Result].[EmployeeName],
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber],
	[@Result].[EmployeeID]
UNION
SELECT
	-2 as [ProjectID],
	[@Result].[EmployeeID],
	[@Result].[EmployeeName],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
WHERE 
	[@Result].[ProjectNumber] = ' '
GROUP BY
	[@Result].[EmployeeName],
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber],
	[@Result].[EmployeeID]
UNION
SELECT
	-3 as [ProjectID],
	[@Result].[EmployeeID],
	[@Result].[EmployeeName],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
WHERE 
	[@Result].[ProjectNumber] = ' '
GROUP BY
	[@Result].[EmployeeName],
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber],
	[@Result].[EmployeeID]
UNION
SELECT
	-4 as [ProjectID],
	[@Result].[EmployeeID],
	[@Result].[EmployeeName],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
WHERE 
	[@Result].[ProjectNumber] = ''
GROUP BY
	[@Result].[EmployeeName],
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber],
	[@Result].[EmployeeID]
UNION
SELECT
	-5 as [ProjectID],
	[@Result].[EmployeeID],
	[@Result].[EmployeeName],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
WHERE 
	[@Result].[ProjectNumber] = ''
GROUP BY
	[@Result].[EmployeeName],
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber],
	[@Result].[EmployeeID]
UNION
SELECT
	-6 as [ProjectID],
	[@Result].[EmployeeID],
	[@Result].[EmployeeName],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
WHERE 
	[@Result].[ProjectNumber] = ''
GROUP BY
	[@Result].[EmployeeName],
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber],
	[@Result].[EmployeeID]
UNION
SELECT
	-7 as [ProjectID],
	[@Result].[EmployeeID],
	[@Result].[EmployeeName],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
WHERE 
	[@Result].[ProjectNumber] = ''
GROUP BY
	[@Result].[EmployeeName],
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber],
	[@Result].[EmployeeID]
UNION
SELECT
	[@Result].[ProjectID],
	[@Result].[EmployeeID],
	[@Result].[EmployeeName],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
WHERE 
	[@Result].[ProjectNumber] NOT IN ('  ', ' ', ' ',
									'', '', '', '')
GROUP BY
	[@Result].[ProjectID],
	[@Result].[EmployeeName],
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber],
	[@Result].[EmployeeID]


SELECT
	-1 as [ProjectID],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
WHERE
	[@Result].[ProjectNumber] = '  '
GROUP BY
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber]
UNION
SELECT
	-2 as [ProjectID],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
WHERE
	[@Result].[ProjectNumber] = ' '
GROUP BY
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber]
UNION
SELECT
	-3 as [ProjectID],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
WHERE
	[@Result].[ProjectNumber] = ' '
GROUP BY
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber]
UNION
SELECT
	-4 as [ProjectID],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
WHERE
	[@Result].[ProjectNumber] = ''
GROUP BY
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber]
UNION
SELECT
	-5 as [ProjectID],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
WHERE
	[@Result].[ProjectNumber] = ''
GROUP BY
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber]
UNION
SELECT
	-6 as [ProjectID],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
WHERE
	[@Result].[ProjectNumber] = ''
GROUP BY
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber]
UNION
SELECT
	-7 as [ProjectID],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
WHERE
	[@Result].[ProjectNumber] = ''
GROUP BY
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber]
UNION
SELECT
	[@Result].[ProjectID],
	[@Result].[ProjectNumber],
	[@Result].[ProjectOrder],
	SUM( [@Result].[TimeDuration] ) AS [TimeDuration]
FROM
	@Result
WHERE
	[@Result].[ProjectNumber] NOT IN ('  ', ' ', ' ',
									'', '', '', '')
GROUP BY
	[@Result].[ProjectID],
	[@Result].[ProjectOrder],
	[@Result].[ProjectNumber]
		
--  
EXEC ReportProjectTimeAllocationByEmployeeHeader
	    @CompanyID,
        @DivisionID ,
        @PeriodName,
        @PeriodStart,
        @PeriodEnd,
        @RoundedType
        
RETURN 0
GO

GRANT EXEC ON ReportProjectTimeAllocationByEmployee TO PUBLIC
GO

