IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportRevenueAnalysisByProjects')
	BEGIN
		PRINT 'Dropping Procedure ReportRevenueAnalysisByProjects'
		DROP  Procedure  ReportRevenueAnalysisByProjects
	END

GO

PRINT 'Creating Procedure ReportRevenueAnalysisByProjects'
GO

/******************************************************************************
**		File: ReportRevenueAnalysisByProjects.sql
**		Name: ReportRevenueAnalysisByProjects
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: MAN
**		Date: 23/08/2010 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		23.08.2010	MAN				First Version
*******************************************************************************/
CREATE Procedure dbo.ReportRevenueAnalysisByProjects
	@CompanyID				TIdentifier,
	@CostCenterSelector		TIdentifier,
	@CostCenterID			TIdentifier,
	@ProjectManagerID		TIdentifier,
	@ProjectID				TIdentifier,
	@DateTypeSelector		TIdentifier,
	@PeriodStart			TDateTime,
	@PeriodEnd				TDateTime,
	@CurrencySelector		TAmount
AS
	SET NOCOUNT ON

DECLARE
	@CompanyFileAS			TName,		--  
	@CostCenterFileAs		TName,		--   
	@ProjectManagerFileAs	TName,		--  
	@ProjectFileAs			TName,		--  
	@PeriodCode				TName, 
	@UserId					TIdentifier,
	@UserName				TName,
	@RequiredFieldFlag		TIdentifier, --    
	@MAXValue				TAmount,
	@Rate					float,
    @Prefix					varchar(5),
    @PeriodName				TName,
	@ProjectXML				XML
	
--  
IF  dbo.adfHasAccessRightByName('ViewRevenueAnalysisByProjectReport') = 0 
BEGIN
      RAISERROR('#NotEnoughPermissions', 18, -1)
      RETURN 1
END
	
DECLARE @Result TABLE 
(
	ProjectID			TIdentifier,
	ProjectNumber		TName,	
	TimeMarked			TAmount, -- : 
	TimeBillable		TAmount, -- :  
	TimeSold			TAmount, -- :  
	ExpenseMarked		TAmount, -- : 
	ExpenseBillable		TAmount, -- :  
	ExpenseSold			TAmount, -- :  
	CostingBillable		TAmount, -- :  
	CostingRegistered	TAmount, -- : 
	CostingApproved		TAmount, -- : 
	RevenueSold			TAmount, -- :  
	RevenueApproved		TAmount, -- : 
	RevenueSigned		TAmount, -- : 
	RevenuePaid			TAmount	 -- : 
)

SET @RequiredFieldFlag = 3 --            

-- 
EXEC ReportGetPeriod 
	@DateTypeSelector,		--   
	@PeriodStart OUTPUT,	--  
	@PeriodEnd	 OUTPUT,	--  
	@PeriodName  OUTPUT		--  
	
DECLARE 
	@CurrencyCode TCode3
	--      	
	SET @CurrencyCode = 
	CASE @CurrencySelector
		WHEN 0 THEN dbo.fnPjm5GetBaseCurrency()
		WHEN 1 THEN dbo.fnPjm5GetNationalCurrency()
	END
	
--  
EXEC ReportRevenueAnalysisByProjectsHeader
	@CompanyID,
	@CostCenterID, 
	@ProjectManagerID, 
	@ProjectID, 
	@PeriodName, 
	@CurrencyCode
	
IF @CostCenterSelector = 0
	SET @CostCenterID = -1
	
--   
INSERT INTO @Result (ProjectID,ProjectNumber)
	SELECT
		[ProjectID],
		[ProjectNumber]
	FROM
		fnReportGetAvailableProjects 
		(
			@CompanyID,
			@CostCenterID,
			@ProjectManagerID,
			@ProjectID,
			@PeriodStart,
			@PeriodEnd,
			@RequiredFieldFlag,
			1 --   
		)
--  XML
SET @ProjectXML =
( 			
	SELECT
		[ProjectID]
	FROM
		@Result
	FOR XML RAW
)
--   - 
UPDATE 
	@Result
SET 
	[@Result].[TimeMarked]	 = [Times].[TimeMarked],	--  : 
	[@Result].[TimeBillable] = [Times].[TimeBillable],  --  :  
	[@Result].[TimeSold]	 = [Times].[TimeSold]       --  :  
FROM
	fnReportGetTimeDurationSum( @PeriodStart, @PeriodEnd, @ProjectXML ) AS [Times]
WHERE
	[Times].[ProjectID] = [@Result].[ProjectID]

--   - 
UPDATE 
	@Result
SET 
	[@Result].[ExpenseMarked]	= [Expenses].[ExpenseMarked],   --  : 
	[@Result].[ExpenseBillable]	= [Expenses].[ExpenseBillable], --  :  
	[@Result].[ExpenseSold]		= [Expenses].[ExpenseSold]		--  :  
FROM
	fnReportGetExpense(@PeriodStart, @PeriodEnd, @CurrencyCode ,@ProjectXML) AS [Expenses]
WHERE
	[Expenses].[ProjectID] = [@Result].[ProjectID]
	
--   -   
UPDATE 
	@Result
SET 
	[@Result].[CostingBillable]		= 	ISNULL([TimeCost].[TimeCostingBillable],0),		--  :  
	[@Result].[CostingRegistered]	=  	ISNULL([TimeCost].[TimeCostingRegistered],0) ,	--  : 
	[@Result].[CostingApproved]		= 	ISNULL([TimeCost].[TimeCostingApproved],0),		--  : 
	[@Result].[RevenueSold]			= 	ISNULL([TimeCost].[TimeRevenueSold],0),			--  :  
	[@Result].[RevenueApproved]		= 	ISNULL([TimeCost].[TimeRevenueApproved],0),		--  : 
	[@Result].[RevenueSigned]		= 	ISNULL([TimeCost].[TimeRevenueSigned],0)		--  : 
FROM

	 fnReportGetTimeCostSum (@PeriodStart, @PeriodEnd, @CurrencyCode,@ProjectXML) AS [TimeCost]
WHERE
	[TimeCost].[ProjectID] =  [@Result].[ProjectID]
	
UPDATE 
	@Result
SET 
	[@Result].[CostingBillable]		= ISNULL([@Result].[CostingBillable],0) +  ISNULL([ExpenseCost].[ExpenseCostingBillable],0),  --  :  
	[@Result].[CostingRegistered]	= ISNULL([@Result].[CostingRegistered],0) + ISNULL([ExpenseCost].[ExpenseCostingRegistered],0),--  : 
	[@Result].[CostingApproved]		= ISNULL([@Result].[CostingApproved],0)	+  ISNULL([ExpenseCost].[ExpenseCostingApproved],0),	 --  : 
	[@Result].[RevenueSold]			= ISNULL([@Result].[RevenueSold],0) + ISNULL([ExpenseCost].[ExpenseRevenueSold],0),	     --  :  
	[@Result].[RevenueApproved]		= ISNULL([@Result].[RevenueApproved],0)	+ ISNULL([ExpenseCost].[ExpenseRevenueApproved],0),  --  : 
	[@Result].[RevenueSigned]		= ISNULL([@Result].[RevenueSigned],0) + ISNULL([ExpenseCost].[ExpenseRevenueSigned],0)	 --  : 
FROM
	 fnReportGetExpenseCostSum (@PeriodStart, @PeriodEnd, @CurrencyCode,@ProjectXML) AS [ExpenseCost]
WHERE
	[ExpenseCost].[ProjectID] = [@Result].[ProjectID]
	
		
UPDATE 
	@Result
SET [@Result].[RevenuePaid] = [TableRevenuePaid].[Value]
FROM
	dbo.fnReportGetRevenuePaid( @ProjectXML, @PeriodStart, @PeriodEnd, @CurrencyCode) AS [TableRevenuePaid]
WHERE
	[TableRevenuePaid].[ProjectID] = [@Result].[ProjectID]

SET @MAXValue = 
	(
		SELECT
	MAX
	(
		[MaxValues].[MaxVal]
	)
FROM
(
	SELECT MAX(ISNULL([@Result].[ExpenseMarked],0)) as MaxVal FROM @Result
	UNION
	SELECT	MAX(ISNULL([@Result].[ExpenseBillable],0) )as MaxVal FROM @Result
	UNION
	SELECT	MAX(ISNULL([@Result].[ExpenseSold],0) )	as MaxVal FROM @Result	
	UNION
	SELECT MAX(ISNULL([@Result].[CostingBillable],0)) as MaxVal	FROM @Result		
	UNION
	SELECT	MAX(ISNULL([@Result].[CostingRegistered],0)) as MaxVal FROM @Result		
	UNION
	SELECT	MAX(ISNULL([@Result].[CostingApproved],0)) as MaxVal FROM @Result	
	UNION
	SELECT	MAX(ISNULL([@Result].[RevenueSold],0)) as MaxVal FROM @Result		
	UNION
	SELECT	MAX(ISNULL([@Result].[RevenueApproved],0)) as MaxVal FROM @Result		
	UNION
	SELECT	MAX(ISNULL([@Result].[RevenueSigned],0)) as MaxVal FROM @Result	
	UNION
	SELECT	MAX(ISNULL([@Result].[RevenuePaid],0)) as MaxVal FROM @Result	
) AS MaxValues
)
-- SMART VALUE
	
SET @Rate = CASE  
                 WHEN @MAXValue<1000 THEN 1
                 WHEN @MAXValue>=1000 and @MAXValue<10000000 THEN 0.001
                 WHEN @MAXValue>=10000000 and @MAXValue<10000000000 THEN 0.000001
                 WHEN @MAXValue>=10000000000 THEN 0.000000001
            END
SET @Prefix = CASE  
                 WHEN @MAXValue<1000 THEN ''
                 WHEN @MAXValue>=1000 and @MAXValue<10000000 THEN '.'
                 WHEN @MAXValue>=10000000 and @MAXValue<10000000000 THEN '.'
                 WHEN @MAXValue>=10000000000 THEN '.'
            END
	
--   
SELECT 
	[@Result].[ProjectID],
	[@Result].[ProjectNumber],
	[@Result].[TimeMarked],
	[@Result].[TimeBillable],
	[@Result].[TimeSold],
	( 
		ISNULL([@Result].[TimeMarked],0) - ISNULL([@Result].[TimeSold],0)
	) AS [TimeDeviation],
	[@Result].[ExpenseMarked]	* @Rate as [ExpenseMarked],
	[@Result].[ExpenseBillable] * @Rate as [ExpenseBillable],
	[@Result].[ExpenseSold]		* @Rate as [ExpenseSold],
	( 
		ISNULL([@Result].[ExpenseMarked],0) - ISNULL([@Result].[ExpenseSold],0)
	) * @Rate AS [ExpenseDeviation],
	[@Result].[CostingBillable]		* @Rate AS [CostingBillable],	
	[@Result].[CostingRegistered]	* @Rate AS [CostingRegistered],	
	[@Result].[CostingApproved]		* @Rate AS [CostingApproved],
	[@Result].[RevenueSold]			* @Rate AS [RevenueSold],
	[@Result].[RevenueApproved]		* @Rate AS [RevenueApproved],
	[@Result].[RevenueSigned]		* @Rate AS [RevenueSigned],
	[@Result].[RevenuePaid]			* @Rate 
	--* [@Result].[RevenueApproved]
	 AS [RevenuePaid],
	(
		ISNULL([@Result].[CostingBillable],0) - ISNULL([@Result].[RevenuePaid],0)
	) * @Rate AS [Deviation],
	@Prefix AS [Prefix]
FROM 
	@Result
	
RETURN 0
GO
GRANT EXEC ON ReportRevenueAnalysisByProjects TO PUBLIC
GO
