IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportWRE')
	BEGIN
		PRINT 'Dropping Procedure ReportWRE'
		DROP  Procedure  ReportWRE
	END

GO

PRINT 'Creating Procedure ReportWRE'
GO
/******************************************************************************
**		File: 
**		Name: ReportWRE
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		31.07.2013	BAO				 ISNULL -  NULL  0
**
**									 :
**									UNION ALL
**									SELECT NULL,0,0,0,0,0,0,0,0,0
**									 ,     
*******************************************************************************/
CREATE Procedure ReportWRE
	@CompanyID		TIdentifier,
	@DateSelector   int,
	@WeekStart	    TDateTime,
	@DivisionSelector int,
	@DivisionID		TIdentifier
AS
	SET NOCOUNT ON
	SET DATEFIRST 1
	
	IF @DivisionID IS NULL AND @DivisionSelector=2 
	BEGIN
		RAISERROR('#DivisionIsNotSelected', 16, -1)
		RETURN 1
	END
	
	
	DECLARE 
		@Date		TDate,
		@NextDate	TDate,
		@LastSymbol	char(8)	
		
		SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)
	
		SET @WeekStart = CASE @DateSelector
			WHEN 0 THEN DATEADD(day, 1 - DATEPART(weekday, @Date), @Date)
			WHEN 1 THEN DATEADD(week, -1, DATEADD(day, 1 - DATEPART(weekday, @Date), @Date))
			ELSE CAST(CONVERT(varchar(8), @WeekStart, 112) AS datetime)
		END
		
		SET @NextDate = CASE @DateSelector
			WHEN 0 THEN DATEADD(day, 1, @Date)
			ELSE DATEADD(week, 1, @WeekStart)
		END	
		
	
	EXECUTE ReportWREHeader @CompanyID, @WeekStart, @NextDate, @DivisionID, @DivisionSelector
	
	DECLARE 
		@t table(
		[EmployeeID]	int,
		[Day]			int,
		[Sum]			decimal(18,2),
		[Approved]		decimal(18,2),
		[Calculation]	decimal(18,2)
		)
	INSERT INTO @t(
		[EmployeeID],
		[Day],
		[Sum],
		[Approved],	
		[Calculation]
		)
		
	SELECT
		[Employee].[ID],		
		 DATEPART(WEEKDAY,[TimeEntry].[StartTime]),
		 SUM([TimeEntry].[RoundedDuration] / 60.0),
		SUM(CASE WHEN [TimeEntry].[State]in(3,6) 
				 THEN [TimeEntry].[RoundedDuration] / 60.0
				ELSE 0 END),					
		SUM(CASE WHEN [TimeEntry].[State]in(3,6)
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END)
	FROM
		[Employee] 
		INNER JOIN [Company] 
			ON [Employee].[CompanyID] = [Company].[ID]
		LEFT OUTER JOIN [Division] 
			ON [Employee].[DivisionID] = [Division].[ID]	
		LEFT OUTER JOIN	[vwTimeEntry] as [TimeEntry]
			ON ([Employee].[ID] = [TimeEntry].[EmployeeID])
			AND ([TimeEntry].[StartTime] >= @WeekStart AND [TimeEntry].[StartTime]<@NextDate)												
	WHERE
		([Employee].[CompanyID] = @CompanyID OR @CompanyID IS NULL) AND
		(
			@DivisionSelector = 0 OR 
			(@DivisionSelector = 1 AND [Employee].[DivisionID] IS NULL) OR
			(@DivisionSelector = 2 AND (@DivisionID IS NULL OR [Employee].[DivisionID] = @DivisionID ))
		) 
		AND [Employee].[State] = 1 	AND
		 [Company].[Own] = 1 AND [Company].[State] = 1		
	GROUP BY
		[Employee].[ID],
		 DATEPART(WEEKDAY,[TimeEntry].[StartTime])
	
	
SELECT
	[Employee].[FileAs] AS [EmployeeName],
	ISNULL((SELECT [Sum] 
		FROM @t WHERE [EmployeeID] = [Employee].[ID] AND [Day] = 1), 0) AS [Total1],
	ISNULL((SELECT [Sum] 
		FROM @t WHERE [EmployeeID] = [Employee].[ID] AND [Day] = 2), 0) AS [Total2],
	ISNULL((SELECT [Sum] 
		FROM @t WHERE [EmployeeID] = [Employee].[ID] AND [Day] = 3), 0) AS [Total3],
	ISNULL((SELECT [Sum] 
		FROM @t WHERE [EmployeeID] = [Employee].[ID] AND [Day] = 4), 0) AS [Total4],
	ISNULL((SELECT [Sum] 
		FROM @t WHERE [EmployeeID] = [Employee].[ID] AND [Day] = 5), 0) AS [Total5],
	ISNULL((SELECT [Sum] 
		FROM @t WHERE [EmployeeID] = [Employee].[ID] AND [Day] = 6), 0) AS [Total6],
	ISNULL((SELECT [Sum] 
		FROM @t WHERE [EmployeeID] = [Employee].[ID] AND [Day] = 7), 0) AS [Total7],
	(SELECT Sum([Approved]) 
		FROM @t WHERE [EmployeeID] = [Employee].[ID]) AS [Approved],
	(SELECT Sum([Calculation]) 
		FROM @t WHERE [EmployeeID] = [Employee].[ID]) AS [Calculation]	

	FROM 
		[Employee]
		INNER JOIN @t AS t
			ON [Employee].[ID] = t.[EmployeeID]
	GROUP BY 
		[Employee].[FileAs],
		[Employee].[ID]
	--UNION ALL
	--SELECT NULL,0,0,0,0,0,0,0,0,0		
	

RETURN 0
GO

GRANT EXEC ON ReportWRE TO PUBLIC

GO