IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'VistaServiceRequestReport')
	BEGIN
		PRINT 'Dropping Procedure VistaServiceRequestReport'
		DROP  Procedure  VistaServiceRequestReport
	END
GO
PRINT 'Creating Procedure VistaServiceRequestReport'
GO

CREATE Procedure VistaServiceRequestReport
		@StateSelector INT,
		@DateSelector INT,
		@PeriodStart TDate,
		@PeriodEnd TDate
AS
	SET NOCOUNT ON
		
	IF @DateSelector = 1
	BEGIN
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodStart = DATEADD(day, 1-DATEPART(day, @PeriodStart), @PeriodStart),
			@PeriodStart = DATEADD(month, -1, @PeriodStart),
			@PeriodEnd = DATEADD(day, -1, DATEADD(month, 1, @PeriodStart))
	END
	ELSE IF @DateSelector = 2 -- current month
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodStart = DATEADD(day, 1-DATEPART(day, @PeriodStart), @PeriodStart),
			@PeriodEnd = DATEADD(day, -1, DATEADD(month, 1, @PeriodStart))

	SET @PeriodEnd = DATEADD(day, 1, @PeriodEnd)

	DECLARE	
	@value TVariant,
	@VATRate TPercent

	EXEC adfParameterGet 'VATRate', 'CommonBusiness', @value OUTPUT	
	SET @VATRate = CAST(@value AS decimal(18,4))

	DECLARE @Lang TLanguage
	SET @Lang = dbo.adfGetLanguage()

	SELECT
		[ServiceAssignment].[ID] as [ServiceAssignmentID],
		[ServiceRequest].[Number],
		[ServiceRequest].[Date],
		[ServiceRequest].[DueDate],
		[ServiceRequestLine].[FactAmount] as [Amount],
		[SupplierCompany].[FileAs] AS [SupplierFileAs],
		[CustomerCompany].[FileAs] As [CustomerFileAs],
		[Project].[FileAs] as [ProjectFileAs],
		CONVERT(datetime, CONVERT(varchar(8), [Project].[Date], 112), 112) as [ProjectDate],
		[Project].[CurrencyCode],
		CASE [Project].[ApplyVAT] * 2 + [ServiceRequest].[VATIsIncluded]
			WHEN 0 THEN [ServiceRequestLine].[Price]
			WHEN 1 THEN [ServiceRequestLine].[Price] / (1 + @VATRate)
			WHEN 2 THEN [ServiceRequestLine].[Price]
			WHEN 3 THEN [ServiceRequestLine].[Price] / (1 + @VATRate)
		END as [Price],
		CASE [Project].[ApplyVAT] * 2 + [ServiceRequest].[VATIsIncluded]
			WHEN 0 THEN [ServiceRequestLine].[Price] * [ServiceRequestLine].[FactAmount]
			WHEN 1 THEN [ServiceRequestLine].[Price] * [ServiceRequestLine].[FactAmount] / (1 + @VATRate)
			WHEN 2 THEN [ServiceRequestLine].[Price] * [ServiceRequestLine].[FactAmount]
			WHEN 3 THEN [ServiceRequestLine].[Price] * [ServiceRequestLine].[FactAmount] / (1 + @VATRate)
		END as [Total], 
		CASE [Project].[ApplyVAT] * 2 + [ServiceRequest].[VATIsIncluded]
			WHEN 0 THEN [ServiceRequestLine].[Price] * [ServiceRequestLine].[FactAmount]
			WHEN 1 THEN [ServiceRequestLine].[Price] * [ServiceRequestLine].[FactAmount] / (1 + @VATRate)
			WHEN 2 THEN [ServiceRequestLine].[Price] * [ServiceRequestLine].[FactAmount] * (1 + @VATRate)
			WHEN 3 THEN [ServiceRequestLine].[Price] * [ServiceRequestLine].[FactAmount]
		END as [TotalWithVAT],
		CASE [Project].[ApplyVAT] * 2 + [ServiceRequest].[VATIsIncluded]
			WHEN 0 THEN 0
			WHEN 1 THEN 0
			WHEN 2 THEN [ServiceRequestLine].[Price] * [ServiceRequestLine].[FactAmount] * @VATRate 
			WHEN 3 THEN [ServiceRequestLine].[Price] * [ServiceRequestLine].[FactAmount] * @VATRate / (1 + @VATRate)
		END as [VAT],
		[Service].[Code],
		[ServiceAssignment].[FileAs] as [ServiceName],
		[ServiceType].[FileAs] as [ServiceType],
		[Employee].[Initials] as [Employee],
		[Division].[FileAs] as [Division],
		[Project].[ApplyVAT] * 2 + [ServiceRequest].[VATIsIncluded] as [VATState],
		ISNULL([StateGlobal].[Name], [State].[Name]) as [StateName]
	FROM
		[ServiceRequest]
		INNER JOIN [Project]
			ON [Project].[ID] = [ServiceRequest].[ProjectID]
		INNER JOIN [ServiceRequestLine]
			ON [ServiceRequest].[ID] = [ServiceRequestLine].[ServiceRequestID]
		INNER JOIN [ServiceAssignment]
			ON [ServiceAssignment].[ID] = [ServiceRequestLine].[ServiceAssignmentID]
		INNER JOIN [Service]
			ON [Service].[ID] = [ServiceAssignment].[ServiceID]
		INNER JOIN [ServiceType]
			ON [Service].[ServiceTypeID] = [ServiceType].[ID]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [ServiceRequest].[EmployeeID]
		INNER JOIN [Company] AS [SupplierCompany]
			ON [Project].[SupplierCompanyID] = [SupplierCompany].[ID]
		INNER JOIN [Company] AS [CustomerCompany]
			ON [Project].[CustomerCompanyID] = [CustomerCompany].[ID]
		LEFT OUTER JOIN [Division]
			ON [Division].[ID] = [Employee].[DivisionID]
		LEFT OUTER JOIN [State]
			ON [State].[Class] = [ServiceRequest].[Class] AND [State].[State] = [ServiceRequest].[State]
		LEFT OUTER JOIN [StateGlobal]
			ON [StateGlobal].[Class] = [ServiceRequest].[Class] AND [StateGlobal].[State] = [ServiceRequest].[State] AND [StateGlobal].[Language] = @Lang
	WHERE
		-- 
		(@DateSelector = 0 OR [ServiceRequest].[DueDate] BETWEEN @PeriodStart AND @PeriodEnd) AND
		-- 
		(
			--
			(@StateSelector = 0) OR 
			-- 
			(@StateSelector = 1 AND [ServiceRequest].[State] = 1) OR
			-- 
			(@StateSelector = 2 AND [ServiceRequest].[State] = 2) OR
			-- 
			(@StateSelector = 3 AND [ServiceRequest].[State] = 3) OR
			-- 
			(@StateSelector = 4 AND [ServiceRequest].[State] = 4) OR
			-- 
			(@StateSelector = 5 AND [ServiceRequest].[State] = 5) OR
			-- 
			(@StateSelector = 6 AND [ServiceRequest].[State] = 6) OR
			-- 
			(@StateSelector = 7 AND [ServiceRequest].[State] = 7) OR
			--  
			(@StateSelector = 8 AND [ServiceRequest].[State] != 6)
		)
	ORDER BY [ServiceRequest].[Number], [Service].[Code]

	RETURN 0
GO

GRANT EXEC ON VistaServiceRequestReport TO PUBLIC
GO
