IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5ServiceRequestBrowseByCategory]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5ServiceRequestBrowseByCategory'
		DROP PROCEDURE [dbo].[pjm5ServiceRequestBrowseByCategory]
	END
GO

PRINT 'Creating procedure pjm5ServiceRequestBrowseByCategory'
GO

/******************************************************************************
**		File: pjm5ServiceRequestBrowseByCategory.sql
**		Name: pjm5ServiceRequestBrowseByCategory
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: andrew.maklakov
**		Date: 08/02/2005 14:07:25
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5ServiceRequestBrowseByCategory]
	@StateSelector  INT,
	@ProjectID		TIdentifier,
	@DateSelector	INT,
	@PeriodStart	datetime,
	@PeriodEnd		datetime
AS
	SET NOCOUNT ON
	
	DECLARE
		@today datetime,
		@CurrentEmployeeID TIdentifier,
		@UserID int,
		@ViewAllProjects TBool
		
		
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @today = GETDATE()
	SET @UserID = dbo.adfGetCurrentUserID()
	SET	@ViewAllProjects = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects'))
	
	DECLARE @ViewAllFinance TBool
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	
	DECLARE @none nvarchar(6)
	IF dbo.adfGetLanguage() = 'ru'
		SET @none = '()'
	ELSE
		SET @none = '(none)'
		
	IF @DateSelector = 1 -- today
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, @PeriodStart)
	
	IF @DateSelector = 2 -- next seven days
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodEnd = DATEADD(day, 7, @PeriodStart)

	IF @DateSelector = 3 -- current week
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodStart = DATEADD(day, 1-DATEPART(weekday, @PeriodStart), @PeriodStart),
			@PeriodEnd = DATEADD(day, 7, @PeriodStart)

	IF @DateSelector = 4 -- previous week
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodStart = DATEADD(day, 1-7-DATEPART(weekday, @PeriodStart), @PeriodStart),
			@PeriodEnd = DATEADD(day, 7, @PeriodStart)

	IF @DateSelector = 5 -- current month
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodStart = DATEADD(day, 1-DATEPART(day, @PeriodStart), @PeriodStart),
			@PeriodEnd = DATEADD(month, 1, @PeriodStart)
			
	IF @DateSelector = 6 -- arbitrary period
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime),
			@PeriodEnd = CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, @PeriodEnd)
	
	SELECT
		[ServiceRequest].[Class],
		[ServiceRequest].[ID],
		[ServiceRequest].[ProjectID],
		[ServiceRequest].[EmployeeID],
		[ServiceRequest].[PriorityID],
		[ServiceRequest].[State],
		[ServiceRequest].[Flag],
		[ServiceRequest].[Date],
		[ServiceRequest].[Number],
		[ServiceRequest].[FileAs],
		[ServiceRequest].[Description],
		[ServiceRequest].[StartDate],
		[ServiceRequest].[DueDate],
		[ServiceRequest].[Billable],
		[ServiceRequest].[VATIsIncluded],
		[ServiceRequest].[Comments],
		[ServiceRequest].[Created],
		[ServiceRequest].[CreatedBy],
		[ServiceRequest].[Modified],
		[ServiceRequest].[ModifiedBy],
		[ServiceRequest].[Timestamp],
		[Project].[SupplierCompanyID],
		[Project].[CustomerCompanyID],
		[Project].[CurrencyCode] AS [CurrencyCode],
		[Project].[CurrencyCode] AS [ProjectCurrencyCode],
		ISNULL([Category].[FileAs], @none) as [Category],
		[ServiceRequest].[ManHour],
		[ServiceRequest].[ActualManHour],
		CASE 
			WHEN @ViewAllFinance = 1 OR [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
				THEN [ServiceRequest].[ActualBudget]
			ELSE -1
		END AS [ActualBudget]
	FROM
		[ServiceRequest]
		INNER JOIN [Project]
			ON [Project].[ID] = [ServiceRequest].[ProjectID]
		LEFT OUTER JOIN [DocumentCategory]
			ON ([ServiceRequest].[Class] = [DocumentCategory].[DocumentClass] AND
				[ServiceRequest].[ID] = [DocumentCategory].[DocumentID])
		LEFT OUTER JOIN [Category]
			ON ([DocumentCategory].[DocumentClass] = [Category].[DocumentClass] AND
				[DocumentCategory].[CategoryID] = [Category].[ID])
	WHERE
		(
			(@DateSelector = 0) OR
			(
				([ServiceRequest].[Date] >= @PeriodStart) AND
				([ServiceRequest].[Date] < @PeriodEnd)
			)
		) AND
		(
			@ViewAllProjects = 1 OR
			dbo.fnPjm5HasFinansDataAccess([Project].[ID], @CurrentEmployeeID, NULL, NULL) = 1 OR
			dbo.fnPjm5AllowCreateProjectEntry([Project].[ID], [ServiceRequest].[EmployeeID]) = 1 OR
			([ServiceRequest].[CreatedBy] = @UserID AND [ServiceRequest].[State] = 1)
		) AND
		(
			@StateSelector = 0 OR 
			@StateSelector != 0 AND [ServiceRequest].[State] = @StateSelector
		) AND
		(
			@ProjectID IS NULL OR [Project].[ID] = @ProjectID
		)
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm5ServiceRequestBrowseByCategory] TO PUBLIC
GO