IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5StatementGet]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5StatementGet'
		DROP PROCEDURE [dbo].[pjm5StatementGet]
	END
GO

PRINT 'Creating procedure pjm5StatementGet'
GO

/******************************************************************************
**		File: pjm5StatementGet.sql
**		Name: pjm5StatementGet
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 01/21/2005 15:47:39
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		25.02.14	SAP				       
**		06.03.14	SAP				   ,    != . 
*******************************************************************************/
CREATE PROCEDURE [pjm5StatementGet]
	@ID TIdentifier
AS
	SET NOCOUNT ON
	DECLARE
		@ProjectID TIdentifier,
		@Class	TClass,
		@Lang	TLanguage

	SET @Lang = dbo.adfGetLanguage()

	SELECT
		@ProjectID = [Statement].[ProjectID],
		@Class = [Statement].[Class]
	FROM 
		[Statement]
	WHERE
		[Statement].[ID] = @ID
	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	IF dbo.fnPjm5HasFinansDataAccess(@ProjectID, @EmployeeID, @Class, NULL) != 1
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	DECLARE
		@advanceValue TMoney,
		@advanceVat TMoney,
		@paymentValue TMoney,
		@paymentVat TMoney,
		@paymentValuePC TMoney,
		@paymentVatPC TMoney,
		@UserID TIdentifier
		
	SET @UserID = dbo.adfGetCurrentUserID()
	
	SELECT 
		@advanceValue = ISNULL(SUM([Invoice].[TotalWithVAT]), 0),
		@advanceVat = ISNULL(SUM([Invoice].[VAT]), 0)	
	FROM
		[StatementAdvanceInvoice] 
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [StatementAdvanceInvoice].[AdvanceInvoiceID]
	WHERE
		[StatementAdvanceInvoice].[StatementID] = @ID

	SELECT 
		@paymentValue = SUM(ISNULL([StatementAdvanceInvoice].[StatementPaymentValue], 0.0)),
		@paymentVat = SUM(ISNULL([StatementAdvanceInvoice].[StatementPaymentVAT], 0.0)),
		@paymentValuePC = SUM(ISNULL([StatementAdvanceInvoice].[StatementPaymentValuePC], 0.0)),
		@paymentVatPC = SUM(ISNULL([StatementAdvanceInvoice].[StatementPaymentVATPC], 0.0))
	FROM
		[StatementAdvanceInvoice] 
	WHERE
		[StatementAdvanceInvoice].[StatementID] = @ID

	DECLARE	@RecurrencePatternID TIdentifier
	SELECT @RecurrencePatternID = [RecurrencePatternID] FROM [Document] WHERE [Document].[Class] = @Class AND [Document].[ID] = @ID

	SELECT
		[Statement].[Class],
		[Statement].[ID],
		[Statement].[State],
		[Statement].[Flag],
		[Statement].[WarningFlagID],
		ISNULL([WarningFlagGlobal].[FileAs], [WarningFlag].[FileAs]) AS [WarningMessage],
		[WarningFlag].[WarningType],
		[Statement].[Date],
		[Statement].[Number],
		[Statement].[FileAs],
		[Statement].[ProjectID],
		[Statement].[PeriodStart],
		[Statement].[PeriodEnd],
		[Statement].[Comments],
		[Statement].[Created],
		[Statement].[CreatedBy],
		[Statement].[Modified],
		[Statement].[ModifiedBy],
		[Statement].[Timestamp],
		[Statement].[SupplierCompanyID],
		[Statement].[CustomerCompanyID],
		[Project].[ContractNumber],
		[Statement].[CurrencyCode],
		[Statement].[CurrencyRate],
		[Statement].[BaseCurrencyRate],
		[Project].[CurrencyCode] AS [ProjectCurrencyCode],
		[Statement].[TotalPC],
		[Statement].[TotalWithVATPC],
		[Statement].[VATPC],
		[Statement].[Total],
		[Statement].[TotalWithVAT],
		[Statement].[VAT],
		@advanceValue AS [AdvanceValue],
		@advanceVat AS [AdvanceVAT],
		ISNULL(@paymentValue, 0.0) AS [PaymentValue],
		ISNULL(@paymentVat, 0.0) AS [PaymentVAT],
		ISNULL(@paymentValuePC, 0.0) AS [PaymentValuePC],
		ISNULL(@paymentVatPC, 0.0) AS [PaymentVATPC],
		[Statement].[ReturnDate],
		ISNULL([UserReminder].[State], CAST(0 as int)) AS [ReminderState],
		CASE
			WHEN [UserReminder].[OriginalInterval] IS NOT NULL THEN
				DATEADD(minute,-[UserReminder].[OriginalInterval],[Statement].[ReturnDate])
			ELSE
				DATEADD(minute,
					-dbo.fnPjm5GetReminderInterval([Statement].[Class], 'MD', @UserID),
					[Statement].[ReturnDate])
		END
		AS [ReminderTime],
		@RecurrencePatternID as [RecurrencePatternID],
		[Statement].[ExchangeBanned],
		[ExportItem].[Date] as [Exported],
		[ExportItem].[EmployeeID] as [ExportedBy]
	FROM
		[Statement]
		INNER JOIN [Project]
			ON [Statement].[ProjectID] = [Project].[ID]
		LEFT OUTER JOIN [Reminder]
			ON ([Reminder].[DocumentClass] = [Statement].[Class] AND
				[Reminder].[DocumentID] = [Statement].[ID] AND
				[Reminder].[Subtype] = 'MD')
		LEFT OUTER JOIN [UserReminder]
			ON ([Reminder].[ID] = [UserReminder].[ReminderID] AND
				[UserReminder].[UserID] = @UserID)
		LEFT OUTER JOIN [ExportItem]
			ON [ExportItem].[ID] = [Statement].[ExportItemID]
		LEFT OUTER JOIN [WarningFlag]
			ON [WarningFlag].[ID] = [Statement].[WarningFlagID]
		LEFT OUTER JOIN [WarningFlagGlobal] 
			ON ([WarningFlag].[ID] = [WarningFlagGlobal].[ID]
				AND [WarningFlagGlobal].[Language] = @Lang)
	WHERE
		[Statement].[ID] = @ID

	
	DECLARE @Lines TABLE
	(
		[ID] int,
		[DocumentClass] TClass NULL,
		[DocumentID] int NULL,
		[Description] TNotes,
		[ServiceTypeID] int,
		[Amount] TAmount,
		[UOMID] int,
		[UOMCode] TCode,
		[VATRate] TPercent,
		[VATIsIncluded] bit,
		[Price] money,
		[PriceWithVAT] money,
		[VAT] money,
		[SumWithVAT] money,
		[PricePC] money,
		[PriceWithVATPC] money,
		[VATPC] money,
		[SumPC] money,
		[BasePrice] TCount,
		[SortKey] TCode,
		[ServiceTypeFileAs] TName
	)
	INSERT INTO @Lines
	SELECT 
		[StatementLine].[ID],
		[StatementLine].[DocumentClass],
		[StatementLine].[DocumentID],
		[StatementLine].[Description],
		[StatementLine].[ServiceTypeID],
		[StatementLine].[Amount],
		[StatementLine].[UOMID],
		[UOM].[Code] AS [UOMCode],
		[StatementLine].[VATRate],
		[StatementLine].[VATIsIncluded],
		NULL,
		NULL,
		NULL,
		NULL,
		[StatementLine].[PricePC],
		CASE 
			WHEN [StatementLine].[VATIsIncluded] = 1
				THEN [StatementLine].[PricePC]
			WHEN [StatementLine].[Amount] != 0 AND [StatementLine].[VATPC] = 0
				THEN [StatementLine].[PricePC]
			WHEN [StatementLine].[Amount] = 0
				THEN [StatementLine].[PricePC] * (1 + [StatementLine].[VATRate])
			ELSE
				ROUND(ROUND([StatementLine].[PricePC] * [StatementLine].[Amount] + [StatementLine].[VATPC], [Statement].[Scale]) / [StatementLine].[Amount], [Statement].[Scale]) 
		END AS [PriceWithVATPC],
		[StatementLine].[VATPC],
		ROUND(CASE 
				WHEN [StatementLine].[VATIsIncluded] = 1
					THEN [StatementLine].[Amount] * [StatementLine].[PricePC]
				ELSE [StatementLine].[PricePC] * [StatementLine].[Amount] + [StatementLine].[VATPC]
			END, [Statement].[Scale]) AS [SumPC],
		[StatementLine].[BasePrice],
		[StatementLine].[SortKey],
		[ServiceType].[FileAs] AS [ServiceTypeFileAs]
	FROM
		[StatementLine]
		INNER JOIN [Statement]
			ON [Statement].[ID] = [StatementLine].[StatementID]
		LEFT OUTER JOIN [UOM]
			ON [StatementLine].[UOMID] = [UOM].[ID]
		LEFT OUTER JOIN [ServiceType]
			ON [StatementLine].[ServiceTypeID] = [ServiceType].[ID]
	WHERE
		[StatementLine].[StatementID] = @ID
	ORDER BY 
		[StatementLine].[Description]

	DECLARE 
		@CurrencyRate decimal(18,10),
		@CurrencyCode TCode3,
		@NationalCurrencyCode TCode3,
		@Val TVariant

	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @Val OUTPUT
	SELECT
		@NationalCurrencyCode = CAST(@Val AS char(3)),
		@CurrencyRate = [CurrencyRate],
		@CurrencyCode = [CurrencyCode]
	FROM
		[Statement]
	WHERE 
		[ID] = @ID
	

	DECLARE
		@tmpID int,
		@tmpSumPC money,		
		@tmpAmount TAmount,
		@tmpVATRate TPercent

	DECLARE cur CURSOR FAST_FORWARD FOR
	SELECT
		[L].[ID],		
		[L].[SumPC],
		[L].[Amount],
		[L].[VATRate]
	FROM
		@Lines as [L]
			
			
	OPEN [cur]
	FETCH NEXT FROM [cur] INTO @tmpID, @tmpSumPC, @tmpAmount, @tmpVATRate
	WHILE @@fetch_status = 0
	BEGIN

		DECLARE	@TVWPC money,
				@TVW money,
				@Ttl money,
				@V money,
				@PVW money,
				@P money

		

		SET @TVWPC = @tmpSumPC
		IF @CurrencyCode = @NationalCurrencyCode
			SET @TVW = ROUND(@TVWPC * @CurrencyRate, 2)
		ELSE
			SET @TVW = ROUND(@TVWPC / @CurrencyRate, 2)
		SET @V = ROUND(@TVW * @tmpVATRate / (1 + @tmpVATRate), 2)
		SET @Ttl = @TVW - @V
		SET @PVW = ROUND(@TVW / @tmpAmount, 2)
		SET @P = ROUND(@Ttl / @tmpAmount, 2)

		UPDATE @Lines
		SET 
			[Price] = @P,
			[PriceWithVAT] = @PVW,
			[VAT] = @V,
			[SumWithVAT] = @TVW
		WHERE [ID] = @tmpID
		

		

	FETCH NEXT FROM [cur] INTO @tmpID, @tmpSumPC, @tmpAmount, @tmpVATRate
	END
	CLOSE [cur]
	DEALLOCATE [cur]

	
	SELECT * FROM @Lines

	SELECT
		[RecurrencePattern].[ID],
		[RecurrencePattern].[StartDate],
		[RecurrencePattern].[EndDate],
		[RecurrencePattern].[Occurrences],
		[RecurrencePattern].[RecurrenceType],
		[RecurrencePattern].[Interval],
		[RecurrencePattern].[DayOfWeekMask],
		[RecurrencePattern].[Instance],
		[RecurrencePattern].[MonthOfYear],
		[RecurrencePattern].[DayOfMonth]
	FROM
		[RecurrencePattern]
	WHERE
		[RecurrencePattern].[ID] = @RecurrencePatternID
	
	
	RETURN 0
GO

GRANT EXECUTE ON [pjm5StatementGet] TO PUBLIC
GO

