IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TaskBrowse]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5TaskBrowse'
		DROP PROCEDURE [dbo].[pjm5TaskBrowse]
	END
GO

PRINT 'Creating procedure pjm5TaskBrowse'
GO

/******************************************************************************
**		File: pjm5TaskBrowse.sql
**		Name: pjm5TaskBrowse
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 13:49:21
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5TaskBrowse]
	@Presentation	INT,
	@StateSelector	INT,
	@DateSelector	INT,
	@PeriodStart	datetime,
	@PeriodEnd		datetime,
	@Milestone		int
AS
	SET NOCOUNT ON
	DECLARE
		@ViewAllTasks TBool,
		@today datetime,
		@ViewAllFinance TBool,
		@CurrentEmployeeID TIdentifier
		
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewAllTasks = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllTasks'))
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @today = GETDATE()

	IF @DateSelector = 1 -- today
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, @PeriodStart)
	
	IF @DateSelector = 2 -- next seven days
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodEnd = DATEADD(day, 7, @PeriodStart)

	IF @DateSelector = 3 -- current week
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodStart = DATEADD(day, 1-DATEPART(weekday, @PeriodStart), @PeriodStart),
			@PeriodEnd = DATEADD(day, 7, @PeriodStart)

	IF @DateSelector = 4 -- previous week
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodStart = DATEADD(day, 1-7-DATEPART(weekday, @PeriodStart), @PeriodStart),
			@PeriodEnd = DATEADD(day, 7, @PeriodStart)

	IF @DateSelector = 5 -- current month
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodStart = DATEADD(day, 1-DATEPART(day, @PeriodStart), @PeriodStart),
			@PeriodEnd = DATEADD(month, 1, @PeriodStart)
			
	IF @DateSelector = 6 -- arbitrary period
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime),
			@PeriodEnd = CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, @PeriodEnd)

	SELECT
		[Task].[Class],
		[Task].[ID],
		[Task].[State],
		[Task].[Flag],
		[Task].[FileAs],
		[Task].[ProjectID],
		[Task].[PriorityID],
		[Task].[ParentID],
		[Task].[StartDate],
		[Task].[DueDate],
		[Task].[EndDate],
		[Task].[Duration],
		[Task].[PercentComplete],
		[Task].[Milestone],
		dbo.fnPjm5GetWorkingDays(@today, [Task].[DueDate]) AS [RestDays],
		[Task].[PlanPercent],
		[Task].[ManHour] / 60.0 AS [ManHour],
		CASE 
			WHEN @ViewAllFinance = 1 OR [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
				THEN [Task].[Budget]
			ELSE -1
		END AS [Budget],
		[Task].[RealManHour],
		CASE
			WHEN [Task].[ManHour] != 0 THEN
				CAST([Task].[RealManHour] as decimal(18,2))/[Task].[ManHour]
			ELSE 0
		END AS [RealManHourPercent],
		CASE 
			WHEN @ViewAllFinance = 1 OR [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
				THEN [Task].[TimeRealBudget]+[Task].[ExpenseRealBudget]
			ELSE -1
		END AS [RealBudget],
		CASE
			WHEN [Task].[Budget] != 0 THEN
				CAST([Task].[TimeRealBudget]+[Task].[ExpenseRealBudget] as decimal(18,2))/[Task].[Budget]
			ELSE 0
		END AS [RealBudgetPercent],
		[Task].[Comments],
		[Task].[Created],
		[Task].[CreatedBy],
		[Task].[Modified],
		[Task].[ModifiedBy],
		[Task].[Timestamp],
		CAST([Task].[Milestone] as tinyint) as M,
		(CAST([Task].[PercentComplete] * 100 as int) / 25) * 25 as PC
	FROM
		[pjm5vwTask] AS [Task]
		INNER JOIN [Project]
			ON [Task].[ProjectID] = [Project].[ID]
	WHERE
		(
			(@DateSelector = 0) OR
			(
				([Task].[DueDate] >= @PeriodStart) AND
				([Task].[StartDate] < @PeriodEnd)
			)
		) AND
		(
			(@StateSelector = 0 AND [Task].[State] != 7) OR			--  
			(@StateSelector = 1 AND [Task].[State] = 8) OR			-- 
			(@StateSelector = 2 AND [Task].[State] = 2) OR		-- 
			(@StateSelector = 3 AND [Task].[State] = 5) OR		-- 
			(@StateSelector = 4 AND [Task].[State] = 3) OR			-- 
			(@StateSelector = 5 AND [Task].[State] = 6)				-- 
		) AND
		(
			ISNULL(@Milestone, 0) != 1 OR [Task].[Milestone] = 1
		) AND
		(
			(
				(@Presentation = 0) AND
				(
				EXISTS(
					SELECT * 
					FROM
						[TaskAssignment] INNER JOIN [vwAssignment] AS [Assignment]
							ON ([TaskAssignment].[AssignmentID] = [Assignment].[ID])
					WHERE
						[TaskAssignment].[TaskID] = [Task].[ID] AND
						[Assignment].[EmployeeID] = @CurrentEmployeeID
						AND [TaskAssignment].[MsAvailable] = 1
					)
				)	
			) OR
			(
				(@Presentation = 2) AND
				(
					@ViewAllTasks = 1 OR 
					[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID OR 
					dbo.fnPjm5IsProjectMember([Project].[ID], @CurrentEmployeeID) = 1
				)
			)
		) AND [Task].[SubprojectID] IS NULL
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm5TaskBrowse] TO PUBLIC
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TaskMileStoneBrowse]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5TaskMileStoneBrowse'
		DROP PROCEDURE [dbo].[pjm5TaskMileStoneBrowse]
	END
GO

PRINT 'Creating procedure pjm5TaskMileStoneBrowse'
GO

/******************************************************************************
**		File: pjm5TaskMileStoneBrowse.sql
**		Name: pjm5TaskMileStoneBrowse
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 13:49:21
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
/*CREATE PROCEDURE [pjm5TaskMileStoneBrowse]
	@StateSelector	INT,
	@DateSelector	INT,
	@PeriodStart	datetime,
	@PeriodEnd		datetime
AS
	SET NOCOUNT ON
	DECLARE
		@ViewAllTasks TBool,
		@today datetime,
		@ViewAllFinance TBool,
		@CurrentEmployeeID TIdentifier
		
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewAllTasks = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllTasks'))
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @today = GETDATE()

	IF @DateSelector = 1 -- today
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, @PeriodStart)
	
	IF @DateSelector = 2 -- next seven days
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodEnd = DATEADD(day, 7, @PeriodStart)

	IF @DateSelector = 3 -- current week
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodStart = DATEADD(day, 1-DATEPART(weekday, @PeriodStart), @PeriodStart),
			@PeriodEnd = DATEADD(day, 7, @PeriodStart)

	IF @DateSelector = 4 -- previous week
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodStart = DATEADD(day, 1-7-DATEPART(weekday, @PeriodStart), @PeriodStart),
			@PeriodEnd = DATEADD(day, 7, @PeriodStart)

	IF @DateSelector = 5 -- current month
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
			@PeriodStart = DATEADD(day, 1-DATEPART(day, @PeriodStart), @PeriodStart),
			@PeriodEnd = DATEADD(month, 1, @PeriodStart)
			
	IF @DateSelector = 6 -- arbitrary period
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime),
			@PeriodEnd = CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, @PeriodEnd)

	SELECT
		[Task].[Class],
		[Task].[ID],
		[Task].[State],
		[Task].[Flag],
		[Task].[FileAs],
		[Task].[ProjectID],
		[Task].[PriorityID],
		[Task].[ParentID],
		[Task].[StartDate],
		[Task].[DueDate],
		[Task].[EndDate],
		[Task].[Duration],
		[Task].[PercentComplete],
		[Task].[Milestone],
		dbo.fnPjm5GetWorkingDays(@today, [Task].[DueDate]) AS [RestDays],
		[Task].[PlanPercent],
		[Task].[ManHour] / 60.0 AS [ManHour],
		CASE 
			WHEN @ViewAllFinance = 1 OR [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
				THEN [Task].[Budget]
			ELSE -1
		END AS [Budget],
		[Task].[RealManHour],
		CASE
			WHEN [Task].[ManHour] != 0 THEN
				CAST([Task].[RealManHour] as decimal(18,2))/[Task].[ManHour]
			ELSE 0
		END AS [RealManHourPercent],
		CASE 
			WHEN @ViewAllFinance = 1 OR [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
				THEN [Task].[TimeRealBudget]+[Task].[ExpenseRealBudget]
			ELSE -1
		END AS [RealBudget],
		CASE
			WHEN [Task].[Budget] != 0 THEN
				CAST([Task].[TimeRealBudget]+[Task].[ExpenseRealBudget] as decimal(18,2))/[Task].[Budget]
			ELSE 0
		END AS [RealBudgetPercent],
		[Task].[Comments],
		[Task].[Created],
		[Task].[CreatedBy],
		[Task].[Modified],
		[Task].[ModifiedBy],
		[Task].[Timestamp],
		CAST([Task].[Milestone] as tinyint) as M,
		(CAST([Task].[PercentComplete] * 100 as int) / 25) * 25 as PC
	FROM
		[pjm5vwTask] AS [Task]
		INNER JOIN [Project]
			ON [Task].[ProjectID] = [Project].[ID]
	WHERE
		[Task].[MileStone] = 1 AND
		(
			(@DateSelector = 0) OR
			(
				([Task].[DueDate] >= @PeriodStart) AND
				([Task].[StartDate] < @PeriodEnd)
			)
		) AND
		(
			(@StateSelector = 0 AND [Task].[State] != 7) OR			--  
			(@StateSelector = 1 AND [Task].[State] = 8) OR			-- 
			(@StateSelector = 2 AND [Task].[State] = 2) OR		-- 
			(@StateSelector = 3 AND [Task].[State] = 5) OR		-- 
			(@StateSelector = 4 AND [Task].[State] = 3) OR			-- 
			(@StateSelector = 5 AND [Task].[State] = 6)				-- 
		) AND
		(
			@ViewAllTasks = 1 OR 
			[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID OR 
			dbo.fnPjm5IsProjectMember([Project].[ID], @CurrentEmployeeID) = 1
		)
		
	RETURN 0
*/
--GO

--GRANT EXECUTE ON [pjm5TaskMileStoneBrowse] TO PUBLIC
--GO
