IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm6TaskRequestUpdate')
	BEGIN
		PRINT 'Dropping Trigger pjm6TaskRequestUpdate'
		DROP  Trigger pjm6TaskRequestUpdate
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm6TaskRequestUpdate
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		13.11.09	PAM					    
**										   	
**      
**		11.02.10	SYV					      
**										  UserParameters  
*******************************************************************************/

PRINT 'Creating Trigger pjm6TaskRequestUpdate'
GO
CREATE TRIGGER pjm6TaskRequestUpdate 
ON [TaskRequest] FOR UPDATE
AS
BEGIN
    IF @@rowcount = 0
       RETURN
       
	SET NOCOUNT ON

	DECLARE 
		@author TIdentifier,
		@user1 TIdentifier, 
		@user2 TIdentifier, 
		@taskrequest TIdentifier, 
		@percent1 TPercent,
		@percent2 TPercent,
		@startTime1 DateTime,
		@startTime2 DateTime,
		@dueTime1 DateTime,
		@dueTime2 DateTime,
		@employee TIdentifier,
		@rv int
		
	DECLARE users CURSOR FAST_FORWARD FOR
		SELECT
			[inserted].[CreatedBy], [inserted].[ID], e1.[UserID], e2.[UserID], [deleted].[PercentComplete], [inserted].[PercentComplete], 
			[deleted].[StartTime], [inserted].[StartTime], [deleted].[DueTime], [inserted].[DueTime]
		FROM
			[inserted]
			INNER JOIN [deleted]
				ON [deleted].[ID] = [inserted].[ID] AND 
					[deleted].[State] = 2 AND [inserted].[State] = 2
			LEFT OUTER JOIN [Employee] e1
				ON [inserted].[SupervisorEmployeeID] = e1.[ID]
			LEFT OUTER JOIN [Employee] e2
				ON [deleted].[SupervisorEmployeeID] = e2.[ID]
	OPEN users
	FETCH NEXT FROM users INTO @author, @taskrequest, @user1, @user2, @percent1, @percent2, @startTime1, @startTime2, @dueTime1, @dueTime2
	WHILE @@FETCH_STATUS = 0
	BEGIN
		IF @user1 != @user2
		BEGIN
			IF @user1 IS NOT NULL
				EXEC pjm6TaskRequestSupervisorOnAssignment @taskrequest, @user1
			IF @user2 IS NOT NULL
				EXEC pjm6TaskRequestSupervisorOffAssignment @taskrequest, @user2
		END
		IF @percent1 != @percent2
		BEGIN
			EXEC pjm6TaskRequestPercentChanged @taskrequest, @author, @percent1, @percent2
			IF @author != @user1
				EXEC pjm6TaskRequestPercentChanged @taskrequest, @user1, @percent1, @percent2
		END
		IF @startTime1 != @startTime2
		BEGIN
			EXEC pjm6TaskRequestStartTimeChanged @taskrequest, @author, @startTime1, @startTime2
			IF @author != @user1
			BEGIN
				EXEC pjm6TaskRequestStartTimeChanged @taskrequest, @user1, @startTime1, @startTime2
			END
			
			SET @employee = null
			DECLARE Assignment CURSOR FOR
				SELECT e2.[UserID] FROM [TaskRequestAssignment]
				LEFT OUTER JOIN [Employee] e2
				ON [TaskRequestAssignment].[EmployeeID] = e2.[ID]
				WHERE [TaskRequestAssignment].[TaskRequestID] = @taskrequest and e2.[UserID] != @author and 
				((@user1 is NULL) or  (@user1 is NOT NULL and e2.[UserID]!= @user1))
			OPEN Assignment
			FETCH NEXT FROM Assignment INTO @employee
			WHILE @@FETCH_STATUS = 0
			BEGIN
				EXEC pjm6TaskRequestStartTimeChanged @taskrequest, @employee, @startTime1, @startTime2
				FETCH NEXT FROM Assignment INTO @employee
			END
			CLOSE Assignment
			DEALLOCATE Assignment
		END
		IF @dueTime1 != @dueTime2
		BEGIN
			EXEC pjm6TaskRequestDueTimeChanged @taskrequest, @author, @dueTime1, @dueTime2
			IF @author != @user1
			BEGIN
				EXEC pjm6TaskRequestDueTimeChanged @taskrequest, @user1, @dueTime1, @dueTime2
			END

			SET @employee = null
			DECLARE Assignment CURSOR FOR
				SELECT e2.[UserID] FROM [TaskRequestAssignment]
				LEFT OUTER JOIN [Employee] e2
				ON [TaskRequestAssignment].[EmployeeID] = e2.[ID]
				WHERE [TaskRequestAssignment].[TaskRequestID] = @taskrequest and e2.[UserID] != @author and 
				((@user1 is NULL) or  (@user1 is NOT NULL and e2.[UserID]!= @user1))
			OPEN Assignment
			FETCH NEXT FROM Assignment INTO @employee
			WHILE @@FETCH_STATUS = 0
			BEGIN
				EXEC pjm6TaskRequestDueTimeChanged @taskrequest, @employee, @dueTime1, @dueTime2
				FETCH NEXT FROM Assignment INTO @employee
			END
			CLOSE Assignment
			DEALLOCATE Assignment
			
		END
		
		FETCH NEXT FROM users INTO @author, @taskrequest, @user1, @user2, @percent1, @percent2, @startTime1, @startTime2, @dueTime1, @dueTime2
	END
	CLOSE users
	DEALLOCATE users

	DECLARE @ToState TState,
			@FromState TState,
			@value TVariant,
			@Approve bit,
			@UserID int
	
	SET @value = NULL
	SET @UserID = dbo.adfGetCurrentUserID()		
	
	SELECT
		@FromState = [State]
	FROM
		[deleted]
	
	SELECT
		@ToState = [State]
	FROM
		[inserted]
	
	SELECT @value = [Value] FROM [UserParameter] WHERE [Name] = 'TimeEntryApproveForDocumentInFinalState' AND [UserID] = @UserID
	SET @Approve = ISNULL(CAST(@value as bit), 0)
	
	IF @ToState = 5 AND @FromState IN (2, 3) AND @Approve = 1
	BEGIN
		DECLARE @DocumentClass TClass,
				@DocumentID TIdentifier
		SELECT
				@DocumentClass = [Class],
				@DocumentID = [ID]
		FROM
			[inserted]		
		EXEC pjm6TimeEntryAutoApproveForDocumentInFinalState @DocumentClass, @DocumentID
	END
	
END
GO
